C
C
C
      SUBROUTINE   FDINVL
     I                   (BOUND, NCI, 
     O                    FLCLAS)
C
C     + + + PURPOSE + + +
C     Determines linear class intervals in log space and rounds to
C     2 significant digits.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      NCI
      REAL         BOUND(2), FLCLAS(NCI)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     BOUND  - upper bound of 2nd and last class intervals
C     NCI    - number of class intervals to use
C     FLCLAS  - upper bound of each class interval
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, N, L
      REAL         C, CR, CLOG, DENOM
C
C     + + + INTRINSICS + + +
      INTRINSIC    ALOG10, INT
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT (I3,1X,E11.4)
C
C     + + + END SPECIFICATIONS + + +
C
C     set up class intervals
      DENOM = NCI - 2
      CR = (BOUND(1)/BOUND(2))**(1.0/DENOM)
      FLCLAS(1) = 0.0
      FLCLAS(2) = BOUND(1)
      FLCLAS(NCI)= BOUND(2)
      DO 10 N = 1, NCI-3
        I = NCI - N
        FLCLAS(I) = FLCLAS(I+1)*CR
 10   CONTINUE
C
C     round off class intervals
      DO 20 I = 2, NCI
        C = FLCLAS(I)
        CLOG = ALOG10(C) + 0.001
        IF (CLOG.LT.0.0) CLOG = CLOG - 1
        L = INT(CLOG)
        L = L - 1
        C = (C/(10.0**L)) + 0.5
        FLCLAS(I) = (INT(C))*(10.0**L)
 20   CONTINUE
C
      RETURN
      END
C
C
C
      SUBROUTINE   FDCNT
     I                  (NDAYS, NCI, FLCLAS,
     M                   NUMT, NUMD, NUMB, NMIS, 
     O                   FMIN, FMAX)
C
C     + + + PURPOSE + + +
C     Counts the number of occurrences of flow in each class interval.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      NDAYS, NCI, NUMT(NCI), NUMD(NCI),
     $             NUMB(NCI), NMIS
      REAL         FLCLAS(NCI), FMIN, FMAX
C
C     + + + ARGUMENT DEFINITIONS + + +
C     NDAYS  - number of days in year being processed
C     NCI    - number of class intervals to use
C     FLCLAS  - upper bound of each class interval
C     NUMT   - no. of occurrences of total flow in each class intvl
C     NUMD   - no. of occurrences of surface runoff in each class intvl
C     NUMB   - no. of occurrences of base flow in each class intvl
C     NMIS   - number of values where total flow is less than zero
C     FMIN   - minimum flow value
C     FMAX   - maximum flow value
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'chysep.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, N
C
C     + + + END SPECIFICATIONS + + +
C
      FMIN = 1.0E+30
      FMAX = -1.0E+30
C
      DO 40 I = 1, NDAYS
        IF (DIS(I) .GE. 0.0) THEN
C         for total streamflow...
          N = NCI + 1
 10       CONTINUE
            N = N - 1
          IF (DIS(I).LT.FLCLAS(N) .AND. N.GT.1) GOTO 10
          NUMT(N) = NUMT(N) + 1
C
C         for base flow...
          N = NCI + 1
 20       CONTINUE
            N = N - 1
          IF (GDIS(I).LT.FLCLAS(N) .AND. N.GT.1) GOTO 20
          NUMB(N) = NUMB(N) + 1
C
C         for surface runoff...
          N = NCI + 1
 30       CONTINUE
            N = N - 1
          IF (RUNOFF(I).LT.FLCLAS(N) .AND. N.GT.1) GOTO 30
          NUMD(N) = NUMD(N) + 1
C
C         get min and max
          IF (DIS(I) .GT. 0.0) THEN
            IF (DIS(I) .LT. FMIN) FMIN = DIS(I)
            IF (DIS(I) .GT. FMAX) FMAX = DIS(I)
          END IF
        ELSE
C         bad value
          NMIS = NMIS + 1
        END IF
 40   CONTINUE
C
      RETURN
      END
C
C
C
      SUBROUTINE   FDTABL
     I                   (MESSFL, SCLU, STANAM, METH, IREC, YRARRY, NCI,
     I                    FLCLAS, NUMT, NUMD, NUMB, PRTFUN)
C
C     + + + PURPOSE + + +
C     Prints a flow-duration table for each of total flow, surface
C     runoff, and base flow.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      MESSFL, SCLU, METH, IREC, YRARRY(IREC), NCI, 
     $             NUMT(NCI), NUMD(NCI), NUMB(NCI), PRTFUN
      REAL         FLCLAS(NCI)
      CHARACTER*48 STANAM
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of message file
C     SCLU   - screen cluster number on message file
C     STANAM - station name/description
C     METH   - separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     IREC   - number of years processed
C     YRARRY - array of years processed
C     NCI    - number of class intervals
C     FLCLAS  - upper bound of each class interval
C     NUMT   - no. of occurrences of total flow in each class interval
C     NUMD   - no. of occurrences of surface runoff in each class interval
C     NUMB   - no. of occurrences of base flow in each class interval
C     PRTFUN - Fortran unit number of output (print) file
C
C     + + + PARAMETERS + + +
      INCLUDE 'pclass.inc'
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'chysep.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I4, SGRP, INIT, ILEN, CONT, TNUM, CNUMA, FLOW,
     $             JUST, OUTLEN, NUM(NCLASS,3), LEN
      REAL         PCTA(NCLASS), CPCTA(NCLASS)
      CHARACTER*1  FF, TBUFF(80), TITL1(65), TITL2(65), STYR(4), EDYR(4)
      CHARACTER*4  STYEAR, EDYEAR
      CHARACTER*12 YEARS
      CHARACTER*14 FLWTYP(3)
      CHARACTER*23 METHOD(3)
      CHARACTER*65 LINE1, LINE2
C
C     + + + FUNCTIONS + + +
      INTEGER      LENSTR
C
C     + + + EXTERNALS + + +
      EXTERNAL     WMSGTT
      EXTERNAL     CVARAR, CTRSTR, COPYI, INTCHR, CARVAR, LENSTR
C
C     + + + DATA INITIALIZATIONS + + +
      DATA FLWTYP /'total flow',
     $             'surface runoff',
     $             'base flow'/
      DATA METHOD /'fixed interval method  ',
     $             'sliding interval method',
     $             'local minimum method   ' /
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT (A1)
 2010 FORMAT (80A1)
 2020 FORMAT (1X)
 2030 FORMAT (8X,F9.2,I10,F10.2,I10,F10.2)
C
C     + + + END SPECIFICATIONS + + +
C
      I4 = 4
C
C     fill local NUM array with values from dummy arg.s
      CALL COPYI (NCI, NUMT, NUM(1,1))
      CALL COPYI (NCI, NUMD, NUM(1,2))
      CALL COPYI (NCI, NUMB, NUM(1,3))
C
      DO 50 FLOW = 1, 3
C       output laser printer form-feed character
        FF = CHAR(12)
        WRITE(PRTFUN,2000) FF
C       write heading
        JUST = 0
        CALL INTCHR (YRARRY(1), I4, JUST, 
     O               OUTLEN, STYR)
        CALL INTCHR (YRARRY(IREC), I4, JUST, 
     O               OUTLEN, EDYR)
        CALL CARVAR (I4, STYR, I4, STYEAR)
        CALL CARVAR (I4, EDYR, I4, EDYEAR)
        YEARS = ' ('//STYEAR//'-'//EDYEAR//')'
        I = 14
        LEN = LENSTR (I, FLWTYP(FLOW))
        LINE1 = 'Flow duration table for '//FLWTYP(FLOW)(1:LEN)//', '//
     $          METHOD(METH)
        I = 48
        LEN = LENSTR (I, STANAM)
        LINE2 = 'at '//STANAM(1:LEN)//YEARS
        ILEN = 65
        CALL CVARAR (ILEN, LINE1, ILEN,
     O               TITL1)
        CALL CVARAR (ILEN, LINE2, ILEN,
     O               TITL2)
        CALL CTRSTR (ILEN,TITL1)
        CALL CTRSTR (ILEN,TITL2)
        WRITE (PRTFUN,2010) (TITL1(I), I = 1, 65)
        WRITE (PRTFUN,2010) (TITL2(I), I = 1, 65)
        WRITE (PRTFUN,2020) 
        SGRP = 33
        INIT = 1
 10     CONTINUE
          ILEN = 80
          CALL WMSGTT (MESSFL,SCLU,SGRP,INIT,
     M                 ILEN,
     O                 TBUFF,CONT)
          INIT = 0
          WRITE(PRTFUN,2010) TBUFF
        IF (CONT.EQ.1) GO TO 10
C
        TNUM = 0
        DO 20 I = 1,NCI
          TNUM = TNUM + NUM(I,FLOW)
 20     CONTINUE
        CNUMA = TNUM
        PCTA(1) = 0.0
        DO 30 I = 1,NCI
          PCTA(I) = 100.0* REAL(NUM(I,FLOW))/ REAL(TNUM)
          IF (I.GT.1) THEN
            CNUMA = CNUMA - NUM(I-1,FLOW)
          END IF
          CPCTA(I) = 100.0*REAL(CNUMA)/REAL(TNUM)
C
C         print values; omit rows of values w/o meaningful numbers
          IF (I.NE.1 .AND. I.NE.NCI) THEN
            IF (.NOT. (NUM(I-1,FLOW).EQ.0 .AND. NUM(I+1,FLOW).EQ.0))
     $        WRITE(PRTFUN,2030) FLCLAS(I), NUM(I,FLOW), PCTA(I), CNUMA,
     $                           CPCTA(I)
          ELSE
            WRITE(PRTFUN,2030) FLCLAS(I), NUM(I,FLOW), PCTA(I), CNUMA,
     $                         CPCTA(I)
          END IF
 30     CONTINUE
C
 50   CONTINUE
C
      RETURN
      END
C
C
C
      SUBROUTINE   FDSET
C
C     + + + PURPOSE + + +
C     Assigns values for plot parameters not dependent on data
C     for flow duration plot of annual flows.
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I1, MAXVAR, YTYPE, XTYPE, WHICH(6), TICS, 
     $             TRNTYP(6), BVALFG(4)
      REAL         SIZEL, XPAGE, YPAGE, XPHYS, YPHYS, XLEN, YLEN, ALEN
      CHARACTER*80 XLABL
C
C     + + + EXTERNALS + + +
      EXTERNAL     GPLBXB, GPATYL, GPATYR, GPATXB, GPVWCH, GPTCYL
      EXTERNAL     GPTCXB, GPTRAN, GPBVFG, GPSIZE
C
C     + + + END SPECIFICATIONS + + +
C
      I1 = 1
      MAXVAR = 6
C
C     set x-axis label and plot title
      XLABL = 'PERCENTAGE OF TIME FLOW WAS EQUALED OR EXCEEDED'
      CALL GPLBXB (XLABL)
C
C     set axes types (left y- log, x- probability %, no right y-axis)
      YTYPE = 2
      CALL GPATYL (YTYPE)
      XTYPE = 6
      CALL GPATXB (XTYPE)
      YTYPE = 0
      CALL GPATYR (YTYPE)
C
C     set axis type for flow var.s to left-y, percent var.s to x-axis
      DO 20 I = 1, MAXVAR
        IF (MOD(I,2) .NE. 0) THEN
          WHICH(I) = 1
        ELSE
          WHICH(I) = 4
        END IF
 20   CONTINUE
      CALL GPVWCH (I1, MAXVAR, WHICH)
C
C     set number tics for y- and x-axis
      TICS = 10
      CALL GPTCYL (TICS)
      CALL GPTCXB (TICS)
C
C     set variable transformations
      DO 10 I = 1, MAXVAR
        IF (MOD(I,2) .NE. 0) THEN
C         flow variables--logarithmic
          TRNTYP(I) = 2
        ELSE
C         percents--arithmetic
          TRNTYP(I) = 1
        END IF
 10   CONTINUE
      CALL GPTRAN (I1, MAXVAR, TRNTYP)
C
C     set bad value flag to ignore values off scale
      BVALFG(1)= 4
      BVALFG(2)= 4
      BVALFG(3)= 4
      BVALFG(4)= 4
      CALL GPBVFG (BVALFG)
C
C     set up relative physical plot size
      SIZEL = 0.095
      XPAGE = 7.5
      YPAGE = 7.5
      XPHYS = 1.0
      YPHYS = 1.0
      XLEN = 5.5
      YLEN = 5.5
      ALEN = 0.0
      CALL GPSIZE (SIZEL, XPAGE, YPAGE, XPHYS, YPHYS, XLEN,
     $             YLEN, ALEN)
C
      RETURN
      END
C
C
C
      SUBROUTINE   FDDAT
     I                  (FDOPT, STAID, STANAM, METH, IREC, YRARRY, 
     I                   NCI, FLCLAS, NUMT, NUMD, NUMB, FMIN, FMAX, 
     I                   UNITFG)
C
C     + + + PURPOSE + + +
C     Assigns plot parameters specific to data for flow-duration plot
C     of annual flows.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      FDOPT(3), METH, IREC, YRARRY(IREC), NCI, 
     $             NUMT(NCI), NUMD(NCI), NUMB(NCI), UNITFG
      REAL         FLCLAS(NCI), FMIN, FMAX
      CHARACTER*8  STAID
      CHARACTER*48 STANAM
C
C     + + + ARGUMENT DEFINITIONS + + +
C     FDOPT  - flow-duration plot curves to be included (0-no, 1-yes)
C              FDOPT(1)  - total flow
C              FDOPT(2)  - surface runoff
C              FDOPT(3)  - base flow
C     STAID  - station ID
C     STANAM - station name/description
C     METH   - separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     IREC   - number of years processed
C     YRARRY - array of years processed
C     NCI    - number of class intervals
C     FLCLAS  - upper bound of each class interval
C     NUMT   - no. of occurrences of total flow in each class intvl
C     NUMD   - no. of occurrences of surface runoff in each class intvl
C     NUMB   - no. of occurrences of base flow in each class intvl
C     UNITFG - flow measurement units
C              1 - english (ft3/s)
C              2 - metric (m3/s)
C     FMIN   - minimum flow value
C     FMAX   - maximum flow value
C
C     + + + PARAMETERS + + +
      INCLUDE 'pclass.inc'
C
C     + + + SAVES + + +
      INTEGER      CVLAST(3)
      SAVE         CVLAST
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I1, I4, I20, NPTS, LN, JUST, NUMVAR, NUMCRV, J,
     $             RETCOD, SCLTYP, LNTYP(6), COLOR(6), PATTRN(6), 
     $             SYMBL(6), CVTYP(6), CRV, YVAR, XVAR, TOTL, FLWLIN(3),
     $             IPOS, OUTLEN, NMT(NCLASS), NMD(NCLASS), NMB(NCLASS)
      REAL         XA(100), XB(100), XC(100), Y(100), VARMIN(6),
     $             VARMAX(6), YLMIN, YLMAX, XMIN, XMAX,
     $             RTOTL, CPCTA(100), CPCTB(100), CPCTC(100)
      CHARACTER*1  STYR(4), EDYR(4)
      CHARACTER*4  YLAB, STYEAR, EDYEAR
      CHARACTER*13 YEARS
      CHARACTER*20 CLAB(3), CRVLAB(3), CINVL, XVARLB(3)
      CHARACTER*23 METHOD(3)
      CHARACTER*28 UNITS(2)
      CHARACTER*80 YLABL
      CHARACTER*240 TITL
      LOGICAL      SAME
C
C     + + + FUNCTIONS + + +
      INTEGER      LENSTR
      REAL         GAUSEX
C
C     + + + INTRINSICS + + +
      INTRINSIC    REAL
C
C     + + + EXTERNALS + + +
      EXTERNAL    GPSCYL, GPSCXB, GPDATR, GPNCRV, GPCURV, GPVMNX, SCALIT
      EXTERNAL    GPLBVR, GPTITL
      EXTERNAL    GAUSEX
      EXTERNAL    LENSTR, COPYI, INTCHR, CARVAR
C
C     + + + INPUT FORMATS + + +
 1000 FORMAT( 2X, 80A1 )
C
C     + + + DATA INITIALIZATIONS + + +
      DATA CINVL  /'Class interval'/
      DATA UNITS  /', IN CUBIC FEET PER SECOND',
     $             ', IN CUBIC METERS PER SECOND'/
      DATA CVLAST /0,0,0/
C
C     + + + END SPECIFICATIONS + + +
C
C     variable 1 = flow class intervals
C     variable 2 = percents for total flow
C     variable 3 = flow class intervals
C     variable 4 = percents for surface runoff
C     variable 5 = flow class intervals
C     variable 6 = percents for GW flow
C
      I1  = 1
      I4 = 4
      I20 = 20
      YLAB = 'FLOW'
      XVARLB(1) = '% exceed, total flow'
      XVARLB(2) = '% exceed, srfc rnoff'
      XVARLB(3) = '% exceed, base flow'
      CRVLAB(1) = 'TOTAL STREAMFLOW'
      CRVLAB(2) = 'SURFACE RUNOFF'
      CRVLAB(3) = 'BASE FLOW'
      METHOD(1) = 'fixed interval method  '
      METHOD(2) = 'sliding interval method'
      METHOD(3) = 'local minimum method   '
C     set line type for total flow to dashed
      FLWLIN(1) = 2
C     set line type for surface runoff to dotted
      FLWLIN(2) = 3
C     set line type for base flow to solid
      FLWLIN(3) = 1
C
      SAME = .TRUE.
      IF (.NOT. (FDOPT(1).EQ.CVLAST(1) .AND.
     $           FDOPT(2).EQ.CVLAST(2) .AND.
     $           FDOPT(3).EQ.CVLAST(3))) THEN
C       curves to be plotted aren't same ones as last time
        SAME = .FALSE.
        CVLAST(1) = FDOPT(1)
        CVLAST(2) = FDOPT(2)
        CVLAST(3) = FDOPT(3)
      END IF
C
      IF (.NOT. SAME) THEN
C       assign plot parameters for curves
C       set number of variables and curves to be plotted
        NUMCRV = FDOPT(1) + FDOPT(2) + FDOPT(3)
        NUMVAR = NUMCRV * 2
        CALL GPNCRV (NUMCRV,NUMVAR)
C
C       set y-axis label
        IF (NUMCRV .EQ. 1) THEN
C         put "Total flow"/"Surface runoff"/"Base flow" in y-axis label
          IF (FDOPT(1) .EQ. 1) THEN
            LN = LENSTR (I20, CRVLAB(1))
            YLABL = CRVLAB(1)(1:LN)//UNITS(UNITFG)
          ELSE IF (FDOPT(2) .EQ. 1) THEN
            LN = LENSTR (I20, CRVLAB(2))
            YLABL = CRVLAB(2)(1:LN)//UNITS(UNITFG)
          ELSE
            LN = LENSTR (I20, CRVLAB(3))
            YLABL = CRVLAB(3)(1:LN)//UNITS(UNITFG)
          END IF
        ELSE
C         just put "Flow" in y-axis label
          YLABL = YLAB//UNITS(UNITFG)
        END IF
        CALL GPLBYL(YLABL)
C
C       set the specifications for the curve(s)
        CRV = 1
C       loop through FDOPT to find curves to be plotted
        DO 10 I = 1, 3
          IF (FDOPT(I) .EQ. 1) THEN
C           set symbol type to none
            SYMBL(CRV) = 0
C           set color to black
            COLOR(CRV) = 1
C           set pattern to none
            PATTRN(CRV) = 0
C           set curve type to x-y plot
            CVTYP(CRV) = 6
C           set line types and curve labels
            IF (I .EQ. 1) THEN
              LNTYP(CRV) = FLWLIN(1)
              CLAB(CRV) = CRVLAB(1)
            ELSE IF (I .EQ. 2) THEN
              LNTYP(CRV) = FLWLIN(2)
              CLAB(CRV) = CRVLAB(2)
            ELSE
              LNTYP(CRV) = FLWLIN(3)
              CLAB(CRV) = CRVLAB(3)
            END IF
            CRV = CRV + 1
          END IF
 10     CONTINUE
        CALL GPCURV (CVTYP, LNTYP, SYMBL, COLOR, PATTRN,
     $               CLAB)
C
C     end if (.not. same)
      END IF
C
C     set plot title
      JUST = 0
      CALL INTCHR (YRARRY(1), I4, JUST, OUTLEN, STYR)
      CALL INTCHR (YRARRY(IREC), I4, JUST, OUTLEN, EDYR)
      CALL CARVAR (I4, STYR, I4, STYEAR)
      CALL CARVAR (I4, EDYR, I4, EDYEAR)
      YEARS = '('//STYEAR//'-'//EDYEAR//'), '
      TITL = 'Flow duration '//YEARS//METHOD(METH)//'&'//
     $       STAID//'  '//STANAM
      CALL GPTITL (TITL)
C
C     determine percents
      TOTL = 0
      DO 20 I = 1, NCI
        TOTL = TOTL + NUMT(I)
 20   CONTINUE
      RTOTL = REAL(TOTL)
C
      I = NCLASS
      CALL COPYI (I, NUMT, NMT)
      CALL COPYI (I, NUMD, NMD)
      CALL COPYI (I, NUMB, NMB)
C
      DO 25 I = 2, NCI
        NMT(I) = NMT(I-1) + NMT(I)
        NMD(I) = NMD(I-1) + NMD(I)
        NMB(I) = NMB(I-1) + NMB(I)
 25   CONTINUE
C
      DO 30 I = 1, NCI
        CPCTA(I) = 1 - REAL(NMT(I))/RTOTL
        CPCTB(I) = 1 - REAL(NMD(I))/RTOTL
        CPCTC(I) = 1 - REAL(NMB(I))/RTOTL
 30   CONTINUE
C
      NPTS = NCI - 1
      DO 40 I = 1, NPTS
        Y(I) = FLCLAS(I+1)
        XA(I) = -GAUSEX(CPCTA(I+1))
        XB(I) = -GAUSEX(CPCTB(I+1))
        XC(I) = -GAUSEX(CPCTC(I+1))
 40   CONTINUE
C
C     place data for each variable in plotting common block; set min/max
      CRV = 1
      IPOS = 1
      DO 50 I = 1, 3
        IF (FDOPT(I) .EQ. 1) THEN
C         place flow class intervals in plotting common block
          YVAR = CRV*2 - 1
          CALL GPDATR (YVAR, IPOS, NPTS, Y, RETCOD)
C         set min/max
          VARMIN(YVAR) = FLCLAS(2)
          VARMAX(YVAR) = FLCLAS(NCI)
C         set variable label
          CALL GPLBVR (YVAR, CINVL)
          IPOS = IPOS + NPTS
C
C         place percents for this curve in plotting common block
          XVAR = YVAR + 1
          IF (I .EQ. 1) THEN
            CALL GPDATR (XVAR, IPOS, NPTS, XA, RETCOD)
C           set min/max
            VARMIN(XVAR) = XA(1)
            VARMAX(XVAR) = XA(NPTS)
          ELSE IF (I .EQ. 2) THEN
            CALL GPDATR (XVAR, IPOS, NPTS, XB, RETCOD)
C           set min/max
            VARMIN(XVAR) = XB(1)
            VARMAX(XVAR) = XB(NPTS)
          ELSE
            CALL GPDATR (XVAR, IPOS, NPTS, XC, RETCOD)
C           set min/max
            VARMIN(XVAR) = XC(1) 
            VARMAX(XVAR) = XC(NPTS)
          END IF
C         set variable label
          CALL GPLBVR (XVAR, XVARLB(I))
          IPOS = IPOS + NPTS
          CALL GPWCXY (CRV, YVAR, XVAR)
          CRV = CRV + 1
        END IF
 50   CONTINUE
C
C     put min/max for all variables into plotting common block
      CALL GPVMNX (I1, NUMVAR, VARMIN, VARMAX)
C
C     set y-axis scale
      SCLTYP = 2
      CALL SCALIT (SCLTYP, FMIN, FMAX, 
     O             YLMIN, YLMAX)
      CALL GPSCYL (YLMIN, YLMAX)
C
C     set x-axis scale
      XMIN = -3.0
      XMAX = 3.0
      CALL GPSCXB (XMIN, XMAX)
C
      RETURN
      END
