C
C
C
      SUBROUTINE   FRQSET
C
C     + + + PURPOSE + + +
C     Assigns values for plot parameters not dependent on data 
C     for frequency plot of annual flows.
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I1, MAXVAR, TRNTYP(6), TICS, WHICH(6), 
     $             XTYP, YTYP, BVALFG(4) 
      REAL         ALEN, YLEN, SIZEL, XPAGE, YPAGE, XPHYS, YPHYS, XLEN
      CHARACTER*39 XLAB1
      CHARACTER*27 XLAB2
      CHARACTER*80 XLAB
C
C     + + + EXTERNALS + + +
      EXTERNAL     GPLBXB, GPSIZE, GPATYL, GPATXB, GPBVFG
      EXTERNAL     ZIPI
C
C     + + + END SPECIFICATIONS + + +
C
      I1 = 1
      MAXVAR = 6
C
C     set x-axis label
      XLAB1 = 'PERCENTAGE OF TIME RUNOFF WAS LESS THAN'
      XLAB2 = 'OR EQUAL TO INDICATED VALUE'
      XLAB = XLAB1 // '&' // XLAB2
      CALL GPLBXB (XLAB)
C
C     set axes types (left y- arith., x- probability %, no right y-axis)
      YTYP = 1
      CALL GPATYL (YTYP)
      XTYP = 6
      CALL GPATXB (XTYP)
      YTYP = 0
      CALL GPATYR (YTYP)
C
C     set axis type for flow var.s to left-y, freq. var.s to x-axis
      DO 10 I = 1, MAXVAR
        IF (MOD(I,2) .NE. 0) THEN
          WHICH(I) = 1
        ELSE
          WHICH(I) = 4
        END IF
 10   CONTINUE
      CALL GPVWCH (I1, MAXVAR, WHICH)
C
C     set number of tics for y- and bottom x-axis
      TICS = 10
      CALL GPTCYL (TICS)
      CALL GPTCXB (TICS)
C
C     set transformations to none (arithmetic)
      CALL ZIPI (MAXVAR, I1, TRNTYP)
      CALL GPTRAN (I1, MAXVAR, TRNTYP)
C
C     set bad value flag to ignore values off scale
      BVALFG(1)= 4
      BVALFG(2)= 4
      BVALFG(3)= 4
      BVALFG(4)= 4
      CALL GPBVFG (BVALFG)
C
C     set up relative physical plot size
      SIZEL = 0.095
      XPAGE = 7.5
      YPAGE = 7.5
      XPHYS = 1.0
      YPHYS = 1.0
      XLEN = 5.5
      YLEN = 5.5
      ALEN = 0.0
      CALL GPSIZE (SIZEL, XPAGE, YPAGE, XPHYS, YPHYS, XLEN,
     $             YLEN, ALEN)
C
      RETURN
      END
C
C
C
      SUBROUTINE   FRQDAT
     I                   (FRQOPT, STAID, STANAM, METH, NPTS, YRARRY,
     I                    FREQ, SRTQ, SRTBF, SRTDR, UNITFG)
C
C     + + + PURPOSE + + +
C     Assigns plot parameters specific to data for frequency plot
C     of annual flows.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      FRQOPT(3), METH, NPTS, YRARRY(NPTS), UNITFG
      REAL         FREQ(NPTS), SRTQ(NPTS), SRTBF(NPTS), SRTDR(NPTS)
      CHARACTER*8  STAID
      CHARACTER*48 STANAM
C
C     + + + ARGUMENT DEFINITIONS + + +
C     FRQOPT - array of flags of frequency distribution plot options
C              FRQOPT(1) - total flow 
C              FRQOPT(2) - surface runoff
C              FRQOPT(3) - base flow
C     METH   - base flow separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     STANAM - station name/description
C     STAID  - station ID
C     NPTS   - number of points to be plotted (no. of years processed)
C     YRARRY - array of years processed
C     FREQ   - frequency distribution of annual flows
C     SRTQ   - streamflow depth sorted by frequency
C     SRTBF  - base flow depth sorted by frequency
C     SRTDR  - surface runoff depth sorted by frequency
C     UNITFG - flow depth units
C              1 - english (inches)
C              2 - metric (centimeters)
C
C     + + + PARAMETERS + + +
      INCLUDE 'pmxyrs.inc'
C
C     + + + SAVES + + +
      INTEGER      CVLAST(3)
      SAVE         CVLAST
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I1, I4, I6, I20, NUMVAR, NUMCRV, SCLTYP, YVAR, 
     $             XVAR, IPOS, RETCOD, LNTYP(3), COLOR(3), PATTRN(3),
     $             CVTYP(3), SYMBL(3), FLWSYM(3), LN, JUST, OUTLEN, CRV
      REAL         VARMIN(6), VARMAX(6), YLMIN, YLMAX, XBMIN, XBMAX, 
     $             QMIN, QMAX, DRMIN, DRMAX, BFMIN, BFMAX, FRQMIN,
     $             FRQMAX, VMIN, VMAX, FRQTRN(MXYRS)
      CHARACTER*1  STYR(4), EDYR(4)
      CHARACTER*4  STYEAR, EDYEAR
      CHARACTER*6  YLAB
      CHARACTER*13 YEARS
      CHARACTER*16 UNITS(2)
      CHARACTER*20 CLAB(3), CRVLAB(3), XVARLB
      CHARACTER*23 METHOD(3)
      CHARACTER*80 YLABL
      CHARACTER*240 TITL
      LOGICAL      SAME
C
C     + + + FUNCTIONS + + +
      INTEGER      LENSTR
      REAL         GAUSEX
C
C     + + + EXTERNALS + + +
      EXTERNAL     GPNCRV, GPCURV, GPVMNX, SCALIT, GPSCYL, GPSCXB
      EXTERNAL     GPLBYL, GPTITL
      EXTERNAL     GAUSEX
      EXTERNAL     LENSTR, INTCHR, CARVAR, ZIPR
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  UNITS  /', IN INCHES',
     $              ', IN CENTIMETERS'/
      DATA  CVLAST /0,0,0/
C
C     + + + END SPECIFICATIONS + + +
C
      I1 = 1
      I4 = 4
      I6 = 6
      I20 = 20
      FRQMIN = 1.0E30
      FRQMAX = -1.0E30
C
      YLAB = 'RUNOFF'
      XVARLB = '% non-exceedance'
      CRVLAB(1) = 'TOTAL STREAMFLOW'
      CRVLAB(2) = 'SURFACE RUNOFF'
      CRVLAB(3) = 'BASE FLOW'
      METHOD(1) = 'fixed interval method  '
      METHOD(2) = 'sliding interval method'
      METHOD(3) = 'local minimum method   '
C     set symbol for total flow to 'O'
      FLWSYM(1) = 4
C     set symbol for surface runoff to 'X'
      FLWSYM(2) = 5
C     set symbol for base flow to '+'
      FLWSYM(3) = 2
C
      SAME = .TRUE.
      IF (.NOT. (FRQOPT(1).EQ.CVLAST(1) .AND.
     $           FRQOPT(2).EQ.CVLAST(2) .AND.
     $           FRQOPT(3).EQ.CVLAST(3))) THEN
C       curves to be plotted aren't same ones as last time
        SAME = .FALSE.
        CVLAST(1) = FRQOPT(1)
        CVLAST(2) = FRQOPT(2)
        CVLAST(3) = FRQOPT(3)
      END IF
C
      IF (.NOT. SAME) THEN
C       assign plot parameters for curves
C       set number of variables and curves to be plotted
        NUMCRV = FRQOPT(1) + FRQOPT(2) + FRQOPT(3)
        NUMVAR = NUMCRV * 2
        CALL GPNCRV (NUMCRV, NUMVAR)
C
C       set y-axis label
        IF (NUMCRV .EQ. 1) THEN
C         put "Total flow"/"Surface runoff"/"Base flow" in y-axis label
          IF (FRQOPT(1) .EQ. 1) THEN
            LN = LENSTR (I20, CRVLAB(1))
            YLABL = CRVLAB(1)(1:LN)//UNITS(UNITFG)
          ELSE IF (FRQOPT(2) .EQ. 1) THEN
            LN = LENSTR (I20, CRVLAB(2))
            YLABL = CRVLAB(2)(1:LN)//UNITS(UNITFG)
          ELSE
            LN = LENSTR (I20, CRVLAB(3))
            YLABL = CRVLAB(3)(1:LN)//UNITS(UNITFG)
          END IF
        ELSE
C         just put "Flow" in y-axis label
          YLABL = YLAB//UNITS(UNITFG)
        END IF
        CALL GPLBYL(YLABL)
C
C       set the specifications for the curve(s)
        CRV = 1
C       loop through FRQOPT to find curves to be plotted
        DO 10 I = 1, 3
          IF (FRQOPT(I) .EQ. 1) THEN
C           set line type to solid--connect the points
            LNTYP(CRV) = 1
C           set color to black
            COLOR(CRV) = 1
C           set pattern to none
            PATTRN(CRV) = 0
C           set curve type to x-y plot
            CVTYP(CRV) = 6
C           set symbols and curve labels
            IF (I .EQ. 1) THEN
              SYMBL(CRV) = FLWSYM(1)
              CLAB(CRV) = CRVLAB(1)
            ELSE IF (I .EQ. 2) THEN
              SYMBL(CRV) = FLWSYM(2)
              CLAB(CRV) = CRVLAB(2)
            ELSE
              SYMBL(CRV) = FLWSYM(3)
              CLAB(CRV) = CRVLAB(3)
            END IF
            CRV = CRV + 1
          END IF
 10     CONTINUE
        CALL GPCURV (CVTYP, LNTYP, SYMBL, COLOR, PATTRN,
     $               CLAB)
C     end if (.not. same)
      END IF
C
C     set plot title
      JUST = 0
      CALL INTCHR (YRARRY(1), I4, JUST, OUTLEN, STYR)
      CALL INTCHR (YRARRY(NPTS), I4, JUST, OUTLEN, EDYR)
      CALL CARVAR (I4, STYR, I4, STYEAR)
      CALL CARVAR (I4, EDYR, I4, EDYEAR)
      YEARS = '('//STYEAR//'-'//EDYEAR//'), '
      TITL = 'Annual flow '//YEARS//METHOD(METH)//'&'//
     $       STAID//'  '//STANAM
      CALL GPTITL (TITL)
C
C     perform probability transformation of frequency distribution
      DO 15 I = 1, NPTS
        FRQTRN(I) = -GAUSEX (0.01*FREQ(I))
 15   CONTINUE
C
C     place data for each variable in plotting common block
      CRV = 1
      IPOS = 1
      DO 20 I = 1, 3
C       save the annual flows
        IF (FRQOPT(I).EQ.1) THEN
          YVAR = CRV*2 - 1
          IF (I .EQ. 1) THEN
            CALL GPDATR (YVAR, IPOS, NPTS, SRTQ, RETCOD)
          ELSE IF (I .EQ. 2) THEN
            CALL GPDATR (YVAR, IPOS, NPTS, SRTDR, RETCOD)
          ELSE
            CALL GPDATR (YVAR, IPOS, NPTS, SRTBF, RETCOD)
          END IF
C         set variable label
          CALL GPLBVR (YVAR, CRVLAB(I))
          IPOS = IPOS + NPTS
C
C         save the frequency distribution
          XVAR = YVAR + 1
          CALL GPDATR (XVAR, IPOS, NPTS, FRQTRN, RETCOD)
C         set variable label
          CALL GPLBVR (XVAR, XVARLB)
          IPOS = IPOS + NPTS
C         link the variables to the curve
          CALL GPWCXY (CRV, YVAR, XVAR)
          CRV = CRV + 1
        END IF
 20   CONTINUE
C
C     find min/max for flow var.s; ignore null data (negative values)
      QMIN = 1.0E30
      QMAX = -1.0E30
      DRMIN = 1.0E30
      DRMAX = -1.0E30
      BFMIN = 1.0E30
      BFMAX = -1.0E30
      CALL ZIPR (I6, QMIN, VARMIN)
      CALL ZIPR (I6, QMAX, VARMAX)
      CRV = 1
      IF (FRQOPT(1) .EQ. 1) THEN
C       find streamflow min/max
        DO 30 I = 1, NPTS
          IF (SRTQ(I) .GT. QMAX)  QMAX = SRTQ(I)
          IF (SRTQ(I).LT.QMIN .AND. SRTQ(I).GE.0) QMIN = SRTQ(I)
 30     CONTINUE
        VARMIN(CRV*2-1) = QMIN
        VARMAX(CRV*2-1) = QMAX
        CRV = CRV + 1
      END IF
      IF (FRQOPT(2) .EQ. 1) THEN
C       find surface runoff min/max
        DO 40 I = 1, NPTS
          IF (SRTDR(I) .GT. DRMAX)  DRMAX = SRTDR(I)
          IF (SRTDR(I).LT.DRMIN .AND. SRTDR(I).GE.0) DRMIN = SRTDR(I)
 40     CONTINUE
        VARMIN(CRV*2-1) = DRMIN
        VARMAX(CRV*2-1) = DRMAX
        CRV = CRV + 1
      END IF
      IF (FRQOPT(3) .EQ. 1) THEN
C       find base flow min/max
        DO 50 I = 1, NPTS
          IF (SRTBF(I) .GT. BFMAX)  BFMAX = SRTBF(I)
          IF (SRTBF(I).LT.BFMIN .AND. SRTBF(I).GE.0) BFMIN = SRTBF(I)
 50     CONTINUE
        VARMIN(CRV*2-1) = BFMIN
        VARMAX(CRV*2-1) = BFMAX
      END IF
C
C     find frequency distribution min/max
      DO 60 I = 1, NPTS
        IF (FRQTRN(I) .GT. FRQMAX)  FRQMAX = FRQTRN(I)
        IF (FRQTRN(I).LT.FRQMIN .AND. FRQTRN(I).GE.0) FRQMIN = FRQTRN(I)
 60   CONTINUE
      DO 70 I = 2, NUMVAR, 2
        VARMIN(I) = FRQMIN
        VARMAX(I) = FRQMAX
 70   CONTINUE
C
C     put min/max for all variables into plotting common block
      CALL GPVMNX (I1, NUMVAR, VARMIN, VARMAX)
C
C     determine appropriate scale for y-axis
      VMIN = VARMIN(1)
      VMAX = VARMAX(1)
      DO 80 I = 3, NUMVAR-1, 2
        IF (VARMIN(I) .LT. VMIN) VMIN = VARMIN(I)
        IF (VARMAX(I) .GT. VMAX) VMAX = VARMAX(I)
 80   CONTINUE
      SCLTYP = 1
      CALL SCALIT (SCLTYP, VMIN, VMAX, 
     O             YLMIN, YLMAX)
C     set y-axis scale 
      CALL GPSCYL (YLMIN, YLMAX)
C
C     set x-axis scale 
      XBMIN = -3.0
      XBMAX = 3.0
      CALL GPSCXB (XBMIN, XBMAX)
C
      RETURN
      END
