C
C
C
      SUBROUTINE   SEASET
C
C     + + + PURPOSE + + +
C     Assigns values for plot parameters not dependent on data for 
C     bar graph of mean monthly base flow and surface runoff.
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I1, L4, L12, NUMCRV, NUMVAR, GWCH(12), TICNUM, 
     $             YTYPE, XTYPE, CRVTYP(2), LNTYP(2), GTRANF(12), 
     $             BVALFG(4), PAT(2)
      REAL         SIZEL, XPAGE, YPAGE, XPHYS, YPHYS, XLEN, YLEN, ALEN
      CHARACTER*20 CLAB(2)
C
C     + + + EXTERNALS + + +
      EXTERNAL     GPNCRV, GPLBCV, GPATXB, GPBVFG, GPSIZE
      EXTERNAL     GPATYL, GPVWCH, GPTCYL, GPTRAN, GPCTYP, GPLNTY
      EXTERNAL     GPPATN
      EXTERNAL     ZIPI
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  CLAB  /'BASE FLOW',
     $             'SURFACE RUNOFF'/
C
C     + + + END SPECIFICATIONS + + +
C
      I1 = 1
      L4 = 4
      L12 = 12
C
C     set number of curves to 2 (# bars per cluster)
      NUMCRV = 2
C     set number of variables to number of clusters of bars
      NUMVAR = 12
      CALL GPNCRV(NUMCRV, NUMVAR)
C
C     set curve labels
      DO 10 I = 1, NUMCRV
        CALL GPLBCV (I, CLAB(I))
 10   CONTINUE
C
C     set axes types (y-axis arithmetic, x-axis clustered bar chart)
      YTYPE = 1
      CALL GPATYL (YTYPE)
      XTYPE = 9
      CALL GPATXB (XTYPE)
C
C     set variables to be plotted on left y-axis
      CALL ZIPI (L12, I1, GWCH)
      CALL GPVWCH (I1, NUMVAR, GWCH)
C
C     set tics for left y-axis
      TICNUM = 10
      CALL GPTCYL (TICNUM)
C
C     set transformation type for variables to none (arithmetic)
      CALL ZIPI (L12, I1, GTRANF)
      CALL GPTRAN (I1, NUMVAR, GTRANF)
C
C     set curve types for bar graph
      CRVTYP(1) = 8
      CRVTYP(2) = 8
      CALL GPCTYP (I1, NUMCRV, CRVTYP)
C     set line types to solid
      LNTYP(1) = 1
      LNTYP(2) = 1
      DO 40 I = 1, NUMCRV
        CALL GPLNTY (I, LNTYP(I))
 40   CONTINUE
C
C     set fill patterns: base flow - hollow, surface runoff - diagonal
      PAT(1) = 1
      PAT(2) = 5
      DO 50 I = 1, NUMCRV
        CALL GPPATN (I, PAT(I)) 
 50   CONTINUE
C
C     set BVALFG to use clip option
      I = 1
      CALL ZIPI (L4, I, BVALFG)
      CALL GPBVFG (BVALFG)
C     set up sizes
      SIZEL = .11
      XPAGE = 10.0
      YPAGE = 8.0
      XPHYS = 1.5
      YPHYS = 1.5
      XLEN = 7.5
      YLEN = 5.0
      ALEN = 0.0
      CALL GPSIZE(SIZEL,XPAGE,YPAGE,XPHYS,YPHYS,XLEN,YLEN,ALEN)
C
      RETURN
      END
C
C
C
      SUBROUTINE   SEADAT
     I                   (SEAOPT, STAID, STANAM, METH, IREC, YRARRY,
     I                    BGNMON, DRAIN, MNCNT, MNTFL, MNTBF, UNITFG)
C
C     + + + PURPOSE + + +
C     Assigns plot parameters specific to data for bar graph of
C     mean monthly base flow and surface runoff.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      SEAOPT, METH, IREC, YRARRY(IREC), BGNMON, MNCNT(12), 
     $             UNITFG
      REAL         DRAIN, MNTFL(12), MNTBF(12)
      CHARACTER*8  STAID
      CHARACTER*48 STANAM
C
C     + + + ARGUMENT DEFINITIONS + + +
C     SEAOPT - seasonal bar chart option
C              1 - average
C              2 - percent
C     STAID  - station ID
C     STANAM - station name/description
C     METH   - base flow separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     IREC   - number of years to be processed
C     YRARRY - array of years processed
C     BGNMON - 1st month for annual summaries
C              1=Jan, 2=Feb,...,12=Dec
C     DRAIN  - drainage area
C     MNCNT  - count of days of flow for each month
C     MNTFL  - total flow for each month
C     MNTBF  - total base flow for each month
C     UNITFG - flow depth units
C              1 - english (inches)
C              2 - metric (centimeters)
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'chysep.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I1, I2, I4, L23, MON, RETCOD, IPOS, SCLTYP, 
     $             MTHLEN, NV, JUST, OUTLEN
      REAL         GVMIN(2), GVMAX(2), YLMIN, YLMAX, BF(12), SR(12),
     $             MNTSR, MINVAL, MAXVAL
      CHARACTER*1  STYR(4), EDYR(4)
      CHARACTER*4  STYEAR, EDYEAR
      CHARACTER*13 YEARS
      CHARACTER*20 VARLAB(12)
      CHARACTER*23 METHOD(3)
      CHARACTER*52 TITLA
      CHARACTER*80 YAVGLB(2), YPRCLB 
      CHARACTER*240 TITL
C
C     + + + FUNCTIONS + + +
      INTEGER      LENSTR
C
C     + + + INTRINSICS + + +
      INTRINSIC    AMIN1, AMAX1
C
C     + + + EXTERNALS + + +
      EXTERNAL     GPLBVR, GPDATR, GPVMNX, SCALIT, GPSCYL 
      EXTERNAL     GPWCTM, GPLBYL, GPTITL
      EXTERNAL     ZIPI, LENSTR
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  YAVGLB /'AVERAGE MONTHLY DISCHARGE, IN INCHES',
     $              'AVERAGE MONTHLY DISCHARGE, IN CENTIMETERS'/
      DATA  YPRCLB 
     $/'MONTHLY DISCHARGE, IN PERCENT OF AVERAGE MONTHLY FLOW'/
      DATA  TITLA 
     $/'Estimated mean monthly base flow and surface runoff '/
      DATA  VARLAB /'JAN',
     $              'FEB',
     $              'MAR',
     $              'APR',
     $              'MAY',
     $              'JUNE',
     $              'JULY',
     $              'AUG',
     $              'SEPT',
     $              'OCT',
     $              'NOV',
     $              'DEC'/
C
C     + + + END SPECIFICATIONS + + +
C
      I1 = 1
      I2 = 2
      I4 = 4
      L23 = 23
      METHOD(1) = 'fixed interval method  '
      METHOD(2) = 'sliding interval method'
      METHOD(3) = 'local minimum method   '
C
C     set variable labels
      MON = BGNMON
      DO 10 I = 1, 12
        CALL GPLBVR (I, VARLAB(MON))
        MON = MON + 1
        IF (MON .GT. 12) MON = MON - 12
 10   CONTINUE
C
C     set left y-axis label
      IF (SEAOPT .EQ. 1) THEN
C       label as average monthly values
        CALL GPLBYL (YAVGLB(UNITFG))
      ELSE IF (SEAOPT .EQ. 2) THEN
C       label as percent of average monthly flow
        CALL GPLBYL (YPRCLB)
      END IF
C
C     set plot title
      DO 20 I = 1, 240
        TITL(I:I) = ' '
 20   CONTINUE
      JUST = 0
      CALL INTCHR (YRARRY(1), I4, JUST, OUTLEN, STYR)
      CALL INTCHR (YRARRY(IREC), I4, JUST, OUTLEN, EDYR)
      CALL CARVAR (I4, STYR, I4, STYEAR)
      CALL CARVAR (I4, EDYR, I4, EDYEAR)
      YEARS = '('//STYEAR//'-'//EDYEAR//'),'
      MTHLEN = LENSTR (L23, METHOD(METH))
      TITL = TITLA // YEARS // '&' // METHOD(METH)(1:MTHLEN) // 
     $       ', ' // STAID // ' ' // STANAM
      CALL GPTITL (TITL)
C
      DO 30 I = 1, 12
        MNTSR = MNTFL(I) - MNTBF(I)
        IF (SEAOPT .EQ. 1) THEN
C         plot average monthly values
          IF (UNITFG .EQ. 1) THEN
C           convert from cfs to inches
            BF(I) = .03719*(MNTBF(I)/MNCNT(I))/DRAIN
            SR(I) = .03719*(MNTSR/MNCNT(I))/DRAIN
          ELSE IF (UNITFG .EQ. 2) THEN
C           convert from cfs to centimeters
            BF(I) = 8.64*(MNTBF(I)/MNCNT(I))/DRAIN
            SR(I) = 8.64*(MNTSR/MNCNT(I))/DRAIN
          END IF
        ELSE IF (SEAOPT .EQ. 2) THEN
C         plot values as percent of average monthly flow
          BF(I) = MNTBF(I)/MNTFL(I)
          SR(I) = MNTSR/MNTFL(I)
        END IF
 30   CONTINUE
C
C     place base flow data in plotting common block
      I = 1
      IPOS = 1
      NV = 12
      CALL GPDATR (I, IPOS, NV, BF, RETCOD)
C
C     place surface runoff data in plotting common block
      I = 2
      IPOS = IPOS + NV
      CALL GPDATR (I, IPOS, NV, SR, RETCOD)
C
C     find min and max; ignore null data (negative values)
      GVMIN(1) = 1.0E30
      GVMAX(1) = -1.0E30
      GVMIN(2) = 1.E30
      GVMAX(2) = -1.0E30
      DO 40 I = 1, 12
        IF (BF(I).GT.GVMAX(1)) GVMAX(1) = BF(I)
        IF (BF(I).LT.GVMIN(1) .AND. BF(I).GE.0)  GVMIN(1) = BF(I)
        IF (SR(I).GT.GVMAX(2)) GVMAX(2) = SR(I)
        IF (SR(I).LT.GVMIN(2) .AND. SR(I).GE.0)  GVMIN(2) = SR(I)
 40   CONTINUE
C     set data ranges
      CALL GPVMNX (I1, I2, GVMIN, GVMAX)
C
C     determine overall min/max
      MAXVAL = AMAX1(GVMAX(1), GVMAX(2))
      MINVAL = AMIN1(GVMIN(1), GVMIN(2))
C
C     determine appropriate scale for left y-axis based on largest GVMAX
      SCLTYP = 1
      CALL SCALIT (SCLTYP, MINVAL, MAXVAL,
     O             YLMIN, YLMAX)
C     set left y-axis scale
      CALL GPSCYL (YLMIN, YLMAX)
C
      RETURN
      END
