C
C
C
      SUBROUTINE   HYINWD
     I                   ( MESSFL, WDMFL, FE, INFL, OTFL,
     I                     DSSTAT, DSCFRM, DSNINC, LPTH, PTHNAM,
     M                     DSN )
C
C     + + + PURPOSE + + +
C     This routine reads standard WATSTORE card image daily values and 
C     the station header information, and outputs the information to a 
C     WDM file.  This routine is a variation of INWDVX.  The call to 
C     INDSOP--which interactively obtains input from the user--has been 
C     removed.  INRDST, which displays a progress report of the input 
C     process, is no longer called.  A value for TSFILL is explicitly 
C     assigned.
C
C     + + + KEYWORDS + + +
C     WDM file
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   MESSFL, WDMFL, FE, INFL, OTFL,
     $          DSSTAT, DSCFRM, LPTH, DSNINC, DSN
      CHARACTER*8 PTHNAM(LPTH)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of ANNIE message file
C     WDMFL  - Fortran unit number of WDM file
C     FE     - Fortran unit number for debug output (0 if none)
C     INFL   - Fortran unit number of daily values file
C     OTFL   - Fortran unit number for summary output
C              0 -no summary output file
C     DSSTAT - data set status
C              1 - new
C              2 - find
C              3 - existing
C     DSCFRM - confirm data set numbers, space, and attributes
C              1 - none
C              2 - first
C              3 - all
C     DSNINC - increment for new data sets
C     DSN    - data-set number
C
C     + + + COMMONS + + +
      INCLUDE 'ciowdm.inc'
      INCLUDE 'catrib.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER       NEW, LEN, RETC, DSTYPE, CFRM, IZIP, FLAGST
C     integer       i
      CHARACTER*1   ID
      CHARACTER*10  PARMST
      CHARACTER*15  STA
      CHARACTER*80  RECORD
C
C     + + + LOCAL DEFINITIONS + + +
C     NEW    - flag indicating record processing status
C              0 - continuing processing the same time series
C              1 - starting to process a new time series
C              2 - processing last input record
C              3 - read error
C     ID     - identifier for type of input record
C              Z - station header, agency record
C              H - station header, location record
C              N - station header, station name record
C              Y - station header, base discharge record
C              2 - daily values parameter and statistics record
C              3 - daily values data record
C
C     + + + EXTERNALS + + +
      EXTERNAL   INWHDR, INWAT2, INWAT3, INDSOP, INSVTS, CVWTAT
      EXTERNAL   INWSTA, INRDST, INWREC, INITAX
      EXTERNAL   DSNSET
      EXTERNAL   ZIPI, ZIPR
C
C     + + + DATA INITIALIZATION + + +
      DATA  DSTYPE / 1 /
C
C     + + + INPUT FORMATS + + +
 1002 FORMAT ( I4 )
C
C     + + + OUTPUT FORMATS + + +
 2001 FORMAT (/,' Warning:  unexpected or invalid record at', I6,
     $                      ', kount is', I6, ' (hyinwd)',
     $        /,'          ', A40, /,'          ', A40 )
C
C     + + + debug formats + + +
C3000 format ( '  back from   ktrec   new   sta              other',
C    $       /,' -----------  -----   ---   ---------------  --------')
C3001 format ( ' <-- inwrec:', i7, i5, 21x, 'rec = ', a80 )      
C3002 format ( ' <-- inwsta:', 15x, a15, 3x,
C    $                         'acval = ', 16a1,
C    $                         'aival =', I10 )
C3003 format ( ' <-- inwhdr:', i7, i5, 3x, a15, 3x, 'rec =', a80 )
C3004 format ( ' <-- inwat2:', i7, i5, 3x, a15, 3x, 'rec =', a80 )
C3005 format ( ' --> 3 loop:', i7, i5, 3x, a15, 3x, 'rec =', a80 )
C3006 format ( ' <-- inrdst:', i7, i5, 3x, a15, 3x, 'rec =', a80 )
C3007 format ( ' <-- inwat3:', i7, i5, 3x, a15, 3x, 'rec =', a80,
C    $       /,'            ', 32x, 'ipt =', i5 )
C3008 format ( ' <-- indsop:', i7, i5, 3x, a15, 3x, 'rec =', a80 )
C3009 format ( ' <-- insvts:', i7, i5, 3x, a15, 3x, 'retc =', i5 )
C3010 format ( ' end of 100:', i7, i5, 3x, a15, 3x, 'rec =', a80 )
C
C     + + + END SPECIFICATIONS + + +
C
C     set wdput arguments
      TSSTEP = 1
      TUNITS = 4
      DTOVWR = 0
      QFLAG  = 0
C
C     initialize counters, pointers, and dates
      KTERR = 0
      KTREC = 0
      IPT = 0
      NEW = 0
Cmyg  FLAGST = 1
Cmyg  CFRM = DSCFRM
      DSN = DSN - DSNINC
      IZIP = 0
      LEN = 18
      CALL ZIPI ( LEN, IZIP, DATES )
C
C     initialize identifiers
      PARMST = '          '
      STA    = '               '
      ID     = ' '
C
C     set TSFILL
      ARVAL(1) = -999.0
C
C     write (fe,3000)
 100  CONTINUE
C       process next record
        IF (ID .EQ. ' ') THEN
C         record is empty or invalid, get a new record
          CALL INWREC ( INFL, KTREC, ID, RECORD, NEW )
C         write (fe,3001) ktrec, new, record
        END IF
        IF (ID .EQ. 'Z') THEN
C         agency record
          CALL INWATZ ( INFL, FE,
     M                  KTREC, ID, RECORD, ACVAL(85), NEW )
        END IF
        IF (STA .NE. RECORD(2:16)) THEN
C         new station
          CALL INITAX
          PARMST = '          '
          NEW = 1
          STA = RECORD(2:16)
          CALL INWSTA ( STA, ACVAL(1), AIVAL(13) )
C        write (fe,3002) sta, (acval(i),i=1,16), aival(13)
        END IF
C       process record according to type
        IF (ID .EQ. 'Z'  .OR.  (STA .EQ. RECORD(2:16)  .AND.
     $     (ID .EQ. 'H' .OR. ID .EQ. 'Y' .OR. ID .EQ. 'N'))) THEN
C         same station record, same station
          CALL INWHDR ( INFL, FE, STA,
     M                  KTREC, ID, RECORD, NEW )
C         write (fe,3003) ktrec, new, sta, record
        ELSE IF (ID .EQ. '2'  .AND.  RECORD(2:16) .EQ. STA) THEN
C         parameter/statistics record, same station
          CALL INWAT2 ( INFL, FE,
     M                  KTREC, ID, RECORD, STA, PARMST, NEW,
     O                  AIVAL(14) )
C         write (fe,3004) ktrec, new, sta, record
          CALL CVWTAT ( MESSFL, AIVAL(14), ACVAL(17) )
        ELSE IF (ID .EQ. '3'  .AND.  RECORD(2:16) .EQ. STA) THEN
C         daily values record, same station
C         write (fe,3005) ktrec, new, sta, record
          IF (NEW .EQ. 1) THEN
C           this is a new time series, get base year from record
            READ (RECORD(17:20),1002) AIVAL(6)
C           get the data set number
            DSN = DSN + DSNINC
            CALL DSNSET (MESSFL, WDMFL, FE, DSN,
     O                   RETC)
Cmyg        CALL INDSOP ( MESSFL, WDMFL, FE, OTFL, LPTH, PTHNAM,
Cmyg I                    DSTYPE, DSSTAT, CFRM, DSNINC,
Cmyg M                    DSN,
Cmyg O                    RETC )
C           write (fe,3008) ktrec, new, sta, record
Cmyg        IF (CFRM .EQ. 2) THEN
C             confirm only the first time series
Cmyg          CFRM = 1
Cmyg        END IF
C           fill time-series array with missing value
            IPT = MXVAL
            CALL ZIPR ( IPT, ARVAL(1), VAL )
            IPT = 0
            NEW = 0
C           set status flag to new
Cmyg        FLAGST = 1
          END IF
 300      CONTINUE
C           process the daily values records
Cmyg        CALL INRDST ( MESSFL, LPTH, PTHNAM, FLAGST, STA, DSN )
C           write (fe,3006)  ktrec, new, sta, record
Cmyg        FLAGST = 2
            CALL INWAT3 ( INFL, FE,
     M                    ID, RECORD, STA, NEW )
C           write (fe,3007)  ktrec, new, sta, record, ipt
            IF (IPT .GT. 0) THEN
C             save the daily values to the wdm
              CALL INSVTS ( WDMFL, DSN, RETC )
C             write (fe,3009) ktrec, new, sta, retc
              CALL ZIPR ( IPT, ARVAL(1), VAL )
              IPT = 0
              DATES(1,1) = 0
            END IF
C           continue reading daily values if same station
          IF (ID .EQ. '3'  .AND.  RECORD(2:16) .EQ. STA) GO TO 300
        ELSE IF (NEW .NE. 2) THEN
C         invalid or bad record (not end of file)
          KTERR = KTERR + 1
          WRITE (FE,2001) KTREC,  KTERR, RECORD(1:40), RECORD(41:80)
          ID = ' '
        END IF
C       write (fe,3010) ktrec, new, sta, record
C       continue processing if end of file not reached
      IF (NEW .NE. 2) GO TO 100
C
C
      RETURN
      END
