C
C
C
      SUBROUTINE   FIXED
     I                   (NDAYS, DIS, INTRVL, LSTFLG,
     M                    START,
     O                    GDIS)
C
C     + + + PURPOSE + + +
C     Hydrograph separation by the fixed interval method
C     adapted from Pettyjohn and Henning (1979)
C     by R. A. Sloto
C     04/01/88   3.2
C
C     Code modified by AML for cases of missing data at beginning of 
C     record and transition between years.  Missing data values are 
C     defined by negative values.  9/16/91
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   NDAYS, INTRVL, START, LSTFLG
      REAL      DIS(NDAYS), GDIS(NDAYS)
C
C     + + + ARGUMENT DEFINITION + + +
C     NDAYS  - number of days for processing
C     DIS    - daily streamflow
C     INTRVL - time period in days for finding minimum
C     LSTFLG - flag set equal to 1 if last year being processed
C     START  - position (day) in DIS after which initial interval should begin
C              (index of last processed value/last bad value)
C     GDIS   - computed daily baseflow
C
C     + + + LOCAL VARIABLES + + +
      INTEGER   I, J, K, L1, L2, LD, LA, M, GOODV, FXDAYS
      REAL      PMIN
C
C     + + + END SPECIFICATIONS + + +
C
C     initialize variables and find start of good data--
C     initialize GDIS to 0.0 for days of good data and set equal
C     to DIS for days of negative data
      GOODV = 0
      DO 10 I = 1,NDAYS
        IF (DIS(I) .GE. 0.0) THEN
          GDIS(I) = 0.0
          GOODV = 1
        ELSE
          GDIS(I) = DIS(I)
C         reset START only if a good value hasn't been found after initial START
          IF (GOODV.EQ.0 .AND. I.GT.START)  START = I
        END IF
 10   CONTINUE
C
      FXDAYS = NDAYS
      IF (LSTFLG .EQ. 1) THEN
C       last year to process; reduce total days for processing by the
C       number of missing values within extra 11 days at end
        DO 15 I = NDAYS, NDAYS-10, -1
          IF (DIS(I) .LT. 0) THEN
            FXDAYS = FXDAYS - 1
          END IF
 15     CONTINUE
      END IF
C
      K = (FXDAYS - START)/INTRVL
C     for beginning of period
      IF (K .GE. 1) THEN
        DO 40 I = 1,K
          PMIN = 100000.
          L1 = ((I-1)*INTRVL) + START + 1
          L2 = I*INTRVL + START
          DO 20 J = L1,L2
            IF(DIS(J) .LT. PMIN)  PMIN = DIS(J)
 20       CONTINUE
          DO 30 J = L1,L2
            GDIS(J) = PMIN
 30       CONTINUE
 40     CONTINUE
      END IF
C
      IF (LSTFLG .NE. 1) THEN
C       set START for next year so that first few days of next year
C       use some of last few days of this year to determine base flow
C
C       find last day processed
        LD = START + K*INTRVL
C       find last day of year in array
        LA = NDAYS - 11
C       move START back in INTRVL increments
        M = LD
 70     CONTINUE
          M = M - INTRVL
        IF (M .GT. LA) GOTO 70
        START = 11 - (LA - M)
      ELSE
C       last year to process
        IF (L2 .LT. FXDAYS) THEN
C         extra days left over after processing K intervals;
C         do base-flow separation on those days by themselves
          PMIN = 100000.
          DO 80 J = L2+1,FXDAYS
            IF(DIS(J) .LT. PMIN)  PMIN = DIS(J)
 80       CONTINUE
          DO 90 J = L2+1,FXDAYS
            GDIS(J) = PMIN
 90       CONTINUE
        END IF
      END IF
C
      RETURN
      END
C
C
C
      SUBROUTINE   SLIDE
     I                   (NDAYS, DIS, INTRVL,
     O                    GDIS)
C
C     + + + PURPOSE + + +
C     Hydrograph separation by the sliding interval method
C     adapted from Pettyjohn and Henning (1979)
C     by R. A. Sloto
C     04/05/88   3.1
C
C     Code modified by AML for cases of missing data.  Missing data values
C     are identified by negative values.  Code also converted to
C     IF-THEN-ELSE structure.  9/16/91
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   NDAYS, INTRVL
      REAL      DIS(NDAYS), GDIS(NDAYS)
C
C     + + + ARGUMENT DEFINITION + + +
C     NDAYS  - number of days for processing
C     DIS    - daily streamflow
C     GDIS   - computed daily baseflow
C     INTRVL - time period in days for finding minimum
C
C
C     + + + LOCAL VARIABLES + + +
      INTEGER   I, J, INT, K1, K2, GOODV, START, S1, DAY
      REAL      PMIN
C
C     + + + END SPECIFICATIONS + + +
C
C     initialize variables and find start of good data--
C     initialize GDIS to 0.0 for days of good data and set equal
C     to DIS for days of negative data
      START = 0
      GOODV = 0
      DO 10 I = 1,NDAYS
        IF (DIS(I) .GE. 0.0) THEN
          GDIS(I) = 0.0
          GOODV = 1
        ELSE
          GDIS(I) = DIS(I)
C         reset START only if a good value hasn't been found yet
          IF (GOODV .EQ. 0) START = I
        END IF
 10   CONTINUE
C
      INT=(INTRVL-1)/2
      S1 = START + 1
      DO 50 I = S1, NDAYS
        IF(DIS(I).GE.0.0) THEN
C         set DAY equal to index of current day in year
          DAY = I - START
          IF (DAY .LE. INT) THEN
C           when day near beginning
            PMIN = 100000.
            K2 = I+INT
            DO 20 J = S1,K2
              IF(DIS(J).LT.PMIN) PMIN = DIS(J)
 20         CONTINUE
            GDIS(I) = PMIN
          ELSE IF (NDAYS-I .LE. INT) THEN
C           when day near end
            PMIN=100000.
            K1=I-INT
            DO 30 J=K1,NDAYS
              IF(DIS(J).LT.PMIN) PMIN=DIS(J)
 30         CONTINUE
            GDIS(I)=PMIN
          ELSE
C           when day not near beginning or end
            PMIN=100000.
            K1=I-INT
            K2=I+INT
            DO 40 J=K1,K2
              IF(DIS(J).LT.PMIN) PMIN=DIS(J)
 40         CONTINUE
            GDIS(I)=PMIN
          END IF
        END IF
 50   CONTINUE
C
      RETURN
      END
C
C
C
      SUBROUTINE   LOCMIN
     I                    (NDAYS, DIS, INTRVL,
     O                     GDIS)
C
C     + + + PURPOSE + + +
C     Hydrograph separation by the local minimum method
C     adapted from Pettyjohn and Henning (1979)
C     by R. A. Sloto
C     04/05/88   2.1
C
C     Code modified by AML for cases of missing data.  Missing data values
C     are identified by negative values.  Code also converted to
C     IF-THEN-ELSE structure.  9/16/91
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   NDAYS, INTRVL
      REAL      DIS(NDAYS), GDIS(NDAYS)
C
C     + + + ARGUMENT DEFINITION + + +
C     NDAYS  - Number of days in the year
C     DIS    - streamflow
C     GDIS   - baseflow
C     INTRVL - interval
C
C     + + + LOCAL VARIABLES + + +
      INTEGER   I, J, K, NUMPT, L, IPOINT(400), ID, PFLAG, END,
     $          IJ, IP1, IP2, ISTART, IEND, IJK, S, GOODV, START
      REAL      X, Y
C
C     + + + INTRINSCIS + + +
      INTRINSIC   ALOG10
C
C     + + + END SPECIFICATIONS + + +
C
      ID = 0
 10   CONTINUE
C       loop for periods of good data
        NUMPT = 0
        GOODV = 0
        PFLAG = 0
 20     CONTINUE
C         find start and end of good values
          ID = ID + 1
          IF (DIS(ID) .GE. 0.0) THEN
C           good value
            GDIS(ID) = 0.0
            IF (GOODV .EQ. 0) START = ID
            GOODV = GOODV + 1
            END = ID
          ELSE
C           bad value
            IF (GOODV .EQ. 0) THEN
C             no good values yet
              GDIS(ID) = DIS(ID)
            ELSE IF (GOODV .LT. INTRVL) THEN
C             not enough good values to process
              DO 25 J = 1, GOODV
                K = ID - J
                GDIS(K) = -999.0
 25           CONTINUE
              GOODV = 0
            ELSE
C             found good period to process
              PFLAG = 1
              GDIS(ID) = -999.0
            END IF
          END IF
        IF (ID.LT.NDAYS .AND. PFLAG.EQ.0) GO TO 20
C
        IF (GOODV .GE. INTRVL) THEN
C         have good period to process
          IF(INTRVL.EQ.3) THEN
            L=END-1
            S = START + 1
            DO 30 I = S, L
              IF(DIS(I).LE.DIS(I+1).AND.DIS(I).LE.DIS(I-1)) THEN
                NUMPT=NUMPT+1
                IPOINT(NUMPT)=I
              END IF
 30         CONTINUE
          ELSE IF(INTRVL.EQ.5) THEN
            L=END-2
            S = START + 2
            DO 35 I = S, L
              IF(DIS(I).LE.DIS(I+1).AND.DIS(I).LE.DIS(I-1).AND.
     $           DIS(I).LE.DIS(I+2).AND.DIS(I).LE.DIS(I-2)) THEN
                NUMPT=NUMPT+1
                IPOINT(NUMPT)=I
              END IF
 35         CONTINUE
          ELSE IF(INTRVL.EQ.7) THEN
            L=END-3
            S = START + 3
            DO 40 I = S, L
              IF(DIS(I).LE.DIS(I+1).AND.DIS(I).LE.DIS(I+2).AND.
     $           DIS(I).LE.DIS(I+3).AND.DIS(I).LE.DIS(I-1).AND.
     $           DIS(I).LE.DIS(I-2).AND.DIS(I).LE.DIS(I-3)) THEN
                NUMPT=NUMPT+1
                IPOINT(NUMPT)=I
              END IF
 40         CONTINUE
          ELSE IF(INTRVL.EQ.9) THEN
            L=END-4
            S = START + 4
            DO 45 I = S, L
              IF(DIS(I).LE.DIS(I+1).AND.DIS(I).LE.DIS(I+2).AND.
     $           DIS(I).LE.DIS(I+3).AND.DIS(I).LE.DIS(I-1).AND.
     $           DIS(I).LE.DIS(I-2).AND.DIS(I).LE.DIS(I-3).AND.
     $           DIS(I).LE.DIS(I+4).AND.DIS(I).LE.DIS(I-4)) THEN
                NUMPT=NUMPT+1
                IPOINT(NUMPT)=I
              END IF
 45         CONTINUE
          ELSE IF(INTRVL.GE.11) THEN
            L=END-5
            S = START + 5
            DO 50 I = S, L
              IF(DIS(I).LE.DIS(I+1).AND.DIS(I).LE.DIS(I+2).AND.
     $           DIS(I).LE.DIS(I+3).AND.DIS(I).LE.DIS(I-1).AND.
     $           DIS(I).LE.DIS(I-2).AND.DIS(I).LE.DIS(I-3).AND.
     $           DIS(I).LE.DIS(I+4).AND.DIS(I).LE.DIS(I-4).AND.
     $           DIS(I).LE.DIS(I+5).AND.DIS(I).LE.DIS(I-5)) THEN
                NUMPT=NUMPT+1
                IPOINT(NUMPT)=I
              END IF
 50         CONTINUE
          END IF
C
          IF (NUMPT .GT. 0) THEN
C           at least one local minimum found in good period being analyzed
            K=NUMPT-1
            J=IPOINT(1)
            L=IPOINT(NUMPT)
C           set beginning values to first local minimum
            DO 60 IJ=START,J
              GDIS(IJ)=DIS(J)
 60         CONTINUE
C           set ending values to last local minimum
            DO 65 IJ=L,END
              GDIS(IJ)=DIS(L)
 65         CONTINUE
C           set all the values in the middle
            DO 75 I=1,K
              IP1=IPOINT(I)
              IP2=IPOINT(I+1)
              GDIS(IP1)=DIS(IP1)
              GDIS(IP2)=DIS(IP2)
              ISTART=IP1
              IEND=IP2
              DO 70 J=ISTART,IEND
                X=J-IP1
                Y=IP2-IP1
                IF(GDIS(IP1).LE.0.0) GDIS(IP1)=0.01
                IF(GDIS(IP2).LE.0.0) GDIS(IP2)=0.01
                GDIS(J)=10.**((X/Y)*(ALOG10(GDIS(IP2))-
     $                  ALOG10(GDIS(IP1)))+ALOG10(GDIS(IP1)))
 70           CONTINUE
 75         CONTINUE
          ELSE
C           no local minimum found in period analyzed
            DO 80 I = START, END
              GDIS(I) = -999.0
 80         CONTINUE
          END IF
        END IF
      IF (END.LT.NDAYS .AND. ID.LT.NDAYS) GO TO 10
C
      DO 90 IJK=1,NDAYS
        IF(GDIS(IJK).GT.DIS(IJK)) GDIS(IJK)=DIS(IJK)
 90   CONTINUE
C
      RETURN
      END
C
C
C
      SUBROUTINE   MONTH
     I                  (STA, STAID, OTUNIT, UNITFG, ENGOPT, METH, 
     I                   INTRVL, DRAIN, IREC, IWY, NPFLAG, 
     I                   STMNTH, MXSIZE, 
     M                   ABFW, AQW, MNCNT, MNTFL, MNTBF)
C
C     + + + PURPOSE + + +
C     This subroutine calculates information about the hydrograph
C     separation on a monthly basis.
C     Adapted from Pettyjohn and Henning (1979) by R. A. Sloto.
C     04/25/88   3.0
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      OTUNIT, UNITFG, ENGOPT, METH, INTRVL, IREC, 
     $             IWY, NPFLAG, STMNTH, MXSIZE, MNCNT(12)
      REAL         DRAIN, ABFW(MXSIZE), AQW(MXSIZE), MNTFL(12), 
     $             MNTBF(12)
      CHARACTER*8  STAID
      CHARACTER*48 STA
C
C     + + + ARGUMENT DEFINITIONS + + +
C     STA    - name of station currently being processed
C     STAID  - station id. number
C     OTUNIT - Fortran unit number of output file
C     UNITFG - print file units
C              1 - english
C              2 - metric
C     ENGOPT - units for base flow in last column of print file
C              1 - Mgal/d/mi2
C              2 - Mgal/d
C              3 - ft3/s/mi2
C     METH   - separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     INTRVL - interval, in days, used in hydrograph separation
C     DRAIN  - drainage area
C     IREC   - order of current yr being processed w/in pd spec'd by user
C     IWY    - year in which the current 1-year period ends
C     NPFLAG - short/long printout flag
C              0 - don't print monthly summary
C              1 - 80 column output
C              2 - 132 column output
C     STMNTH - 1st month for annual summaries
C              1=Jan, 2=Feb,...,12=Dec
C     MXSIZE - maximum size of output arrays (maximum no. of years stored)
C     ABFW   - array of total annual base flow 
C     AQW    - array of total annual streamflow
C     MNCNT  - number of months with good values (no missing values)
C     MNTFL  - total flow for good months
C     MNTBF  - total base flow for good months
C
C     + + + COMMON BLOCS + + +
      INCLUDE 'chysep.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      K, I, J, M, DPM, NULFLG, SFNULL, BFNULL, L, YR
      REAL         MNTH(12,8), TOTALQ, TOTLGW, ANNLQ, ANNLGW, RDPM
      CHARACTER*5  MC(12), CC(12)
      CHARACTER*23 METHOD(3)
C
C     + + + INTRINSICS + + +
      INTRINSIC   REAL
C
C     + + + FUNCTIONS + + +
      INTEGER   DAYMON
C
C     + + + EXTERNALS + + +
      EXTERNAL   DAYMON
C
C     + + + DATA INITIALIZATIONS + + +
      DATA MC /'Jan. ', 'Feb. ', 'Mar. ', 'Apr. ',
     $         'May  ', 'June ', 'July ', 'Aug. ',
     $         'Sept.', 'Oct. ', 'Nov. ', 'Dec. '/
      DATA  METHOD / 'fixed interval method  ',
     $               'sliding interval method',
     $               'local minimum method   ' /
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT (/, 80('-'))
 2010 FORMAT (14X, 'Hydrograph separation by the ', A23/)
 2020 FORMAT (16X,A48/29X,'Station ID = ',A8/26X,'Drainage area = ',
     $        F10.2,' square miles')
 2025 FORMAT (16X,A48/29X,'Station ID = ',A8/26X,'Drainage area = ',
     $        F10.2,' square kilometers')
 2030 FORMAT ('Period ending in ',I4,41X,'interval = ', I2,' days'/)
 2100 FORMAT
     $(/6X,'   Mean       Mean       Mean     Total   Total   Total',
     $  1X,'   BF/     Base',
     $ /6X,'  stream-     base      surface  stream-   base  surface',
     $     ' stream-   flow',
     $ /6X,'   flow       flow      runoff    flow     flow   runoff',
     $     '  flow   (Mgal/d/',
     $ /6X,'  (ft3/s)    (ft3/s)    (ft3/s)    (in)    (in)    (in)',
     $  1X,'   (%)      mi2)',
     $ /6X,'---------- ---------- ---------- ------- ------- -------',
     $  '  ----- ----------')
 2110 FORMAT
     $(/6X,'   Mean       Mean       Mean     Total   Total   Total',
     $  1X,'   BF/',
     $ /6X,'  stream-     base      surface  stream-   base  surface',
     $     ' stream-   Base',
     $ /6X,'   flow       flow      runoff    flow     flow   runoff',
     $     '  flow     flow',
     $ /6X,'  (ft3/s)    (ft3/s)    (ft3/s)    (in)    (in)    (in)',
     $  1X,'   (%)   (Mgal/d)',
     $ /6X,'---------- ---------- ---------- ------- ------- -------',
     $  '  ----- ----------')
 2120 FORMAT
     $(/6X,'   Mean       Mean       Mean     Total   Total   Total',
     $  1X,'   BF/     Base',
     $ /6X,'  stream-     base      surface  stream-   base  surface',
     $     ' stream-   flow',
     $ /6X,'   flow       flow      runoff    flow     flow   runoff',
     $     '  flow    (ft3/s/',
     $ /6X,'  (ft3/s)    (ft3/s)    (ft3/s)    (in)    (in)    (in)',
     $  1X,'   (%)      mi2)',
     $ /6X,'---------- ---------- ---------- ------- ------- -------',
     $  '  ----- ----------')
 2130 FORMAT
     $(/6X,'   Mean       Mean       Mean     Total   Total   Total',
     $  1X,'   BF/     Base',
     $ /6X,'  stream-     base      surface  stream-   base  surface',
     $     ' stream-   flow',
     $ /6X,'   flow       flow      runoff    flow     flow   runoff',
     $     '  flow    (m3/s/',
     $ /6X,'  (m3/s)     (m3/s)     (m3/s)     (cm)    (cm)    (cm)',
     $  1X,'   (%)      km2)',
     $ /6X,'---------- ---------- ---------- ------- ------- -------',
     $  '  ----- ----------')
 2150 FORMAT (A5,3F11.2,3F8.3,F7.2,F11.3)
 2155 FORMAT (A5,3F11.2,3F8.3,F7.2,F11.7)
 2200 FORMAT (/'Monthly Summary'/15('-'))
 2205 FORMAT (10X, 12(5X,A5) / 12X, 12(1X, 9('-')))
 2210 FORMAT ('Mean Q, cfs',12(F10.2))
 2215 FORMAT ('Mean Q, cms',12(F10.2))
 2220 FORMAT ('Mean BF, cfs',F9.2,11(F10.2))
 2225 FORMAT ('Mean BF, cms',F9.2,11(F10.2))
 2230 FORMAT ('Mean DR, cfs',F9.2,11(F10.2))
 2235 FORMAT ('Mean DR, cms',F9.2,11(F10.2))
 2240 FORMAT ('Total Q, in ',12(F10.3))
 2245 FORMAT ('Total Q, cm ',12(F10.3))
 2250 FORMAT ('Total BF, in',12(F10.3))
 2255 FORMAT ('Total BF, cm',12(F10.3))
 2260 FORMAT ('Total DR, in',12(F10.3))
 2265 FORMAT ('Total DR, cm',12(F10.3))
 2270 FORMAT ('% as BF    ',12(F10.2))
 2280 FORMAT ('BF, mgd/mi2 ',12(F10.3)//)
 2285 FORMAT ('BF, mgd     ',12(F10.3)//)
 2290 FORMAT ('BF, cfs/mi2 ',12(F10.3)//)
 2295 FORMAT ('BF, cmd/km2 ',12(F10.3)//)
C
C     + + + END SPECIFICATIONS + + +
C
C     definitions
C     MNTH(12,8) - statistics arrays
C     TOTALQ - monthly stream discharge
C     TOTLGW - monthly GW discharge
C     RECH   - GW discharge

C     initialize variables
      NULFLG = 0
      ANNLQ = 0.0
      ANNLGW = 0.0
      DO 20 I = 1,12
        DO 10 J = 1,8
          MNTH(I,J) = 0.0
 10     CONTINUE
 20   CONTINUE
C
      IF (NPFLAG .NE. 0) THEN 
C       write table heading
        WRITE (OTUNIT, 2000)
        WRITE (OTUNIT, 2010) METHOD(METH)
        IF (UNITFG .EQ. 1) THEN
C         English units
          WRITE (OTUNIT, 2020) STA, STAID, DRAIN
        ELSE IF (UNITFG .EQ. 2) THEN
C         metric units
          WRITE (OTUNIT, 2025) STA, STAID, DRAIN
        END IF
        WRITE (OTUNIT, 2000)
        WRITE (OTUNIT,2030) IWY, INTRVL
      END IF
C
C     fill CC w/ names of months, beginning with STMNTH
      IF (STMNTH .EQ. 1) THEN
        DO 25 I = 1,12
          CC(I) = MC(I)
 25     CONTINUE
      ELSE
        DO 30 I = 1,12
          M = I + (STMNTH-1)
          IF (M .GT. 12) M = M - 12
          CC(I) = MC(M)
 30     CONTINUE
      END IF
C
      K = 0
      DO 70 I = 1,12
        M = I + (STMNTH-1)
        IF (M .GT. 12) M = M - 12
C       get days per month
        YR = IWY
        IF (STMNTH.GT.1 .AND. M.GE.STMNTH)  YR = YR - 1
        DPM = DAYMON (YR,M)
        RDPM = REAL(DPM)
        SFNULL = 0
        BFNULL = 0
        TOTALQ = 0.0
        TOTLGW = 0.0
        DO 50 J = 1,DPM
          K = K + 1
          IF (DIS(K).LT.0 .OR. GDIS(K).LT.0)  NULFLG = 1
C
          IF (DIS(K) .LT. 0) THEN
            SFNULL = 1
          ELSE
            TOTALQ = TOTALQ + DIS(K)
          END IF
C
          IF (GDIS(K) .LT. 0) THEN
            BFNULL = 1
          ELSE
            TOTLGW = TOTLGW + GDIS(K)
          END IF
 50     CONTINUE
C
        IF (SFNULL .EQ. 0) THEN
C         no missing streamflow values--proceed w/ calculations
          MNTH(I,1) = TOTALQ/RDPM
          IF (UNITFG .EQ. 1) THEN
C           calculate streamflow in inches
            MNTH(I,4) = 0.03719*TOTALQ/DRAIN
          ELSE IF (UNITFG .EQ. 2) THEN
C           calculate streamflow in centimeters
            MNTH(I,4) = 8.64*TOTALQ/DRAIN
          END IF
          ANNLQ = ANNLQ + TOTALQ
          MNTFL(I) = MNTFL(I) + TOTALQ
          MNCNT(I) = MNCNT(I) + 1
        ELSE
          MNTH(I,1) = -1.0
          MNTH(I,4) = -1.0
        END IF
C
        IF (BFNULL .EQ. 0) THEN
C         no missing base flow values--proceed w/ calculations
          MNTH(I,2) = TOTLGW/RDPM
          IF (UNITFG .EQ. 1) THEN
C           calculate base flow in inches and...
            MNTH(I,5) = 0.03719*TOTLGW/DRAIN
            IF (ENGOPT .EQ. 1) THEN
C             Mgal/d/mi2
              MNTH(I,8) = (0.6462/RDPM)*TOTLGW/DRAIN
            ELSE IF (ENGOPT .EQ. 2) THEN
C             Mgal/d
              MNTH(I,8) = (0.6462/RDPM)*TOTLGW
            ELSE IF (ENGOPT .EQ. 3) THEN
C             ft3/s/mi2
              MNTH(I,8) = (TOTLGW/RDPM)/DRAIN
            END IF
          ELSE IF (UNITFG .EQ. 2) THEN
C           calculate base flow in centimeters and m3/s/km2
            MNTH(I,5) = 8.64*TOTLGW/DRAIN
            MNTH(I,8) = (TOTLGW/RDPM)/DRAIN
          END IF
C
          IF (TOTALQ .GT. 0.0) THEN
            MNTH(I,7) = 100.0*TOTLGW/TOTALQ
          ELSE
            MNTH(I,7) = 0.0
          END IF

          MNTH(I,3) = MNTH(I,1) - MNTH(I,2)
          MNTH(I,6) = MNTH(I,4) - MNTH(I,5)
C
          ANNLGW = ANNLGW + TOTLGW
          MNTBF(I) = MNTBF(I) + TOTLGW
        ELSE
          MNTH(I,2) = -1.0
          MNTH(I,3) = -1.0
          DO 60 L = 5, 8
            MNTH(I,L) = -1.0
 60       CONTINUE
        END IF
 70   CONTINUE
C
C     load annual streamflow and base-flow arrays
      IF (NULFLG .EQ. 0) THEN
        AQW(IREC) = ANNLQ
        ABFW(IREC) = ANNLGW
      ELSE
        AQW(IREC) = -1.0
        ABFW(IREC) = -1.0
      END IF
C
      IF (NPFLAG .EQ. 1) THEN
C       print 80-column output
        IF (UNITFG .EQ. 1) THEN
C         English units
          IF (ENGOPT .EQ. 1) THEN
C           base flow is in Mgal/d/mi2
            WRITE (OTUNIT,2100)
          ELSE IF (ENGOPT .EQ. 2) THEN
C           base flow is in Mgal/d
            WRITE (OTUNIT,2110)
          ELSE IF (ENGOPT .EQ. 3) THEN
C           base flow is in ft3/s/mi2
            WRITE (OTUNIT,2120)
          END IF
          WRITE (OTUNIT,2150) (CC(I),(MNTH(I,J),J=1,8),I=1,12)
        ELSE IF (UNITFG .EQ. 2) THEN
C         metric units
          WRITE (OTUNIT,2130)
          WRITE (OTUNIT,2155) (CC(I),(MNTH(I,J),J=1,8),I=1,12)
        END IF
Cmyg  ELSE IF (NPFLAG.EQ.2) THEN
C       print 132-column output
Cmyg    WRITE (OTUNIT,2200)
Cmyg    WRITE (OTUNIT,2205) (CC(I), I=1,12)
Cmyg    IF (UNITFG .EQ. 1) THEN
C         English units
Cmyg      WRITE (OTUNIT,2210) (MNTH(I,1),I=1,12)
Cmyg      WRITE (OTUNIT,2220) (MNTH(I,2),I=1,12)
Cmyg      WRITE (OTUNIT,2230) (MNTH(I,3),I=1,12)
Cmyg      WRITE (OTUNIT,2240) (MNTH(I,4),I=1,12)
Cmyg      WRITE (OTUNIT,2250) (MNTH(I,5),I=1,12)
Cmyg      WRITE (OTUNIT,2260) (MNTH(I,6),I=1,12)
Cmyg      WRITE (OTUNIT,2270) (MNTH(I,7),I=1,12)
Cmyg      IF (ENGOPT .EQ. 1) THEN
C           base flow is in mgd/mi2
Cmyg        WRITE (OTUNIT,2280) (MNTH(I,8),I=1,12)
Cmyg      ELSE IF (ENGOPT .EQ. 2) THEN
C           base flow is in mgd
Cmyg        WRITE (OTUNIT,2285) (MNTH(I,8),I=1,12)
Cmyg      ELSE IF (ENGOPT .EQ. 3) THEN
C           base flow is in cfs/mi2
Cmyg        WRITE (OTUNIT,2290) (MNTH(I,8),I=1,12)
Cmyg      END IF
Cmyg    ELSE IF (UNITFG .EQ. 2) THEN
C         metric units
Cmyg      WRITE (OTUNIT,2215) (MNTH(I,1),I=1,12)
Cmyg      WRITE (OTUNIT,2225) (MNTH(I,2),I=1,12)
Cmyg      WRITE (OTUNIT,2235) (MNTH(I,3),I=1,12)
Cmyg      WRITE (OTUNIT,2245) (MNTH(I,4),I=1,12)
Cmyg      WRITE (OTUNIT,2255) (MNTH(I,5),I=1,12)
Cmyg      WRITE (OTUNIT,2265) (MNTH(I,6),I=1,12)
Cmyg      WRITE (OTUNIT,2270) (MNTH(I,7),I=1,12)
Cmyg      WRITE (OTUNIT,2295) (MNTH(I,8),I=1,12)
Cmyg    END IF
      END IF
C
      RETURN
      END
C
C
C
      SUBROUTINE   STAT
     I                 (OTUNIT, NPFLAG, NDAYS, UNITFG, 
     I                  ENGOPT, DRAIN)
C
C     + + + PURPOSE + + +
C     Calculate and print out summary information about
C     the hydrograph separation.
C     Adapted from Pettyjohn and Henning (1979)
C     by R. A. Sloto
C     04/25/88   4.0
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   OTUNIT, NPFLAG, NDAYS, UNITFG, ENGOPT
      REAL      DRAIN
C
C     + + + ARGUMENT DEFINITIONS + + +
C     OTUNIT - Fortran unit number of output file
C     NPFLAG - short/long printout flag
C                = 1 - 80 column output
C                = 2 - 132 column output
C     NDAYS  - number of days in the year
C     UNITFG - print file units
C              1 - english
C              2 - metric
C     ENGOPT - units for base flow in predefined columns of print file
C              1 - Mgal/d/mi2
C              2 - Mgal/d
C              3 - ft3/s/mi2
C     DRAIN  - drainage area
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'chysep.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER   I, GDAYS
      REAL      LMIN, LMAX, PERCEN, RECHM, TOQUAN, TOQUGW, TOTDIS,
     $          TOTGW, TOTGWD, TOTQDP, TOTUDR, TOTDRD
C
C     + + + LOCAL DEFINITIONS + + +
C     LMIN   - minimum Q
C     LMAX   - maximum Q
C     TOQUAN - mean Q
C     TOQUGW - mean base flow
C     TOTUDR - mean surface runoff
C     TOTGWD - total base-flow depth
C     TOTQDP - total Q depth
C     TOTDRD - total surface runoff depth
C     PERCEN - % of Q that is base flow
C     RECHM  - recharge rate
C
C     + + + INTRINSICS + + +
      INTRINSIC   REAL
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT (5X,3(1X,10('-')),3(1X,7('-')),2X,5('-'),1X,10('-')
     $       /5X,3F11.2,3F8.3,F7.2,F11.3//)
 2005 FORMAT (5X,3(1X,10('-')),3(1X,7('-')),2X,5('-'),1X,10('-')
     $       /5X,3F11.2,3F8.3,F7.2,F11.7//)
 2100 FORMAT ('Summary information on the hydrograph separation'/
     $        48('-'))
 2110 FORMAT ('Mean streamflow for the year            ',F10.2,1X,
     $        'cfs  ',F7.2,' inches')
 2115 FORMAT ('Mean streamflow for the year            ',F10.2,1X,
     $        'cms  ',F7.2,' cm')
 2120 FORMAT ('Mean base flow for the year             ',F10.2,1X,
     $        'cfs  ',F7.2,' inches')
 2125 FORMAT ('Mean base flow for the year             ',F10.2,1X,
     $        'cms  ',F7.2,' cm')
 2130 FORMAT ('Mean surface runoff for the year        ',F10.2,1X,
     $        'cfs  ',F7.2,' inches')
 2135 FORMAT ('Mean surface runoff for the year        ',F10.2,1X,
     $        'cms  ',F7.2,' cm')
 2140 FORMAT ('% of total streamflow due to base flow  ',F10.2)
 2150 FORMAT ('Mean base flow for the year',14X,F10.3,' mgd/mi2'//)
 2155 FORMAT ('Mean base flow for the year',14X,F10.3,' mgd'//)
 2160 FORMAT ('Mean base flow for the year',14X,F10.3,' cfs/mi2'//)
 2165 FORMAT ('Mean base flow for the year',14X,F10.3,' cmd/km2'//)
 2200 FORMAT ('Above summary information based on',I4,' day of good ',
     $        'base-flow values.')
 2210 FORMAT ('Above summary information based on',I4,' days of good ',
     $        'base-flow values.')
C
C     + + + END SPECIFICATIONS + + +
C
C     initialize variables
      LMIN = 100000.
      LMAX = 0.0
      TOTDIS = 0.0
      TOTGW = 0.0
      GDAYS = 0
C
C     calculate and sum statistics
      DO 10 I = 1, NDAYS
        IF (DIS(I).GE.0.0 .AND. GDIS(I).GE.0.0) THEN
          GDAYS = GDAYS + 1
          TOTDIS = TOTDIS+DIS(I)
          TOTGW = TOTGW+GDIS(I)
          IF(DIS(I).LT.LMIN) LMIN = DIS(I)
          IF(DIS(I).GT.LMAX) LMAX = DIS(I)
        END IF
 10   CONTINUE
C
      IF (GDAYS .GT. 0) THEN
        TOQUAN = TOTDIS/REAL(GDAYS)
        TOQUGW = TOTGW/REAL(GDAYS)
        IF (UNITFG .EQ. 1) THEN
C         English units
          TOTQDP = 0.03719*(TOTDIS/DRAIN)
          TOTGWD = 0.03719*(TOTGW/DRAIN)
          IF (ENGOPT .EQ. 1) THEN
C           calculate recharge rate in Mgal/d/mi2
            RECHM = (.6462*TOTGW/GDAYS)/DRAIN
          ELSE IF (ENGOPT .EQ. 2) THEN
C           calculate recharge rate in Mgal/d
            RECHM = .6462*TOTGW/GDAYS
          ELSE IF (ENGOPT .EQ. 3) THEN
C           calculate recharge rate in ft3/s/mi2
            RECHM = (TOTGW/GDAYS)/DRAIN
          END IF
        ELSE IF (UNITFG .EQ. 2) THEN
C         metric units
          TOTQDP = 8.64*(TOTDIS/DRAIN)
          TOTGWD = 8.64*(TOTGW/DRAIN)
          RECHM = (TOTGW/GDAYS)/DRAIN
        END IF
        PERCEN = (TOQUGW/TOQUAN)*100.
        TOTUDR = TOQUAN - TOQUGW
        TOTDRD = TOTQDP - TOTGWD
      ELSE
        TOQUAN = -1.0
        TOQUGW = -1.0
        TOTUDR = -1.0
        TOTQDP = -1.0
        TOTGWD = -1.0
        TOTDRD = -1.0
        PERCEN = -1.0
        RECHM = -1.0
      END IF
C
C     print results
Cmyg  IF (NPFLAG .EQ. 1) THEN
C       print 80-column output
        IF (UNITFG .EQ. 1) THEN
          WRITE(OTUNIT,2000) TOQUAN,TOQUGW,TOTUDR,
     $                       TOTQDP,TOTGWD,TOTDRD,PERCEN,RECHM
        ELSE IF (UNITFG .EQ. 2) THEN
          WRITE(OTUNIT,2005) TOQUAN,TOQUGW,TOTUDR,
     $                       TOTQDP,TOTGWD,TOTDRD,PERCEN,RECHM
        END IF
Cmyg  ELSE IF (NPFLAG. EQ. 2) THEN
C       print 132-column output
Cmyg    WRITE (OTUNIT,2100)
Cmyg    IF (UNITFG .EQ. 1) THEN
C         English units
Cmyg      WRITE (OTUNIT,2110) TOQUAN,TOTQDP
Cmyg      WRITE (OTUNIT,2120) TOQUGW,TOTGWD
Cmyg      WRITE (OTUNIT,2130) TOTUDR,TOTDRD
Cmyg      WRITE (OTUNIT,2140) PERCEN
Cmyg      IF (ENGOPT .EQ. 1) THEN
C           recharge rate is in mgd/mi2
Cmyg        WRITE (OTUNIT,2150) RECHM
Cmyg      ELSE IF (ENGOPT .EQ. 2) THEN
C           recharge rate is in mgd
Cmyg        WRITE (OTUNIT,2155) RECHM
Cmyg      ELSE IF (ENGOPT .EQ. 3) THEN
C           recharge rate is in cfs/mi2
Cmyg        WRITE (OTUNIT,2160) RECHM
Cmyg      END IF
Cmyg    ELSE IF (UNITFG .EQ. 2) THEN
C         metric units
Cmyg      WRITE (OTUNIT,2115) TOQUAN,TOTQDP
Cmyg      WRITE (OTUNIT,2125) TOQUGW,TOTGWD
Cmyg      WRITE (OTUNIT,2135) TOTUDR,TOTDRD
Cmyg      WRITE (OTUNIT,2140) PERCEN
Cmyg      WRITE (OTUNIT,2165) RECHM
Cmyg    END IF
Cmyg  END IF
C
      IF (GDAYS .LT. NDAYS) THEN
        IF (GDAYS .EQ. 1) THEN
          WRITE (OTUNIT,2200) GDAYS
        ELSE
          WRITE (OTUNIT,2210) GDAYS
        END IF
      END IF
C
      RETURN
      END
C
C
C
      SUBROUTINE   ANNUAL
     I                  (OTUNIT, FRQPRT, SEAPRT, MXSIZE, ABFW, AQW, 
     I                   UNITFG, ENGOPT, DRAIN, IREC, IWR, STA, STAID, 
     I                   STMON, ENDMON, METH, MNCNT, MNTFL, MNTBF,
     O                   FREQ, SRTQ, SRTBF, SRTDR, GIREC)
C
C     + + + PURPOSE + + +
C     This subroutine calculates and prints a summary of the hydrograph
C     separation on an annual basis.
C     written by R. A. Sloto
C     04/13/88   5.5
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   OTUNIT, FRQPRT, SEAPRT, MXSIZE, UNITFG, ENGOPT, IREC, 
     $          IWR(MXSIZE), STMON, ENDMON, METH, MNCNT(12), GIREC
      REAL      ABFW(MXSIZE), AQW(MXSIZE), DRAIN, MNTFL(12), 
     $          MNTBF(12), FREQ(MXSIZE), SRTQ(MXSIZE), SRTBF(MXSIZE), 
     $          SRTDR(MXSIZE)
      CHARACTER*48 STA
      CHARACTER*8  STAID
C
C     + + + ARGUMENT DEFINITIONS + + +
C     OTUNIT - Fortran unit number of output file
C     FRQPRT - frequency distribution table flag
C              0 - don't print
C              1 - print it
C     SEAPRT - seasonal distribution table flag
C              0 - don't print
C              1 - print it
C     MXSIZE - maximum no. of years that can be processed at any one time
C     ABFW   - array of total annual base flow 
C     AQW    - array of total annual streamflow 
C     UNITFG - print file units
C              1 - english
C              2 - metric
C     ENGOPT - units for recharge rate
C              1 - Mgal/d/mi2
C              2 - Mgal/d
C              3 - ft3/s/mi2
C     DRAIN  - drainage area
C     IREC   - total yr.s in pd specified by user (includes partial yr.s
C              consisting of data outside start and end mo.s of summary yr)
C     IWR    - array of years in period specified by user
C     STA    - station name
C     STAID  - station id
C     STMON  - starting month of summary year specified by user
C     ENDMON - ending month of summary year specified by user
C     METH   - separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     MNCNT  - count of days of flow for each month
C     MNTFL  - total flow for each month
C     MNTBF  - total base flow for each month
C     FREQ   - frequency distribution of annual flows
C     SRTQ   - streamflow depth sorted by frequency
C     SRTBF  - base flow depth sorted by frequency
C     SRTDR  - surface runoff depth sorted by frequency
C     GIREC  - no. of complete years of data not having missing values
C
C     + + + PARAMETERS + + +
      INCLUDE 'pmxyrs.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER   I, J, K, NUM, START(6), END(6), ADJUST, TU, TS, 
     $          NDAYS, MIDDLE, MIDVAL, MIDPRC, NXTONE, NXT, NXTPRC, OPT,
     $          SRTVAL, NUMBAD, SQPOS(MXYRS), SBFPOS(MXYRS), 
     $          SDRPOS(MXYRS), SPRPOS(MXYRS), VAL, MON
      REAL      RATE(MXYRS), RECHRG(MXYRS), PERCEN(MXYRS), ADRW(MXYRS),
     $          QDPTH(MXYRS), BFDPTH(MXYRS), DRDPTH(MXYRS), MRATE, 
     $          MDEPTH, MRECHR, MPRCEN, XI, XNUM, ZERO, RDAYS, FACTOR,
     $          MNTSR
      CHARACTER*1  ISTA(48), FF
      CHARACTER*9  CMON(12)
      CHARACTER*23 TITL(3)
      CHARACTER*65 ERRMSG(3)
C
C     + + + LOCAL DEFINITIONS + + +
C     BFDPTH - base-flow depth
C     RATE   - mean base-flow rate
C     RECHRG - recharge
C     PERCEN - % base flow
C     MDEPTH - median base flow depth
C     MRATE  - median base flow rate
C     MRECHR - median recharge
C     MPRCEN - median base flow percentage
C
C     + + + FUNCTIONS + + +
      INTEGER   DAYMON
C
C     + + + INTRINSICS + + +
      INTRINSIC   REAL, MOD, CHAR
C
C     + + + EXTERNALS + + +
      EXTERNAL   CTRSTR, CVARAR, DAYMON, TIMDIF, ASRTR, ZIPR
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  TITL/' Fixed interval method ',
     $           'Sliding interval method',
     $           ' Local minimum method  '/
      DATA  CMON/'January  ','February ','March    ','April    ',
     $           'May      ','June     ','July     ','August   ',
     $           'September','October  ','November ','December '/
      DATA  START/0,0,1,0,0,0/, END/0,0,0,24,0,0/
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT (A1)
 2010 FORMAT (56('-')/16X,'Annual base-flow summary'//
     $        4X,48A1/17X,'Station ID = ',A8)
 2020 FORMAT (56('-')/5X,'Annual base-flow summary ordered by ',
     $        'frequency'//48A1/17X,'Station ID = ',A8)
 2025 FORMAT (56('-')/17X,'Seasonal-distribution table '//
     $        48A1/17X,'Station ID = ',A8)
 2030 FORMAT (14X,'Drainage area = ',F10.2,' square miles'//
     $        16X,A23/56('-'))
 2035 FORMAT (14X,'Drainage area = ',F10.2,' square kilometers'//
     $        16X,A23/56('-'))
 2040 FORMAT (17X,'Year starts in ',A9/17X,'Year ends in ',A9/)
 2050 FORMAT (56('-'))
 2100 FORMAT (3X,'                                             % of'
     $       /3X,'Period                            Mgal/d/   stream-'
     $       /3X,'ending      in        ft3/s         mi2      flow')
 2105 FORMAT (3X,'                                             % of'
     $       /3X,'Period                                      stream-'
     $       /3X,'ending      in        ft3/s       Mgal/d     flow')
 2110 FORMAT (3X,'                                             % of'
     $       /3X,'Period                            ft3/s/    stream-'
     $       /3X,'ending      in        ft3/s        mi2       flow')
 2115 FORMAT (3X,'                                             % of'
     $       /3X,'Period                             m3/s/    stream-'
     $       /3X,'ending      cm        m3/s          km2      flow')
 2120 FORMAT (3X,'         -------   ----------   ----------   -----')
 2130 FORMAT (4X,I4,4X,F7.3,3X,F10.2,3X,F10.3,3X,F5.2)
 2135 FORMAT (4X,I4,4X,F7.3,3X,F10.2,3X,F10.7,3X,F5.2)
 2140 FORMAT (3X,'median',3X,F7.3,3X,F10.2,3X,F10.3,3X,F5.2/56('-'))
 2200 FORMAT (10X,'Cum                Mgal/d/'
     $       /10X,'dist      in         mi2      year')
 2205 FORMAT (10X,'Cum'
     $       /10X,'dist      in       Mgal/d     year')
 2210 FORMAT (10X,'Cum                ft3/s/'
     $       /10X,'dist      in        mi2       year')
 2215 FORMAT (10X,'Cum                 m3/d/'
     $       /10X,'dist      cm         km2      year')
 2220 FORMAT (10X,'----   -------   ----------   ----')
 2230 FORMAT (10X,F4.1,3X,F7.3,3X,F10.3,3X,I4)
 2235 FORMAT (10X,F4.1,3X,F7.3,3X,F10.7,3X,I4)
 2300 FORMAT (11X,'              Base flow     Runoff'
     $       /11X,'Month           (in)         (in)')
 2305 FORMAT (11X,'              Base flow     Runoff'
     $       /11X,'Month           (cm)         (cm)')
 2320 FORMAT (11X,'---------     ---------     ------')
 2330 FORMAT (11X,A9,7X,F6.3,6X,F6.3)
 2400 FORMAT (//A7)
 2410 FORMAT (5X,A65)
C
C     + + + END SPECIFICATIONS + + +
C
C     initialize variables
      ZERO = 0.0
      CALL ZIPR (MXSIZE, ZERO, QDPTH)
      CALL ZIPR (MXSIZE, ZERO, BFDPTH)
      CALL ZIPR (MXSIZE, ZERO, DRDPTH)
      CALL ZIPR (MXSIZE, ZERO, RATE)
      CALL ZIPR (MXSIZE, ZERO, RECHRG)
      CALL ZIPR (MXSIZE, ZERO, PERCEN)
      CALL ZIPR (MXSIZE, ZERO, SRTQ)
      CALL ZIPR (MXSIZE, ZERO, SRTBF)
      CALL ZIPR (MXSIZE, ZERO, SRTDR)
      CALL ZIPR (MXSIZE, ZERO, FREQ)
      MDEPTH = 0.0
      MRATE = 0.0
      MRECHR = 0.0
      MPRCEN = 0.0
C     set error message for insufficient good years of data 
      ERRMSG(1) = 'Insufficent complete years of data to produce '//
     $            'annual summary.'
      ERRMSG(2) = 'Any summary output selected--such as the '//
     $            'frequency distribution '
      ERRMSG(3) = 'or flow duration tables or plots--will '//
     $            'not be produced.'
C
C     set start/end months
      START(2) = STMON
      END(2) = ENDMON
C     set flag for when starting month is in previous year
      ADJUST = 0
      IF (ENDMON .LT. STMON)  ADJUST = 1
C
C     calculate annual statistics
      DO 10 I=1,IREC
        IF (ABFW(I) .GT. 0) THEN
C         determine number of days in user-defined summary year
          START(1) = IWR(I) - ADJUST
          END(1) = IWR(I)
          END(3) = DAYMON (END(1), END(2))
          TU = 4
          TS = 1
          CALL TIMDIF (START, END, TU, TS, NDAYS)
          RDAYS = REAL(NDAYS)
C
          IF (UNITFG .EQ. 1) THEN
C           English units
            QDPTH(I) = 0.03719*(AQW(I)/DRAIN)
            BFDPTH(I) = 0.03719*(ABFW(I)/DRAIN)
            DRDPTH(I) = QDPTH(I) - BFDPTH(I)
C           calculate recharge rate
            IF (ENGOPT .EQ. 1) THEN
C             Mgal/d/mi2
              RECHRG(I) = (.6462*ABFW(I)/RDAYS)/DRAIN
            ELSE IF (ENGOPT .EQ. 2) THEN
C             Mgal/d
              RECHRG(I) = .6462*ABFW(I)/RDAYS
            ELSE IF (ENGOPT .EQ. 3) THEN
C             ft3/s/mi2
              RECHRG(I) = (ABFW(I)/RDAYS)/DRAIN
            END IF
          ELSE IF (UNITFG .EQ. 2) THEN
C           metric units
            QDPTH(I) = 8.64*(AQW(I)/DRAIN)
            BFDPTH(I) = 8.64*(ABFW(I)/DRAIN)
            DRDPTH(I) = QDPTH(I) - BFDPTH(I)
            RECHRG(I) = (ABFW(I)/RDAYS)/DRAIN
          END IF
          RATE(I) = ABFW(I)/RDAYS
        ELSE
          QDPTH(I) = -1.0
          BFDPTH(I) = -1.0
          DRDPTH(I) = -1.0
          RATE(I) = -1.0
          RECHRG(I) = -1.0
        END IF
        IF (AQW(I) .GT. 0.0) THEN
C         note:  ABFW(I) and AQW(I) will either both be good or be null
          PERCEN(I) = (ABFW(I)/AQW(I)) * 100.0
          ADRW(I) = AQW(I) - ABFW(I)
        ELSE
          PERCEN(I) = -1.0
          ADRW(I) = -1.0
        END IF
 10   CONTINUE
C
C     sort annual base flow, percent base flow
      OPT = 0
      CALL ASRTR (OPT, IREC, AQW, SQPOS)
      CALL ASRTR (OPT, IREC, ABFW, SBFPOS)
      CALL ASRTR (OPT, IREC, ADRW, SDRPOS)
      CALL ASRTR (OPT, IREC, PERCEN, SPRPOS)
C
C     determine no. of good years of data
      GIREC = IREC
      DO 20 I = 1, IREC
        IF (ABFW(I) .LT. 0)  GIREC = GIREC - 1
 20   CONTINUE
      NUMBAD = IREC - GIREC
C
      IF (GIREC .GE. 1) THEN
C       calculate annual frequency distribution
        NUM = GIREC+1
        XNUM = REAL(NUM)
        XI = 1.0
        DO 30 I = 1,IREC
          VAL = SBFPOS(I)
          IF (ABFW(VAL) .LT. 0) THEN
            FREQ(I) = -1.0
          ELSE
            FREQ(I) = (XI/XNUM)*100.0
            XI = XI + 1.0
          END IF
 30     CONTINUE
C
C       store streamflow, base flow, and surface runoff in sorted order
        DO 40 I=1,IREC
          J = SQPOS(I)
          IF (AQW(J) .GT. 0) THEN
            SRTQ(I) = QDPTH(J)
          ELSE
            SRTQ(I) = -1.0
          END IF
C
          J = SBFPOS(I)
          IF (ABFW(J) .GT. 0) THEN
            SRTBF(I) = BFDPTH(J)
          ELSE
            SRTBF(I) = -1.0
          END IF
C
          J = SDRPOS(I)
          IF (ADRW(J) .GT. 0) THEN
            SRTDR(I) = DRDPTH(J)
          ELSE
            SRTDR(I) = -1.0
          END IF
 40     CONTINUE
C
C       calculate annual medians
C       bad years of data (indicated by -1.0) will have been sorted to the
C       beginning of the array SBFPOS--skip over bad years in determining
C       median value  [note:  the pos. of the median base flow value w/in ABFW
C                             will be stored in SBFPOS(MIDDLE) ]
        K = GIREC + 1
        MIDDLE = NUMBAD + K/2
        MIDVAL = SBFPOS(MIDDLE)
        MIDPRC = SPRPOS(MIDDLE)
        IF (MOD(K,2) .EQ. 0) THEN
C         odd number of years
          MDEPTH = BFDPTH(MIDVAL)
          MRATE = RATE(MIDVAL)
          MRECHR = RECHRG(MIDVAL)
          MPRCEN = PERCEN(MIDPRC)
        ELSE
C         even number of years
          NXT = MIDDLE + 1
          NXTONE = SBFPOS(NXT)
          NXTPRC = SPRPOS(NXT)
          MDEPTH = (BFDPTH(MIDVAL) + BFDPTH(NXTONE))/2.0
          MRATE = (RATE(MIDVAL) + RATE(NXTONE))/2.0
          MRECHR = (RECHRG(MIDVAL) + RECHRG(NXTONE))/2.0
          MPRCEN = (PERCEN(MIDPRC) + PERCEN(NXTPRC))/2.0
        END IF
C
C       print base-flow summary by year
C       output laser printer form-feed control character
        FF = CHAR(12)
        WRITE (OTUNIT,2000) FF
        I = 48
        CALL CVARAR (I,STA,I,ISTA)
C       center the text
        CALL CTRSTR (I,ISTA)
        WRITE (OTUNIT,2010) ISTA, STAID
        IF (UNITFG .EQ. 1) THEN
C         English units
          WRITE (OTUNIT,2030) DRAIN, TITL(METH)
        ELSE IF (UNITFG .EQ. 2) THEN
C         metric units
          WRITE (OTUNIT,2035) DRAIN, TITL(METH)
        END IF
        WRITE (OTUNIT,2040) CMON(STMON), CMON(ENDMON)
        IF (UNITFG .EQ. 1) THEN
C         English units
          IF (ENGOPT .EQ. 1) THEN
C           recharge rate is in Mgal/d/mi2
            WRITE (OTUNIT,2100)
          ELSE IF (ENGOPT .EQ. 2) THEN
C           recharge rate is in Mgal/d
            WRITE (OTUNIT,2105)
          ELSE IF (ENGOPT .EQ. 3) THEN
C           recharge rate is in ft3/s/mi2
            WRITE (OTUNIT,2110)
          END IF
        ELSE IF (UNITFG .EQ. 2) THEN
C         metric units
          WRITE (OTUNIT,2115)
        END IF
        WRITE (OTUNIT,2120)
        DO 50 I = 1,IREC
          IF (UNITFG .EQ. 1) THEN
            WRITE (OTUNIT,2130) IWR(I), BFDPTH(I), RATE(I), RECHRG(I), 
     $                          PERCEN(I)
          ELSE
            WRITE (OTUNIT,2135) IWR(I), BFDPTH(I), RATE(I), RECHRG(I), 
     $                          PERCEN(I)
          END IF
 50     CONTINUE
        WRITE (OTUNIT,2120)
        WRITE (OTUNIT,2140) MDEPTH, MRATE, MRECHR, MPRCEN
C
        IF (FRQPRT.EQ.1 .AND. IREC.GE.3) THEN
C         print base-flow summary ordered by frequency
          WRITE (OTUNIT,2000) FF
          WRITE (OTUNIT,2020) ISTA, STAID
          IF (UNITFG .EQ. 1) THEN
C           English units
            WRITE (OTUNIT,2030) DRAIN, TITL(METH)
          ELSE IF (UNITFG .EQ. 2) THEN
C           metric units
            WRITE (OTUNIT,2035) DRAIN, TITL(METH)
          END IF
          WRITE (OTUNIT,2040) CMON(STMON), CMON(ENDMON)
          IF (UNITFG .EQ. 1) THEN
C           English units
            IF (ENGOPT .EQ. 1) THEN
C             recharge rate is in Mgal/d/mi2
              WRITE (OTUNIT,2200)
            ELSE IF (ENGOPT .EQ. 2) THEN
C             recharge rate is in Mgal/d
              WRITE (OTUNIT,2205)
            ELSE IF (ENGOPT .EQ. 3) THEN
C             recharge rate is in ft3/s/mi2
              WRITE (OTUNIT,2210)
            END IF
          ELSE IF (UNITFG .EQ. 2) THEN
C           metric units
            WRITE (OTUNIT,2215)
          END IF
          WRITE (OTUNIT,2220)
          DO 60 I = 1,IREC
            SRTVAL = SBFPOS(I)
            IF (UNITFG .EQ. 1) THEN
              WRITE (OTUNIT,2230)
     $          FREQ(I),BFDPTH(SRTVAL),RECHRG(SRTVAL),IWR(SRTVAL)
            ELSE
              WRITE (OTUNIT,2235)
     $          FREQ(I),BFDPTH(SRTVAL),RECHRG(SRTVAL),IWR(SRTVAL)
            END IF
 60       CONTINUE
          WRITE (OTUNIT,2050)
        END IF

        IF (SEAPRT.EQ.1 .AND. IREC.GE.3) THEN
C         print seasonal distribution table of mean monthly BF + runoff
          WRITE (OTUNIT,2000) FF
          WRITE (OTUNIT,2025) ISTA, STAID
          IF (UNITFG .EQ. 1) THEN
C           English units
            WRITE (OTUNIT,2030) DRAIN, TITL(METH)
            FACTOR = 0.03719
          ELSE IF (UNITFG .EQ. 2) THEN
C           metric units
            WRITE (OTUNIT,2035) DRAIN, TITL(METH)
            FACTOR = 8.64
          END IF
          WRITE (OTUNIT,2040) CMON(STMON), CMON(ENDMON)
          IF (UNITFG .EQ. 1) THEN
            WRITE (OTUNIT,2300)
          ELSE IF (UNITFG .EQ. 2) THEN
C           metric units
            WRITE (OTUNIT,2305)
          END IF
          WRITE (OTUNIT,2320)
          MON = STMON
          DO 70 I = 1,12
C           compute total monthly surface runoff
            MNTSR = MNTFL(I) - MNTBF(I)
C           write base flow, surface runoff converted to in/cm
            WRITE (OTUNIT,2330) 
     $          CMON(MON), FACTOR*(MNTBF(I)/MNCNT(I))/DRAIN,
     $          FACTOR*(MNTSR/MNCNT(I))/DRAIN
            MON = MON + 1
            IF (MON .GT. 12) MON = MON - 12
 70       CONTINUE
          WRITE (OTUNIT,2050)
        END IF
      ELSE
C       insufficient years of data to produce annual summary
        WRITE (OTUNIT, 2400) '**NOTE:'
        WRITE (OTUNIT, 2410) (ERRMSG(I), I=1,3)
      END IF
C
      RETURN
      END
