C
C
C
      SUBROUTINE   HYDPLT
     I                   (MESSFL, SCLU, STANAM, METH, BASLEN, BASNAM,
     I                    HYDDEV, MODOPT, MAXP, START, TU, TS, 
     M                    UNITFG, HYD1, HYDCNT,
     O                    INTRPT)
C
C     + + + PURPOSE + + +
C     Makes calls to setup plot parameters and produce hydrograph of
C     total flow and separated baseflow.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      MESSFL, SCLU, METH, BASLEN, HYDDEV(2), MODOPT, MAXP,
     $             START(6), TU, TS, UNITFG, HYDCNT(2:4)
      CHARACTER*1  BASNAM(BASLEN)
      CHARACTER*48 STANAM
      LOGICAL      HYD1, INTRPT
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of message file
C     SCLU   - screen cluster number on message file
C     STANAM - station name/description
C     METH   - separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     BASLEN - length of basename to be included in all output files
C     BASNAM - basename to be included in all output files
C     HYDDEV - array of output devices for hydrograph
C              1 - screen
C              2 - laser or dot matrix printer
C              3 - pen plotter
C              4 - meta file
C     MODOPT - plot parameter modification flag:  0-NO, 1-YES
C     MAXP   - number of points (number of time steps)
C     START  - start of event (yr,mo,dy,hr,mn,sec)
C     TU     - time units (1-sec, 2-min, 3-hour, 4-day....)
C     TS     - time step in TU units
C     UNITFG - flow measurement units
C              1 - english (ft3/s)
C              2 - metric (m3/s)
C     HYD1   - flag indicating if this is the 1st hydrograph 
C              for this execution of the baseflow separation
C     HYDCNT - graphical output file counter--if >1 hydrograph is
C              output to a file, ea. plot will be placed in a separate
C              file w/ HYDCNT(n) appended to the basename given by user
C              HYDCNT(2) - counter for printer output
C              HYDCNT(3) - counter for plotter output
C              HYDCNT(4) - counter for metafile output
C     INTRPT - Boolean flag, indicates if user chose 'Interrupt' command
C              to halt plotting/processing of current data set
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'chysep.inc'
C
C     + + + SAVES + + +
      INTEGER      IVAL(265)
      REAL         RVAL(64)
      CHARACTER*1  CVAL(1400)
      SAVE         IVAL, RVAL, CVAL
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I0, I1, I6, SGRP, IRET, CMDID, INDEX, CMPTYP,
     $             DEVCOD, HYDOUT, IMOD, IC(7), WSID, IWAIT, ICLOS,
     $             RETCOD, WNDFLG
      CHARACTER*2  DATTYP
      CHARACTER*4  ENDING(2:4)
      CHARACTER*8  BWNNAM(2)
      CHARACTER*48 WNDNAM
      LOGICAL      FIRST
C
C     + + + EXTERNALS + + +
      EXTERNAL     GPINIT, GPZIPB, GPDEVC, GPMTFL, GGETVL, GPUTVL
      EXTERNAL     PSTUPW, PLTONE, PDNPLT, PROPLT, DOPLOT
      EXTERNAL     ANPRGT, QRESP, ZSTCMA, ZWNSET, ZGTRET, QFCLOS
      EXTERNAL     ZIPI
      EXTERNAL     HYDSET, HYDDAT, OPNFIL
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  FIRST /.TRUE./
C
C     + + + END SPECIFICATIONS + + +
C
      I0 = 0
      I1 = 1
      I6 = 6
      ENDING(2) = 'ps'
      ENDING(3) = 'hpgl'
      ENDING(4) = 'cgm'
      INTRPT = .FALSE.
      IWAIT = 0
      HYDOUT = 0
C
C     allow 'Intrpt' command
Cmyg  CMDID = 16
Cmyg  CALL ZSTCMA (CMDID, I1)
C
C     if very first time through...
      IF (FIRST) THEN
C       initialize graphics common
        CALL GPINIT
C       set default plot parameters
        CALL HYDSET 
C       get plot parm.s from graphics common blk and put in local arrays
        CALL GGETVL (IVAL, RVAL, CVAL)
      ELSE
C       put saved plot parameters in graphics common block
        CALL GPUTVL (IVAL, RVAL, CVAL)
      END IF
C
C     reinitialize data buffer
      CALL GPZIPB
C     set plot parameters specific to data
      CALL HYDDAT (METH, STANAM, MAXP, START, TU, TS, UNITFG)
C
      DO 20 I = 1, 2
        IF (HYDDEV(I) .NE. 0) THEN
C         get device code from TERM.DAT
          INDEX = 39 + HYDDEV(I)
          CALL ANPRGT (INDEX,
     O                 DEVCOD)
C         set device type and code
          CALL GPDEVC (HYDDEV(I), DEVCOD)
C
C         set workstation IDs, workstation close flags
          IF (HYDDEV(I) .EQ. 1) THEN
            WSID = 2
            ICLOS = 0
          ELSE
            WSID = 1
            ICLOS = 1
          END IF
C
          IF (HYDDEV(I) .NE. 1) THEN
C           chk. computer type--may need to open file for graphical output
            CALL ANPRGT (I1, CMPTYP)
            IF (CMPTYP .EQ. 5) THEN
C             cmptyp=aviion, need to open file
              DATTYP = 'hy'
              CALL OPNFIL (BASLEN, BASNAM, DATTYP, ENDING(HYDDEV(I)),
     M                     HYDCNT(HYDDEV(I)),
     O                     HYDOUT)
C             put unit no. of graphical output file in CPLOT common blk
              CALL GPMTFL (HYDOUT)
            END IF
          END IF
C
          IF (HYDDEV(I).EQ.1 .OR.
     $       (HYDDEV(I).NE.1 .AND. (MODOPT.EQ.0 .OR. .NOT.HYD1))) THEN
C           generate plot if output device is screen or not modifying plot
            CALL PSTUPW (WSID, RETCOD)
            CALL PLTONE
            CALL PDNPLT (WSID, ICLOS, IWAIT)
          END IF
C
          IF (MODOPT.EQ.1 .AND. HYD1) THEN
C           allow user to modify plot
 10         CONTINUE
C             set window name
              WNDNAM = 'Execute (E) hydrograph of annual flows'
              CALL ZWNSET (WNDNAM)
              IF (HYDDEV(I) .EQ. 1) THEN
                SGRP = 63
              ELSE
                SGRP = 64
              END IF
              CALL QRESP (MESSFL, SCLU, SGRP, IMOD)
              IF (HYDDEV(I) .NE. 1) IMOD = IMOD + 1
C
C             get screen exit status code
              CALL ZGTRET (IRET)
              IF (IRET .NE. 7) THEN
                IF (IMOD.EQ.1 .OR. (IMOD.EQ.3.AND.HYDDEV(I).NE.1)) THEN
C                 generate current plot
                  CALL PSTUPW (WSID, RETCOD)
                  CALL PLTONE
                  CALL PDNPLT (WSID, ICLOS, IWAIT)
                ELSE IF (IMOD .EQ. 2) THEN
C                 modify plot; set IC to allow mod. of all plot parm.s but device
                  IC(1) = 2
                  CALL ZIPI (I6, I1, IC(2))
                  BWNNAM(1) = 'Modify'
                  BWNNAM(2) = 'EM'
                  CALL PROPLT (MESSFL, IC, BWNNAM,
     O                         WNDFLG)
                END IF
              ELSE
                INTRPT = .TRUE.
              END IF
            IF (IMOD.NE.3 .AND. (.NOT. INTRPT)) GOTO 10
C
C           retrieve plot parameters as modified by user
            CALL GGETVL (IVAL, RVAL, CVAL)
          END IF
C
          IF (FIRST) FIRST = .FALSE.
          IF (HYD1) HYD1 = .FALSE.
          IF (HYDOUT .NE. 0) THEN
C           output file opened--close it and free up Fortran unit no.
            CALL QFCLOS (HYDOUT, I0)
            HYDOUT = 0
          END IF
C
        END IF
 20   CONTINUE
C
C     turn 'Intrpt' off
Cmyg  CALL ZSTCMA (CMDID, I0)
C
      RETURN
      END
C
C
C
      SUBROUTINE   HYDSET
C
C     + + + PURPOSE + + +
C     Assigns values for plot parameters not dependent on data for 
C     hydrograph of total flow and separated baseflow.
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I1, L4, NUMCRV, NUMVAR, GWCH(2), TICNUM, YTYPE,  
     $             XTYPE, CRVTYP(2), LNTYP(2), GTRANF(2), BVALFG(4)
      REAL         SIZEL, XPAGE, YPAGE, XPHYS, YPHYS, XLEN, YLEN, ALEN
      CHARACTER*20 CLAB(2)
C
C     + + + EXTERNALS + + +
      EXTERNAL     GPNCRV, GPLBVR, GPLBCV, GPATXB, GPBVFG, GPSIZE
      EXTERNAL     GPATYL, GPVWCH, GPTCYL, GPTRAN, GPCTYP, GPLNTY
      EXTERNAL     ZIPI
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  CLAB  /'MEASURED FLOW',
     $             'ESTIMATED BASE FLOW'/
C
C     + + + END SPECIFICATIONS + + +
C
      I1 = 1
      L4 = 4
C
C     set number of variables and curves to 2
      NUMVAR = 2
      NUMCRV = 2
      CALL GPNCRV(NUMCRV, NUMVAR)
C
C     set curve labels
      DO 10 I = 1, NUMCRV
        CALL GPLBCV (I, CLAB(I))
 10   CONTINUE
C
C     set variable labels
      DO 20 I = 1, NUMVAR
        CALL GPLBVR (I, CLAB(I))
 20   CONTINUE
C
C     set axes types (y-axis logarithmic, x-axis time)
      YTYPE = 2
      CALL GPATYL (YTYPE)
      XTYPE = 0
      CALL GPATXB (XTYPE)
C
C     set variables to be plotted on left y-axis
      GWCH(1) = 1
      GWCH(2) = 1
      CALL GPVWCH (I1, NUMVAR, GWCH)
C
C     set tics for left y-axis
      TICNUM = 10
      CALL GPTCYL (TICNUM)
C
C     set transformation type for variables to logarithmic
      GTRANF(1) = 2
      GTRANF(2) = 2
      CALL GPTRAN (I1, NUMVAR, GTRANF)
C
C     set curve types for uniform time step w/ lines
      CRVTYP(1) = 1
      CRVTYP(2) = 1
      CALL GPCTYP (I1, NUMCRV, CRVTYP)
C     set line types: measured flow = dashed, simulated flow = solid
      LNTYP(1) = 2
      LNTYP(2) = 1
      DO 40 I = 1, NUMCRV
        CALL GPLNTY (I, LNTYP(I))
 40   CONTINUE
C
C     set BVALFG to use clip option
      I = 1
      CALL ZIPI (L4, I, BVALFG)
      CALL GPBVFG (BVALFG)
C     set up sizes
      SIZEL = .11
      XPAGE = 10.0
      YPAGE = 8.0
      XPHYS = 1.5
      YPHYS = 1.5
      XLEN = 7.5
      YLEN = 5.0
      ALEN = 0.0
      CALL GPSIZE(SIZEL,XPAGE,YPAGE,XPHYS,YPHYS,XLEN,YLEN,ALEN)
C
      RETURN
      END
C
C
C
      SUBROUTINE   HYDDAT
     I                   (METH, STANAM, MAXP, START, TU, TS, UNITFG)
C
C     + + + PURPOSE + + +
C     Assigns plot parameters specific to data for hydrograph of
C     streamflow and separated baseflow.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      METH, MAXP, START(6), TU, TS, UNITFG
      CHARACTER*48 STANAM
C
C     + + + ARGUMENT DEFINITIONS + + +
C     METH   - separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     STANAM - station name/description
C     MAXP   - number of points (number of time steps)
C     START  - start of event (yr,mo,dy,hr,mn,sec)
C     TU     - time units (1-sec, 2-min, 3-hour, 4-day....)
C     TS     - time step in TU units
C     UNITFG - flow measurement units
C              1 - english (ft3/s)
C              2 - metric (m3/s)
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'chysep.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I0, I1, L18, L23, RETCOD, IPOS, SCLTYP, END(6),
     $             DTYPE(18), TSTEP(18), TUNIT(18), NUMVAR, MTHLEN
      REAL         GVMIN(2), GVMAX(2), YLMIN, YLMAX
      CHARACTER*5  TITLB
      CHARACTER*23 METHOD(3)
      CHARACTER*31 TITLA
      CHARACTER*80 YLAB(2)
      CHARACTER*240 TITL
C
C     + + + FUNCTIONS + + +
      INTEGER      LENSTR
C
C     + + + EXTERNALS + + +
      EXTERNAL     GPDATR, TIMADD, GPTIME, GPVMNX, SCALIT, GPSCYL
      EXTERNAL     GPWCTM, GPLBYL, GPTITL
      EXTERNAL     ZIPI, LENSTR
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  YLAB  /'DISCHARGE, IN CUBIC FEET PER SECOND',
     $             'DISCHARGE, IN CUBIC METERS PER SECOND'/
      DATA  TITLA /'Base flow separation using the '/
      DATA  TITLB /' for&'/
C
C     + + + END SPECIFICATIONS + + +
C
      I0 = 0
      I1 = 1
      L18 = 18
      L23 = 23
      METHOD(1) = 'fixed interval method  '
      METHOD(2) = 'sliding interval method'
      METHOD(3) = 'local minimum method   '
      NUMVAR = 2
C
C     set left y-axis label
      CALL GPLBYL (YLAB(UNITFG))
C
C     set plot title
      DO 30 I = 1, 240
        TITL(I:I) = ' '
 30   CONTINUE
      MTHLEN = LENSTR (L23, METHOD(METH))
      TITL = TITLA // METHOD(METH)(1:MTHLEN) // TITLB // STANAM
      CALL GPTITL (TITL)
C
C     save the streamflow
      I = 1
      IPOS = 1
      CALL GPDATR (I, IPOS, MAXP, DIS, RETCOD)
C     assign the streamflow variable to the 1st curve
      CALL GPWCTM (I, I)
C
C     save the base flow
      I = 2
      IPOS = IPOS + MAXP
      CALL GPDATR (I, IPOS, MAXP, GDIS, RETCOD)
C     assign the base flow variable to the 2nd curve
      CALL GPWCTM (I, I)
C
C     find min and max; ignore null data (negative values)
      GVMIN(1) = 1.0E30
      GVMAX(1) = -1.0E30
      GVMIN(2) = 1.E30
      GVMAX(2) = -1.0E30
      DO 20 I = 1, MAXP
        IF (DIS(I).GT.GVMAX(1)) GVMAX(1) = DIS(I)
        IF (DIS(I).LT.GVMIN(1) .AND. DIS(I).GE.0)  GVMIN(1) = DIS(I)
        IF (GDIS(I).GT.GVMAX(2)) GVMAX(2) = GDIS(I)
        IF (GDIS(I).LT.GVMIN(2) .AND. GDIS(I).GE.0)  GVMIN(2) = GDIS(I)
 20   CONTINUE
C     set data ranges
      CALL GPVMNX (I1, NUMVAR, GVMIN, GVMAX)
C
C     determine appropriate scale for left y-axis based on largest GVMAX
      SCLTYP = 2
      CALL SCALIT (SCLTYP, GVMIN(2), GVMAX(1),
     O             YLMIN, YLMAX)
C     set left y-axis scale
      CALL GPSCYL (YLMIN, YLMAX)
C
C     set up times
      CALL TIMADD (START, TU, TS, MAXP, END)
      CALL ZIPI (L18, I0, TSTEP)
      TSTEP(1) = TS
      TSTEP(2) = TS
      CALL ZIPI (L18, I0, TUNIT)
      TUNIT(1) = TU
      TUNIT(2) = TU
C     flows are mean
      CALL ZIPI (L18, I0, DTYPE)
      DTYPE(1) = 1
      DTYPE(2) = 1
      CALL GPTIME (TSTEP, TUNIT, START, END, DTYPE)
C
      RETURN
      END
C
C
C
      SUBROUTINE   BSPLOT
     I                   (MESSFL, SCLU, STAID, STANAM, METH, DRAIN,
     I                    BASLEN, BASNAM, PLTDEV, FRQOPT, DUROPT, 
     I                    SEAOPT, MODOPT, IREC, YRARRY, BGNMON, MXSIZE, 
     I                    FREQ, SRTQ, SRTBF, SRTDR, NCLASS, FLCLAS, 
     I                    NUMT, NUMD, NUMB, FMIN, FMAX, MNCNT, MNTFL, 
     I                    MNTBF, UNITFG,
     M                    PLT1, OTCNTR)
C
C     + + + PURPOSE + + +
C     Calls the routines to produce the plots chosen by user.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      MESSFL, SCLU, METH, BASLEN, PLTDEV(2,3), FRQOPT(3),
     $             DUROPT(3), SEAOPT, MODOPT, IREC, YRARRY(IREC), 
     $             BGNMON, MXSIZE, NCLASS, NUMT(NCLASS), NUMD(NCLASS),
     $             NUMB(NCLASS), MNCNT(12), UNITFG, OTCNTR(2:4,3)
      REAL         DRAIN, FREQ(MXSIZE), SRTQ(MXSIZE), SRTBF(MXSIZE), 
     $             SRTDR(MXSIZE), FLCLAS(NCLASS), FMIN, FMAX, MNTFL(12), 
     $             MNTBF(12)
      CHARACTER*1  BASNAM(BASLEN)
      CHARACTER*8  STAID
      CHARACTER*48 STANAM
      LOGICAL      PLT1(3)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of message file for screens
C     SCLU   - message file screen cluster number
C     STAID  - station ID
C     STANAM - station name/description
C     METH   - base flow separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     DRAIN  - drainage area
C     BASLEN - length of basename to be included in all output files
C     BASNAM - basename to be included in all output files
C     the following argument can contain these values:
C              1 - screen
C              2 - laser or dot matrix printer
C              3 - pen plotter
C              4 - meta file
C     PLTDEV - array of output devices; 2 output devices possible per plot
C              PLTDEV(1:2,1) - for frequency distribution plot 
C              PLTDEV(1:2,2) - for flow duration plot
C              PLTDEV(1:2,3) - for seasonal bar chart
C     FRQOPT - array of flags of frequency distribution plot options
C              FRQOPT(1) - total flow 
C              FRQOPT(2) - surface runoff
C              FRQOPT(3) - base flow
C     DUROPT - array of flags of flow duration plot options
C              DUROPT(1) - total flow 
C              DUROPT(2) - surface runoff
C              DUROPT(3) - base flow
C     SEAOPT - seasonal bar chart option
C              1 - average
C              2 - percent
C     MODOPT - plot parameter modification flag:  0-NO, 1-YES
C     IREC   - number of years to be processed
C     YRARRY - array of years processed
C     BGNMON - 1st month for annual summaries
C              1=Jan, 2=Feb,...,12=Dec
C     MXSIZE - maximum size of input arrays (maximum number of years 
C              that can be processed at one time)
C     FREQ   - frequency distribution of annual flows
C     SRTQ   - streamflow depth sorted by frequency
C     SRTBF  - base flow depth sorted by frequency
C     SRTDR  - surface runoff depth sorted by frequency
C     NCLASS - number of class intervals for flow duration plot
C     FLCLAS  - upper bound of each class interval
C     NUMT   - no. of occurrences of total flow in each class intvl
C     NUMD   - no. of occurrences of surface runoff in each class intvl
C     NUMB   - no. of occurrences of base flow in each class intvl
C     FMIN   - minimum flow value
C     FMAX   - maximum flow value
C     MNCNT  - count of days of flow for each month
C     MNTFL  - total flow for each month
C     MNTBF  - total base flow for each month
C     UNITFG - flow depth units
C              1 - english (inches)
C              2 - metric (centimeters)
C     PLT1   - array of flags indicating if plots to be produced are the
C              first ones of their type for this base-flow separation
C     OTCNTR - array of graphical output file counters--if >1 plot is
C              output to a file, ea. plot will be placed in a separate
C              file w/ OTCNTR(m,n) appended to the basename given by user
C              OTCNTR(2,1) - frequency plot counter for printer output 
C              OTCNTR(3,1) - frequency plot counter for plotter output
C              OTCNTR(4,1) - frequency plot counter for metafile output
C
C              OTCNTR(2,2) - flow duration plot counter for printer output
C              OTCNTR(3,2) - flow duration plot counter for plotter output
C              OTCNTR(4,2) - flow duration plot counter for metafile output
C
C              OTCNTR(2,3) - seasonal bar chart counter for printer output
C              OTCNTR(3,3) - seasonal bar chart counter for plotter output
C              OTCNTR(4,3) - seasonal bar chart counter for metafile output
C
C     + + + SAVES + + +
      INTEGER      IVAL(265,3)
      REAL         RVAL(64,3)
      CHARACTER*1  CVAL(1400,3)
      SAVE         IVAL, RVAL, CVAL
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I0, I1, I6, J, K, L, SGRP, IC(7), IMOD, RETCOD, 
     $             WNDFLG, PLTFUN, INDEX, DEVCOD, WSID, ICLOS, IWAIT, 
     $             CMPTYP, MXPLTS, MXDEVS
      CHARACTER*2  DATTYP
      CHARACTER*4  ENDING(2:4)
      CHARACTER*8  BWNNAM(2)
      CHARACTER*27 PLTTYP(3)
      CHARACTER*48 WNDNAM
      LOGICAL      FIRST(3), MORE
C
C     + + + EXTERNALS + + +
      EXTERNAL     GPINIT, GPZIPB, GPDEVC, GGETVL, GPUTVL, GPMTFL
      EXTERNAL     PSTUPW, PLTONE, PDNPLT,  PROPLT
      EXTERNAL     ANPRGT, ZWNSET, QRESP, PRNTXT, QFCLOS
      EXTERNAL     FRQSET, FRQDAT, FDSET, FDDAT, SEASET, SEADAT, OPNFIL
C
C     + + + DATA INITIALIZATIONS + + +
      DATA FIRST  /.TRUE., .TRUE., .TRUE./
      DATA PLTTYP /'frequency distribution plot',
     $             'flow duration plot',
     $             'seasonal bar chart'/ 
C
C     + + + END SPECIFICATIONS + + +
C
      I0 = 0
      I1 = 1
      I6 = 6
      ENDING(2) = 'ps'
      ENDING(3) = 'hpgl'
      ENDING(4) = 'cgm'
      IWAIT = 0
      PLTFUN = 0
      MXPLTS = 3
      MXDEVS = 2
C
      DO 50 I = 1, MXPLTS
        DO 40 J = 1, MXDEVS
          IF (PLTDEV(J,I) .GE. 1) THEN
C           if very first time through...
            IF (FIRST(I)) THEN
C             initialize graphics common
              CALL GPINIT
C             set default plot parameters
              IF (I .EQ. 1) THEN
                CALL FRQSET
              ELSE IF (I .EQ. 2) THEN
                CALL FDSET (STAID, STANAM) 
              ELSE
                CALL SEASET
              END IF
            ELSE
C             put saved plot parameters in graphics common block
              CALL GPUTVL (IVAL(1,I), RVAL(1,I), CVAL(1,I))
            END IF
C
C           reinitialize data buffer
            CALL GPZIPB
C           set plot parameters specific to data
            IF (I .EQ. 1) THEN
              CALL FRQDAT (FRQOPT, STAID, STANAM, METH, IREC, YRARRY, 
     I                     FREQ, SRTQ, SRTBF, SRTDR, UNITFG)
            ELSE IF (I .EQ. 2) THEN
              CALL FDDAT (DUROPT, STAID, STANAM, METH, IREC, YRARRY, 
     I                    NCLASS, FLCLAS, NUMT, NUMD, NUMB, FMIN, FMAX, 
     I                    UNITFG)
            ELSE
              CALL SEADAT (SEAOPT, STAID, STANAM, METH, IREC, YRARRY,
     I                     BGNMON, DRAIN, MNCNT, MNTFL, MNTBF, UNITFG)
            END IF
C
C           get plot parm.s from graphics common blk and put in local arrays
            CALL GGETVL (IVAL(1,I), RVAL(1,I), CVAL(1,I))
C
C           get device code from TERM.DAT
            INDEX = 39 + PLTDEV(J,I)
            CALL ANPRGT (INDEX,
     O                   DEVCOD)
C           set device type and code
            CALL GPDEVC (PLTDEV(J,I), DEVCOD)
C
C           set workstation IDs, workstation close flags
            IF (PLTDEV(J,I) .EQ. 1) THEN
              WSID = 2
              ICLOS = 0
            ELSE
              WSID = 1
              ICLOS = 1
            END IF
C
            IF (PLTDEV(J,I) .NE. 1) THEN
C             chk. computer type--may need to open file for graphical output
              CALL ANPRGT (I1, CMPTYP)
              IF (CMPTYP .EQ. 5) THEN
C               cmptyp=aviion, need to open file
                IF (I .EQ. 1) THEN
                  DATTYP = 'fq'
                ELSE IF (I .EQ. 2) THEN
                  DATTYP = 'fd'
                ELSE
                  DATTYP = 'sb'
                END IF
                CALL OPNFIL (BASLEN, BASNAM, DATTYP, 
     I                       ENDING(PLTDEV(J,I)),
     M                       OTCNTR(PLTDEV(J,I),I),
     O                       PLTFUN)
C               put unit no. of graphical output file in CPLOT common blk
                CALL GPMTFL (PLTFUN)
              END IF
            END IF
C
            IF (PLTDEV(J,I).EQ.1 .OR.
     $         (PLTDEV(J,I).NE.1 .AND. 
     $          (MODOPT.EQ.0 .OR. .NOT.PLT1(I)))) THEN
C             generate plot if output device is screen or not modifying plot
              CALL PSTUPW (WSID, RETCOD)
              CALL PLTONE
              CALL PDNPLT (WSID, ICLOS, IWAIT)
            END IF
C
C           set window name for screens that might be displayed
            WNDNAM = 'Execute (E) ' // PLTTYP(I)
C
            IF (MODOPT.EQ.1 .AND. PLT1(I)) THEN
C             allow user to modify plot (1-replot, 2-modify, 3-done)
 10           CONTINUE
                CALL ZWNSET (WNDNAM)
                IF (PLTDEV(J,I) .EQ. 1) THEN
                  SGRP = 63
                ELSE
                  SGRP = 64
                END IF
                CALL QRESP (MESSFL, SCLU, SGRP, IMOD)
                IF (PLTDEV(J,I) .NE. 1) IMOD = IMOD + 1
C
                IF (IMOD.EQ.1 .OR. 
     $             (IMOD.EQ.3 .AND. PLTDEV(J,I).NE.1)) THEN
C                 recreate plot
                  CALL PSTUPW (WSID, RETCOD)
                  CALL PLTONE
                  CALL PDNPLT (WSID, ICLOS, IWAIT)
                ELSE IF (IMOD .EQ. 2) THEN
C                 modify plot; set IC to allow mod. of all plot parms. but device
                  IC(1) = 2
                  CALL ZIPI (I6, I1, IC(2))
C                 if flow duration plot, don't allow mod. of axes types
                  IF (I .EQ. 2) IC(2) = 2
                  IF (I .EQ. 3) THEN
C                   if seasonal bar, don't allow mod. of axes, curves, min/max
                    IC(2) = 2
                    IC(4) = 2
                    IC(5) = 2
                  END IF
                  BWNNAM(1) = 'Modify'
                  BWNNAM(2) = 'EM'
                  CALL PROPLT (MESSFL, IC, BWNNAM,
     O                         WNDFLG)
                END IF
              IF (IMOD .NE. 3) GO TO 10
C
C             retrieve plot parameters as modified by user
              CALL GGETVL (IVAL(1,I), RVAL(1,I), CVAL(1,I))
            END IF
C
C           if user has chosen to modify the plot, they'll be able to
C           look at a plot displayed to the screen as long as they want 
C           before choosing "DONE" and continuing on; therefore, only if
C           the user *hasn't* chosen to modify the plot, we check to see
C           if there are more plots to display and, if so, we display a 
C           text screen and wait for user to choose "Accept" before 
C           drawing the next plot
            IF (MODOPT.EQ.0 .AND. PLTDEV(J,I).EQ.1) THEN
C             check if there are more plots to display to screen
              MORE = .FALSE.
              DO 30 K = I, MXPLTS
                DO 20 L = 1, MXDEVS
                  IF (.NOT. (K.EQ.I .AND. L.LE.J) .AND. .NOT.MORE) THEN
C                   past array slot for current plot and haven't yet found more plots
                    IF (PLTDEV(L,K) .EQ. 1) MORE = .TRUE.
                  END IF
 20             CONTINUE
 30           CONTINUE
C
              IF (MORE) THEN
C               pause before going on to next plot
                CALL ZWNSET (WNDNAM)
                SGRP = 81
                CALL PRNTXT (MESSFL, SCLU, SGRP)
              END IF
C           end if (modopt .eq. 0)
            END IF
C
            IF (FIRST(I)) FIRST(I) = .FALSE.
            IF (PLT1(I)) PLT1(I) = .FALSE.
            IF (PLTFUN .NE. 0) THEN
C             output file opened--close it and free up Fortran unit no.
              CALL QFCLOS (PLTFUN, I0)
              PLTFUN = 0
            END IF

C
C         end if (pltdev(j,i) .ge. 1)
          END IF
C
 40     CONTINUE
 50   CONTINUE
C
      RETURN
      END
C
C
C
      SUBROUTINE   OPNFIL
     I                   (BASLEN, BASNAM, DATTYP, SUFFIX, 
     M                    FLCNTR,
     O                    FLUNIT)
C
C     + + + PURPOSE + + +
C     Opens a file for output.  File name follows the pattern:
C     BASNAM//DATTYP//FLCNTR//'.'//SUFFIX.  FLCNTR is used to 
C     distinguish multiple plots of same type; not included in filename 
C     if value is 1.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      BASLEN, FLCNTR, FLUNIT
      CHARACTER*1  BASNAM(BASLEN)
      CHARACTER*2  DATTYP
      CHARACTER*(*) SUFFIX
C
C     + + + ARGUMENT DEFINITIONS + + +
C     BASLEN - length of basename
C     BASNAM - basename chosen by user for all output files
C     DATTYP - output data type for graphical output
C              (string of blanks passed in for non-graphical files)
C              'fq' - frequency distribution plot
C              'fd' - flow-duration plot
C              'sb' - seasonal bar chart
C              'hy' - hydrograph of base-flow separation
C     SUFFIX - filename suffix indicating file contents/format
C     FLCNTR - index of no. of output files produced of this type of plot
C     FLUNIT - Fortran unit number assigned to file
C
C     + + + PARAMETERS + + +
      INCLUDE 'pbasln.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER            I, I1, I3, JUST, BLNGTH, NUMLEN
      CHARACTER*3        NUM
      CHARACTER*64       NAME, FILNAM
      CHARACTER*(BSLNMX) BNAME
C
C     + + + FUNCTIONS + + +
      INTEGER   LENSTR
C
C     + + + EXTERNALS + + +
      EXTERNAL  CARVAR, INTCHR, LENSTR, GETFUN
C
C     + + + END SPECIFICATIONS + + +
C
      I1 = 1
      I3 = 3
C
      CALL CARVAR (BASLEN, BASNAM, BASLEN,
     O             BNAME)
      BLNGTH = LENSTR (BASLEN, BNAME)
C
C     append data type abbreviation to basename
      NAME = BNAME(1:BLNGTH) // DATTYP
      I = BLNGTH + 2
      BLNGTH = LENSTR (I, NAME)
C
      IF (FLCNTR .GT. 1) THEN
C       append FLCNTR to basename to produce new file name
        JUST = 1
        CALL INTCHR (FLCNTR, I3, JUST, 
     O               NUMLEN, NUM)
        NAME = NAME(1:BLNGTH) // NUM(1:NUMLEN)
        FILNAM = NAME(1:BLNGTH+NUMLEN) // '.' // SUFFIX 
      ELSE
        FILNAM = NAME(1:BLNGTH) // '.' // SUFFIX
      END IF
C
      CALL GETFUN (I1, FLUNIT)
      OPEN (UNIT=FLUNIT, FILE=FILNAM, STATUS='UNKNOWN',
     $      ACCESS='SEQUENTIAL', FORM='FORMATTED')
C
C     increment output file counter for next plot (if any)
      FLCNTR = FLCNTR + 1
C
      RETURN
      END
