C
C
C
      SUBROUTINE   WDMSAV
     I                   (MESSFL, SCLU, WDMSFL, ROWDM, BFWDM, 
     I                    ROWAT, BFWAT, IREC, START, ENDYR, 
     I                    NDAYS, DSN, LSTFLG)
C
C     + + + PURPOSE + + +
C     Saves base flow and/or surface runoff to data sets on user's WDM 
C     file.  A new output data set is created when WDMSAV is passed the 
C     first year of data generated from the input data set.  Following 
C     years of data are saved to the same output data set.  Attributes 
C     are copied from the source data set to the output data set(s) and
C     TSTYPE is changed to 'BFLO' or 'SRNF'.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   MESSFL, SCLU, WDMSFL, ROWDM, BFWDM, ROWAT, BFWAT, IREC,
     $          START(6), ENDYR, NDAYS, DSN, LSTFLG
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of the message file
C     SCLU   - screen cluster number on message file
C     WDMSFL - Fortran unit number of the wdm file
C     ROWDM  - WDM surface runoff output flag
C     BFWDM  - WDM base flow output flag
C     ROWAT  - ASCII surface runoff output flag
C     BFWAT  - ASCII base flow output flag
C     IREC   - order no. of year of data w/in period specified by user;
C               1 - 1st year of data w/in period specified by user,
C                   create a new output data set
C              >1 - save data to already created data set 
C     START  - starting date of the data being saved
C     ENDYR  - ending year of period being saved
C     NDAYS  - number of days to be saved
C     DSN    - source data set to be used for attributes
C     LSTFLG - flag indicating if year to save is last one
C              1 - last year
C             -1 - not last year
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'chysep.inc'
C
C     + + + SAVES + + +
      INTEGER   RODSN, BFDSN
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I0, I4, L, EXIST, RETCOD, SGRP, TS, TU, DTOVW,
     $             QFLG, INUM, MAXLIN, SCINIT, IWRT, IVAL(4), SAIND, 
     $             SALEN, NWDMFL, NTYPE, DSNOUT, CLEN(2), TXTLEN, ONUM,
     $             OTYP(5)
      REAL         RVAL(366), RDUM(1)
      DOUBLE PRECISION  DDUM(1)
      CHARACTER*1  SAVAL(4), CVAL(17) 
      CHARACTER*14 TXT(2), CAPTXT(2)
      LOGICAL      DOSAVE
C
C     + + + FUNCTIONS + + +
      INTEGER   WDCKDT, LENSTR
C
C     + + + EXTERNALS + + +
      EXTERNAL   WDDSCL, WDTPUT, WDCKDT, WDBSAC
      EXTERNAL   PMXTXI, PMXTXM
      EXTERNAL   LENSTR, ZIPI, COPYC, COPYR, CVARAR
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  TS, TU, DTOVW, QFLG, I0, I4
     $     / 1,  4,     1,    0,  0,  4 /
      DATA  RODSN, BFDSN
     $     /    0,     0 /
C
C     + + + END SPECIFICATIONS + + +
C
      CALL ZIPI (I4, I0, IVAL)
      RDUM(1) = 0
      DDUM(1) = 0
      TXT(1) = 'surface runoff'
      TXT(2) = 'base flow'
      CAPTXT(1) = 'Surface runoff'
      CAPTXT(2) = 'Base flow'
      MAXLIN = 5
C
      SCINIT = 1
      IWRT = 0
C
      IF (IREC .EQ. 1) THEN
        RODSN = DSN + 1
        BFDSN = DSN + 1
      END IF
C
      DO 50 I = 1, 2
        DOSAVE = .FALSE.
        IF (I.EQ.1 .AND. ROWDM.EQ.1) THEN
          DOSAVE = .TRUE.
          DSNOUT = RODSN
          CALL COPYR (NDAYS, RUNOFF, RVAL)
          SAVAL(1) = 'S'
          SAVAL(2) = 'R'
          SAVAL(3) = 'N' 
          SAVAL(4) = 'F'
        END IF
C
        IF (I.EQ.2 .AND. BFWDM.EQ.1) THEN
          DOSAVE = .TRUE.
          DSNOUT = BFDSN
          CALL COPYR (NDAYS, GDIS, RVAL)
          SAVAL(1) = 'B'
          SAVAL(2) = 'F'
          SAVAL(3) = 'L' 
          SAVAL(4) = 'O'
        END IF
C
        IF (DOSAVE) THEN
          IF (IREC .EQ. 1) THEN
C           this is 1st yr. of data 2B saved--create new output data set
C           check DSNOUT for existence
            EXIST = WDCKDT (WDMSFL, DSNOUT)
            IF (EXIST .NE. 0) THEN
C             data set already exists
 10           CONTINUE
C               increment DSNOUT till free dsn found
                DSNOUT = DSNOUT + 1
                EXIST = WDCKDT (WDMSFL, DSNOUT)
              IF (EXIST .NE. 0) GO TO 10
            END IF
C           create new DSNOUT, copy attributes from DSN
C           assume same wdm file and data-set type
            NWDMFL = WDMSFL
            NTYPE  = 0
            CALL WDDSCL (WDMSFL, DSN, NWDMFL, DSNOUT, NTYPE, RETCOD)
            IF (RETCOD .EQ. 0) THEN
              IF (I .EQ. 1) THEN
                RODSN = DSNOUT
              ELSE
                BFDSN = DSNOUT
              END IF
            END IF
          ELSE
C           add data to already created data set (DSNOUT)
            RETCOD = 0
          END IF
C
          IF (RETCOD .EQ. 0) THEN
C           change TSTYPE to 'BFLO' or 'SRNF'
            SAIND = 1
            SALEN = 4
            CALL WDBSAC (WDMSFL, DSNOUT, MESSFL, SAIND, SALEN, SAVAL,
     O                   RETCOD)
            IF (RETCOD .EQ. 0) THEN
C             no problem changing TSTYPE
C             add base flow data to wdm file
              CALL WDTPUT (WDMSFL, DSNOUT, TS, START, NDAYS,
     I                      DTOVW, QFLG, TU, RVAL,
     O                      RETCOD)
              IF (RETCOD .NE. 0) THEN
C               problem adding data to DSNOUT
                ONUM = 5
                OTYP(1) = 1
                OTYP(2) = 4
                OTYP(3) = 1
                OTYP(4) = 1
                OTYP(5) = 1
                IVAL(1) = DSN
                IVAL(2) = ENDYR
                IVAL(3) = DSNOUT
                IVAL(4) = RETCOD
                L = 14
                CALL CVARAR (L, TXT(I), L, CVAL)
                CLEN(1) = LENSTR (L, CVAL)
                SGRP = 75
                CALL PMXTXM (MESSFL, SCLU, SGRP, MAXLIN, SCINIT, ONUM,
     I                       OTYP, IWRT, IVAL, RDUM, DDUM, CLEN, CVAL)
              ELSE IF (LSTFLG .EQ. 1) THEN
C               last year saved, show which data set written to
                IF (ROWAT.EQ.0 .AND. BFWAT.EQ.0 .AND. 
     $             (I.EQ.1 .OR. (I.EQ.2 .AND. ROWDM.EQ.0))) THEN
C                 1st msg. written after prog. report msg.s--clear screen
                  SCINIT = 1
                ELSE
C                 don't clear screen
                  SCINIT = -1
                END IF
                IF (I.EQ.1 .AND. BFWDM.EQ.1) THEN
C                 just "write and go" if there are more msg.s to display
                  IWRT = 1
                ELSE
C                 last message--write and wait for user acknowledgement
                  IWRT = 0
                END IF
                ONUM = 3
                OTYP(1) = 4
                OTYP(2) = 1
                OTYP(3) = 4
                IVAL(1) = DSNOUT
                L = 14
                CALL CVARAR (L, CAPTXT(I), L, CVAL)
                TXTLEN = LENSTR (L, CVAL)
                CALL COPYC (I4, SAVAL, CVAL(TXTLEN+1))
                CLEN(1) = TXTLEN
                CLEN(2) = 4
                SGRP = 67
                CALL PMXTXM (MESSFL, SCLU, SGRP, MAXLIN, SCINIT, ONUM,
     I                       OTYP, IWRT, IVAL, RDUM, DDUM, CLEN, CVAL)
              END IF
            ELSE
C             problem in modifying TSTYPE 
              INUM = 2
              IVAL(1) = DSNOUT
              IVAL(2) = RETCOD
              SGRP = 78
              CALL PMXTXI (MESSFL, SCLU, SGRP, MAXLIN, SCINIT, IWRT,
     I                     INUM, IVAL)
            END IF
          ELSE
C           problem creating new DSNOUT 
            ONUM = 3
            OTYP(1) = 1
            OTYP(2) = 4
            OTYP(3) = 1
            IVAL(1) = DSNOUT
            IVAL(2) = RETCOD
            L = 14
            CALL CVARAR (L, TXT(I), L, CVAL)
            CLEN(1) = LENSTR (L, CVAL)
            SGRP = 71
            CALL PMXTXM (MESSFL, SCLU, SGRP, MAXLIN, SCINIT, ONUM,
     I                   OTYP, IWRT, IVAL, RDUM, DDUM, CLEN, CVAL)
          END IF
C
C       end if (dosave)
        END IF
 50   CONTINUE
C
      RETURN
      END
C
C
C
      SUBROUTINE   WATSAV
     I                   (MESSFL, SCLU, WDMSFL, ROWAT, BFWAT, 
     I                    ROWDM, BFWDM, IREC, BGNPD, ENDPD, 
     I                    DSN, LSTFLG, BASLEN, 
     I                    BASNAM, 
     M                    WATCNT, WATOUT)
C
C     + + + PURPOSE + + +
C     Saves base flow and surface runoff values to ASCII files in
C     WATSTORE daily values, card-image format.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   MESSFL, SCLU, WDMSFL, ROWAT, BFWAT, ROWDM, BFWDM, IREC, 
     $          BGNPD(6), ENDPD(6), DSN, LSTFLG, BASLEN, 
     $          WATCNT(2), WATOUT(2)
      CHARACTER*1 BASNAM(BASLEN)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of the message file
C     SCLU   - screen cluster number on message file
C     WDMSFL - Fortran unit number of the wdm file
C     ROWAT  - ASCII surface runoff output flag
C     BFWAT  - ASCII base flow output flag
C     ROWDM  - WDM surface runoff output flag
C     BFWDM  - WDM base flow output flag
C     IREC   - order no. of year of data w/in period specified by user
C     BGNPD  - starting date of the data being saved, yr/mo/dy/hr/min/se
C     ENDPD  -   ending date of the data being saved, yr/mo/dy/hr/min/se
C     DSN    - data set on temp. WDM containing daily streamflow values
C     LSTFLG - flag indicating if year to save is last one
C              1 - last year
C             -1 - not last year
C     BASLEN - length of base name to be included in all output files
C     BASNAM - base name to be included in all output files
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'chysep.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, L, SGRP, FLAG, DATE(12), NUMDEC, NUMSIG, DELFG, 
     $             MAXLIN, SCINIT, IWRT, CNUM, CLEN(2)
      REAL         RVAL(366)
      CHARACTER*1  CARD2(80), CVAL(80), FILNAM(64)
      CHARACTER*2  DATTYP
      CHARACTER*3  SUFFIX
      CHARACTER*14 CAPTXT(2)
      LOGICAL      DOSAVE
C
C     + + + FUNCTIONS + + +
      INTEGER      LENSTR
C
C     + + + EXTERNALS + + +
      EXTERNAL     QFSTAT, QFCLOS, PMXTXI, PMXTXA
      EXTERNAL     COPYI, COPYR, CVARAR, LENSTR
      EXTERNAL     WTPRT2, WTPRT3
      EXTERNAL     OPNFIL
C
C     + + + END SPECIFICATIONS + + + 
C
      CAPTXT(1) = 'Surface runoff'
      CAPTXT(2) = 'Base flow'
      MAXLIN = 5
C
      DO 50 I = 1, 2
        DOSAVE = .FALSE.
        IF (I.EQ.1 .AND. ROWAT.EQ.1) THEN
          DOSAVE = .TRUE.
          SUFFIX = 'sro'
          L = 366
          CALL COPYR (L, RUNOFF, RVAL)
        END IF
C
        IF (I.EQ.2 .AND. BFWAT.EQ.1) THEN
          DOSAVE = .TRUE.
          SUFFIX = 'bsf'
          L = 366
          CALL COPYR (L, GDIS, RVAL)
        END IF
C
        IF (DOSAVE) THEN
C         open output file if not already open
          IF (WATOUT(I) .EQ. 0) THEN
            DATTYP = '  '
            CALL OPNFIL (BASLEN, BASNAM, DATTYP, SUFFIX,
     M                   WATCNT(I),
     O                   WATOUT(I))
          END IF
C
C         get '2' card from data set containing streamflow values
          CALL WTPRT2 (WDMSFL, DSN,
     O                 CARD2, FLAG)
C
C         output daily values
          L = 6 
          CALL COPYI (L, BGNPD, DATE)
          CALL COPYI (L, ENDPD, DATE(7))
          NUMDEC = 2
          NUMSIG = 7
          CALL WTPRT3 (WATOUT(I), IREC, DATE, NUMDEC, NUMSIG, RVAL, 
     I                 CARD2, FLAG)
C
          IF (LSTFLG .EQ. 1) THEN
C           just saved last year of data, display name of output file
            IF (I.EQ.1 .OR. (I.EQ.2 .AND. ROWAT.EQ.0)) THEN
C             1st msg. written after prog. report msg.s--clear screen
              SCINIT = 1
            ELSE
C             don't clear screen
              SCINIT = -1
            END IF
            IF ((I.EQ.1 .AND. BFWAT.EQ.1) .OR. 
     $          (ROWDM.EQ.1 .OR. BFWDM.EQ.1)) THEN
C             just "write and go" if there are more msg.s to display
              IWRT = 1
            ELSE
C             last message--write and wait for user acknowledgement
              IWRT = 0
            END IF
            CNUM = 2
            L = 14
            CALL CVARAR (L, CAPTXT(I), L, CVAL)
            CLEN(1) = LENSTR (L, CVAL)
            CALL QFSTAT (WATOUT(I),
     O                   FILNAM)
            L = 64
            CLEN(2) = LENSTR (L, FILNAM)
            CALL COPYC (L, FILNAM, CVAL(CLEN(1)+1))
            SGRP = 82
            CALL PMXTXA (MESSFL, SCLU, SGRP, MAXLIN, SCINIT, IWRT, 
     I                   CNUM, CLEN, CVAL)
C           close output file
            DELFG = 0
            CALL QFCLOS (WATOUT(I), DELFG)
            WATOUT(I) = 0
          END IF
        END IF
 50   CONTINUE
C
      RETURN
      END
