C
C
C
      SUBROUTINE   BSEXEC
     I                   (MESSFL, SCLU, WDMSFL, DSNCNT, DSNBUF, METH, 
     I                    BGNMON, PRTFLG, FRQPRT, DURPRT, SEAPRT, ROWAT,
     I                    BFWAT, ROWDM, BFWDM, UNITFG, ENGOPT, PLTDEV, 
     I                    HYDDEV, FRQOPT, DUROPT, SEAOPT, MODOPT, 
     I                    BASLEN, 
     M                    BASNAM, OTCNTR)
C
C     + + + PURPOSE + + +
C     BSEXEC functions as the driver for the actual execution of the
C     hydrograph separation.  Input to program is daily values in
C     WATSTORE card-image format or from a Watershed Data Management
C     (WDM) file.  Input may be one year or period of record.  Gaps in 
C     record are accounted for.  Graphics use GKS.
C
C     *** AML 10/01/91 ***
C     Baseflow separation performed on 1 year of data at a time. The 
C     beginning (and ending) of the year period determined by the month 
C     the user chooses to be 1st month for the annual summary (BGNMON).
C     Each 1-year period of data is extended by 11 days at the beginning
C     and end to provide greater accuracy in base flow calculation at 
C     the start and end of each period analyzed.  The extra 11-day 
C     intervals at the beginning and end are not included in output.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      MESSFL, SCLU, WDMSFL, DSNCNT, DSNBUF(DSNCNT), METH, 
     $             BGNMON, PRTFLG, FRQPRT, DURPRT, SEAPRT, ROWAT, BFWAT,
     $             ROWDM, BFWDM, UNITFG, ENGOPT, PLTDEV(2,3), HYDDEV(2),
     $             FRQOPT(3), DUROPT(3), SEAOPT, MODOPT, BASLEN, 
     $             OTCNTR(2:4,4)
      CHARACTER*1  BASNAM(BASLEN)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of the message file
C     SCLU   - screen cluster number on message file
C     WDMSFL - Fortran unit number of wdm file
C     DSNCNT - number of data sets to be processed
C     DSNBUF - array of DSNCNT data sets to be processed
C     METH   - separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     BGNMON - 1st month for annual summaries
C              1=Jan, 2=Feb,...,12=Dec
C     the following flags have two possible values:  0-NO, 1-YES
C     PRTFLG - monthly summary printout flag
C     FRQPRT - frequency distribution table flag
C     DURPRT - flow duration table flag 
C     SEAPRT - seasonal distribution table flag
C     ROWAT  - ASCII surface runoff output flag
C     BFWAT  - ASCII base flow output flag
C     ROWDM  - WDM surface runoff output flag
C     BFWDM  - WDM base flow output flag
C     UNITFG - print file units
C              1 - english
C              2 - metric
C     ENGOPT - units for base flow in predefined columns of print file
C              1 - mgd/mi2
C              2 - mg/day
C              3 - cfs/mi2
C     the following two arguments can contain these values:
C              1 - screen
C              2 - laser or dot matrix printer
C              3 - pen plotter
C              4 - meta file
C     PLTDEV - array of output devices; 2 output devices possible per plot
C              PLTDEV(1:2,1) - for frequency distribution plot 
C              PLTDEV(1:2,2) - for flow duration plot
C              PLTDEV(1:2,3) - for seasonal bar chart
C     HYDDEV - array of output devices for hydrograph
C     FRQOPT - array of flags of frequency distribution plot options
C              FRQOPT(1) - total flow 
C              FRQOPT(2) - surface runoff
C              FRQOPT(3) - base flow
C     DUROPT - array of flags of flow duration plot options
C              DUROPT(1) - total flow 
C              DUROPT(2) - surface runoff
C              DUROPT(3) - base flow
C     SEAOPT - seasonal bar chart option
C              1 - average
C              2 - percent
C     MODOPT - plot parameter modification flag:  0-NO, 1-YES
C     BASLEN - length of basename to be included in all output files
C     BASNAM - basename to be included in all output files
C     OTCNTR - array of graphical output file counters--if >1 plot is
C              output to a file, ea. plot will be placed in a separate
C              file w/ OTCNTR(m,n) appended to the basename given by user
C              OTCNTR(2,1) - frequency plot counter for printer output 
C              OTCNTR(3,1) - frequency plot counter for plotter output
C              OTCNTR(4,1) - frequency plot counter for metafile output
C
C              OTCNTR(2,2) - flow duration plot counter for printer output
C              OTCNTR(3,2) - flow duration plot counter for plotter output
C              OTCNTR(4,2) - flow duration plot counter for metafile output
C
C              OTCNTR(2,3) - seasonal bar chart counter for printer output
C              OTCNTR(3,3) - seasonal bar chart counter for plotter output
C              OTCNTR(4,3) - seasonal bar chart counter for metafile output
C
C              OTCNTR(2,4) - hydrograph counter for printer output
C              OTCNTR(3,4) - hydrograph counter for plotter output
C              OTCNTR(4,4) - hydrograph counter for metafile output
C
C     + + + PARAMETERS + + +
      INCLUDE 'pmxyrs.inc'
      INCLUDE 'pbasln.inc'
      INCLUDE 'pclass.inc'
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'chysep.inc'
C
C     + + + SAVES + + +
      INTEGER      PRTCNT, WATCNT(2), WATOUT(2)
      SAVE         PRTCNT, WATCNT, WATOUT
C
C     + + + SAVE DEFINITIONS + + +
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I0, I1, L12, SGRP, IREC, INTRVL, DIND, IYR(MXYRS),
     $             TU,TS, NDAYS, MXSIZE, STREC(6), ENDREC(6), STCOMP(6),
     $             EDCOMP(6), BGNPD(6), ENDPD(6), BGNEXT(6), ENDEXT(6),
     $             DATFLG, ENDMON, STINTR, LSTFLG, WDTRET, DATE(6), 
     $             EXIT, MNCNT(12), LINE, GIREC, NCI, NUMT(NCLASS), 
     $             NUMD(NCLASS), NUMB(NCLASS), NMIS, SAVFLG, PRTFUN
      REAL         ABFW(MXYRS), AQW(MXYRS), FREQ(MXYRS), SRTQ(MXYRS),
     $             SRTBF(MXYRS), SRTDR(MXYRS), DRAIN, MNTFL(12), 
     $             MNTBF(12), BOUND(2), FLCLAS(NCLASS), FMIN, FMAX
      CHARACTER*1  OLDBAS(BSLNMX)
      CHARACTER*2  DATTYP
      CHARACTER*3  SUFFIX
      CHARACTER*8  STAID
      CHARACTER*16 DUM1
      CHARACTER*48 STA
      LOGICAL      INTRPT, AGAIN, HYD1, PLT1(3)
C
C     + + + FUNCTIONS + + +
      INTEGER    CHKNAM
      LOGICAL    NAMCHG
C
C     + + + EXTERNALS + + +
      EXTERNAL   QFCLOS, CKDATE, NAMCHG, CHRCHR, PRNTXT, ZIPI
      EXTERNAL   BSDESC, GTINFO, CHKNAM, BSDATE, WDMSAV, WATSAV, OPNFIL
      EXTERNAL   BSDATA, BSPROG, STAT, HYDPLT, BSPLOT, MONTH, ANNUAL
      EXTERNAL   BSSTAT, FDINVL, FDCNT, FDTABL
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  PRTCNT, WATCNT, WATOUT
     $     /     1,   1, 1,   0, 0 /
C
C     + + + END SPECIFICATIONS + + +
C
C     definitions of variables used for dates
C     STREC  - start date of period of data available on data set
C     ENDREC -   end date of period of data available on data set
C     STCOMP - start date for analysis, yr/mon/dy/hr/min/sec
C     EDCOMP -   end date for analysis, yr/mon/dy/hr/min/sec
C     BGNMON - starting month for table output
C     ENDMON -   ending month for table output
C     BGNPD  - start date for year being analyzed, yr/mon/dy/hr/min/sec
C     ENDPD  -   end date for year being analyzed, yr/mon/dy/hr/min/sec
C     BGNEXT - start date for year being analyzed, minus 11 days
C     ENDEXT -   end date for year being analyzed, plus 11 days
C
      I0 = 0
      I1 = 1
      L12 = 12
      TU = 4
      TS = 1
      MXSIZE = MXYRS
      DIND = 1
      HYD1 = .TRUE.
      PLT1(1) = .TRUE.
      PLT1(2) = .TRUE.
      PLT1(3) = .TRUE.
C     initialize variables needed for opening print file
      DATTYP = '  '
      SUFFIX = 'prt'
      PRTFUN = 0
C
      IF (ROWAT.EQ.1 .OR. BFWAT.EQ.1 .OR. 
     $    ROWDM.EQ.1 .OR. BFWDM.EQ.1) THEN
C       data will be saved to WATSTORE or WDM file, set flag
        SAVFLG = 1
      ELSE
        SAVFLG = 0
      END IF
C
C     start loop for each WDM file data set
 5    CONTINUE
        IREC = 0
        STINTR = 0
C       get basin description and drainage area
        CALL BSDESC (MESSFL, SCLU, WDMSFL, DSNBUF(DIND),
     O               DRAIN, STAID, STA)
C       if metric units chosen, convert drainage area to square km
        IF (UNITFG .EQ. 2) DRAIN = DRAIN * 2.590
C
        IF (DURPRT.EQ.1 .OR.
     $      PLTDEV(1,2).NE.0 .OR. PLTDEV(2,2).NE.0) THEN
C         get class intervals for flow duration analysis
          BOUND(1) = 0.1
          BOUND(2) = 100000.0
          NCI = NCLASS
          CALL FDINVL (BOUND, NCI,
     O                 FLCLAS)
C         initialize flow occurrence counters
          CALL ZIPI (NCI, I0, NUMT)
          CALL ZIPI (NCI, I0, NUMD)
          CALL ZIPI (NCI, I0, NUMB)
          NMIS = 0
        END IF
C
C15     CONTINUE
          INTRPT = .FALSE.
 20       CONTINUE
            AGAIN = .FALSE.
C           get basename for output files, dates for analysis
            CALL CHRCHR (BASLEN, BASNAM,
     O                   OLDBAS)
            CALL GTINFO (MESSFL, SCLU, WDMSFL, DSNBUF(DIND), STAID,
     I                   BASLEN,
     M                   BASNAM, 
     O                   STREC, ENDREC, DATE, EXIT)
            IF (EXIT .EQ. 0) THEN
C             check basename entered by user
              IF (CHKNAM(BASLEN, BASNAM) .GT. 0) THEN
                AGAIN = .TRUE.
                SGRP = 80
                CALL PRNTXT (MESSFL, SCLU, SGRP)
              ELSE
C               check dates entered by user, return dates for init. yr.
                CALL BSDATE (MESSFL, SCLU, STREC, ENDREC, DATE, BGNMON,
     O                       ENDMON, STCOMP, EDCOMP, BGNPD, ENDPD, 
     O                       BGNEXT, ENDEXT, AGAIN)
              END IF
            END IF 
          IF (AGAIN) GOTO 20
C
          IF (EXIT .EQ. 0) THEN
C           continue 
            IF (NAMCHG (BASLEN, OLDBAS, BASNAM)) THEN
C             user entered new basename; reset output counters
              CALL ZIPI (L12, I1, OTCNTR)
              PRTCNT = 1
              WATCNT(1) = 1
              WATCNT(2) = 1
              IF (PRTFUN .NE. 0) THEN
C               print file was opened w/ old basename, close it
                CALL QFCLOS (PRTFUN, I0)
                PRTFUN = 0
              END IF
C             update base name in status window
              LINE = 4
              DUM1 = ' '
              CALL BSSTAT (LINE, WDMSFL, BASLEN, BASNAM, DSNCNT, DUM1)
            END IF
C
C           initialize program variables
            CALL ZIPI (MXSIZE, I0, IYR)
            DO 25 I = 1, MXSIZE
              ABFW(I)=0.0
              AQW(I)=0.0
 25         CONTINUE
            DO 27 I = 1, 12
              MNCNT(I)=0
              MNTFL(I)=0.0
              MNTBF(I)=0.0
 27         CONTINUE
C
C           start loop for analyzing ea. yr. in current data set 
 30         CONTINUE
              IREC = IREC + 1
              IYR(IREC) = ENDPD(1)
C
C             get discharge data and computed baseflow
              CALL BSDATA (MESSFL, SCLU, WDMSFL, DSNBUF(DIND), IREC,
     I                     BGNEXT, ENDEXT, STCOMP, EDCOMP, BGNPD, ENDPD,
     I                     STREC, ENDREC, METH, DRAIN, STINTR, TU, TS,
     O                     INTRVL, NDAYS, LSTFLG, WDTRET)
C
              IF (UNITFG .EQ. 2) THEN
C               convert streamflow, base flow, and runoff to m3/s
                DO 40 I = 1, NDAYS
                  IF (DIS(I) .GE. 0) DIS(I) = DIS(I) * .02832
                  IF (GDIS(I) .GE. 0) GDIS(I) = GDIS(I) * .02832
                  IF (RUNOFF(I) .GE. 0) RUNOFF(I) = RUNOFF(I) * .02832
 40             CONTINUE
              END IF
C
              IF (WDTRET .NE. 0) THEN
C               error in getting data fr. WDM file
C               mod. annual streamflw/baseflw arr.s to indicate null yr
                AQW(IREC) = -1.0
                ABFW(IREC) = -1.0
              ELSE
C               if printing monthly summary open print file if not opened yet
                IF (PRTFLG.NE.0 .AND. PRTFUN.EQ.0) 
     $            CALL OPNFIL (BASLEN, BASNAM, DATTYP, SUFFIX,
     M                         PRTCNT,
     O                         PRTFUN)
C               calculate monthly info. on hyd separation
                CALL MONTH (STA, STAID, PRTFUN, UNITFG, ENGOPT, METH, 
     I                      INTRVL, DRAIN, IREC, ENDPD(1), PRTFLG, 
     I                      BGNMON, MXSIZE, 
     M                      ABFW, AQW, MNCNT, MNTFL, MNTBF)
                IF (PRTFLG .NE. 0) THEN
C                 calculate and output summary info. on hyd separation
                  CALL STAT (PRTFUN, PRTFLG, NDAYS, UNITFG, ENGOPT, 
     I                       DRAIN)
                END IF
C
                IF (HYDDEV(1).NE.0 .OR. HYDDEV(2).NE.0) THEN
C                 produce hydrograph 
                  CALL HYDPLT 
     I                       (MESSFL, SCLU, STA, METH, BASLEN, BASNAM, 
     I                        HYDDEV, MODOPT, NDAYS, BGNPD, TU, TS, 
     M                        UNITFG, HYD1, OTCNTR(2,4),
     O                        INTRPT)
                END IF
C
                IF (DURPRT.EQ.1 .OR.
     $              PLTDEV(1,2).NE.0 .OR. PLTDEV(2,2).NE.0) THEN
C                 count occurrences of flow for flow duration analysis
                  CALL FDCNT (NDAYS, NCI, FLCLAS,
     M                        NUMT, NUMD, NUMB, NMIS,
     O                        FMIN, FMAX)
                END IF
C
Cmyg            IF (.NOT. INTRPT) THEN
C                 continue
C                 give user progress report
                  CALL BSPROG (MESSFL, SCLU, HYDDEV, STAID, IREC, 
     I                         ENDPD(1), LSTFLG, SAVFLG, INTRPT)
                  IF (ROWAT.EQ.1 .OR. BFWAT.EQ.1) THEN
C                   save runoff and/or base flow to ASCII file
                    CALL WATSAV (MESSFL, SCLU, WDMSFL, ROWAT, BFWAT, 
     I                           ROWDM, BFWDM, IREC, BGNPD, ENDPD, 
     I                           DSNBUF(DIND), LSTFLG, BASLEN, 
     I                           BASNAM, 
     M                           WATCNT, WATOUT)
                  END IF
                  IF (ROWDM.EQ.1 .OR. BFWDM.EQ.1) THEN
C                   save runoff and/or base flow on user's WDM file
                    CALL WDMSAV (MESSFL, SCLU, WDMSFL, ROWDM, BFWDM, 
     I                           ROWAT, BFWAT, IREC, BGNPD, ENDPD(1), 
     I                           NDAYS, DSNBUF(DIND), LSTFLG)
                  END IF
C               end if (.not. intrpt)
Cmyg            END IF
              END IF
C
C             increment date variables for next 12-mo. pd. 2B analyzed
              BGNPD(1) = BGNPD(1) + 1
              ENDPD(1) = ENDPD(1) + 1
              BGNEXT(1) = BGNEXT(1) + 1
              ENDEXT(1) = ENDEXT(1) + 1
C
              CALL CKDATE (BGNPD, EDCOMP, DATFLG)
C             if BGNPD is the same as or .LT. EDCOMP, DATFLG will be .LE. 0
            IF (DATFLG.LE.0 .AND. (.NOT. INTRPT))  GOTO 30
C         end if (.not. exit)
          END IF
Cmyg    IF (INTRPT) GOTO 15
C
        IF (EXIT.EQ.0 .AND. .NOT.INTRPT) THEN
C         print annual summary to output file; open file if not opened yet
          IF (PRTFUN .EQ. 0) 
     $      CALL OPNFIL (BASLEN, BASNAM, DATTYP, SUFFIX,
     M                   PRTCNT,
     O                   PRTFUN)
          CALL ANNUAL (PRTFUN, FRQPRT, SEAPRT, MXSIZE, ABFW, AQW, 
     I                 UNITFG, ENGOPT, DRAIN, IREC, IYR, STA, STAID, 
     I                 BGNMON, ENDMON, METH, MNCNT, MNTFL, MNTBF,
     O                 FREQ, SRTQ, SRTBF, SRTDR, GIREC)
          IF (GIREC .GE. 1) THEN
            IF (DURPRT .EQ. 1) THEN
C             print flow duration table to output file
              CALL FDTABL (MESSFL, SCLU, STA, METH, IREC, IYR, NCI, 
     I                     FLCLAS, NUMT, NUMD, NUMB, PRTFUN)
            END IF
C           produce summary plots requested by user
            CALL BSPLOT 
     I                 (MESSFL, SCLU, STAID, STA, METH, DRAIN, BASLEN, 
     I                  BASNAM, PLTDEV, FRQOPT, DUROPT, SEAOPT, 
     I                  MODOPT, IREC, IYR, BGNMON, MXSIZE, FREQ, SRTQ, 
     I                  SRTBF, SRTDR, NCI, FLCLAS, NUMT, NUMD, NUMB, 
     I                  FMIN, FMAX, MNCNT, MNTFL, MNTBF, UNITFG, 
     M                  PLT1, OTCNTR)
C         end if (girec .ge. 1)
          END IF
        END IF
C       check for more datasets
        DIND = DIND + 1
      IF (DIND.LE.DSNCNT .AND. EXIT.NE.-1) GOTO 5
C
C     if print file was opened, close it
      IF (PRTFUN .NE. 0) CALL QFCLOS (PRTFUN, I0)
C
      RETURN
      END
C
C
C
      SUBROUTINE   BSDESC
     I                   (MESSFL, SCLU, WDMSFL, DSN,
     O                     DRAIN, STAID, STA)
C
C     + + + PURPOSE + + +
C     Get station name, station id, and drainage area from data set.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      MESSFL, SCLU, WDMSFL, DSN
      REAL         DRAIN
      CHARACTER*8  STAID
      CHARACTER*48 STA
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of message file
C     SCLU   - screen cluster number on message file
C     WDMSFL - Fortran unit number of wdm file
C     DSN    - data-set number
C     DRAIN  - drainage area
C     STAID  - station id
C     STA    - station name
C
C     + + + LOCAL VARIABLES + + +
      INTEGER   SAIND, SALEN, ID, RETC, LEN8, JUSTL, OLEN, SGRP
      CHARACTER*1  BUFF(48)
C
C     + + + EXTERNALS + + +
      EXTERNAL   WDBSGC, WDBSGI, WDBSGR
      EXTERNAL   INTCHR, CARVAR
      EXTERNAL   QRESPR
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  LEN8, JUSTL
     $     /   8,     1 /
C
C     + + + END SPECIFICATIONS + + +
C
C     get station name
      SAIND = 45
      SALEN = 48
      CALL WDBSGC (WDMSFL, DSN, SAIND, SALEN, BUFF, RETC)
      IF (RETC .EQ. 0) THEN
C       found station name
        CALL CARVAR (SALEN, BUFF, SALEN, STA)
      ELSE
C       no station name found
        STA = 'No station name found in input data'
      END IF
C
C     get station id number
      SAIND = 51
      SALEN = 1
      CALL WDBSGI (WDMSFL, DSN, SAIND, SALEN, ID, RETC)
      IF (RETC .EQ. 0) THEN
        CALL INTCHR (ID, LEN8, JUSTL, OLEN, BUFF)
        CALL CARVAR (OLEN, BUFF, LEN8, STAID)
      ELSE
        STAID = 'No ID   '
      END IF
C
C     get drainage area
      SAIND = 11
      SALEN = 1
      CALL WDBSGR (WDMSFL, DSN, SAIND, SALEN, DRAIN, RETC)
      IF (RETC .NE. 0) DRAIN = -999
C
      IF (DRAIN .LE. 0) THEN
C       missing drainage area
        SGRP = 61
        CALL QRESPR (MESSFL, SCLU, SGRP, DRAIN)
      END IF
C
      RETURN
      END
C
C
C
      SUBROUTINE   GTINFO
     I                   (MESSFL, SCLU, WDMSFL, DSN, STAID, BASLEN,
     M                    BASNAM, 
     O                    STREC, ENDREC, DATE, EXIT)
C
C     + + + PURPOSE + + +
C     Prompts the user for basename to be used in all output files for 
C     this DSN; prompts for dates for analysis.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      MESSFL, SCLU, WDMSFL, DSN, BASLEN, STREC(6),
     $             ENDREC(6), DATE(6), EXIT
      CHARACTER*1  BASNAM(BASLEN)
      CHARACTER*8  STAID
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of message file
C     SCLU   - screen cluster number on message file
C     WDMSFL - Fortran unit number of wdm file
C     DSN    - data-set number
C     STAID  - station id
C     BASLEN - length of basename
C     BASNAM - basename for output files, can be up to BASLEN char.s 
C              long; an extension will be added to basename for each 
C              output file produced for this DSN
C     STREC  - start date of period of data available on data set
C     ENDREC - end date of period of data available on data set
C     DATE   - dates for analysis
C              DATE(1:3) - start yr/mo/dy, DATE(4:6) - end yr/mo/dy
C     EXIT   - exit flag
C              -1 - user chose 'Interrupt', exit execution loop
C              -2 - could not get start/end dates for this DSN, skip it
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I0, I1, I3, SGRP, INUM, IVAL(6), CIND, IRET, 
     $             MAXLIN, SCINIT, IWRT, CMDID, GPFLG, TDSFRC, RETCOD
      CHARACTER*8  WINARR(1)
C
C     + + + EXTERNALS + + +
      EXTERNAL WTFNDT, PMXTXI, COPYI, ZSTCMA, ZWNSOP
      EXTERNAL Q1INIT, QSTCTF, QSETI, Q1EDIT, QGTCTF, QGETI
C
C     + + + END SPECIFICATIONS + + +
C
      I0 = 0
      I1 = 1
      I3 = 3
C     allow 'Interrupt' command
      CMDID = 16
      CALL ZSTCMA (CMDID, I1)
C
C     get period of available data
      GPFLG = 1
      CALL WTFNDT (WDMSFL, DSN, GPFLG,
     O             TDSFRC, STREC, ENDREC, RETCOD)
      IF (RETCOD .NE. 0) THEN
C       error in determining starting and ending dates of data--
C       instruct user to not include this DSN in buffer
        MAXLIN = 1
        SCINIT = 1
        IWRT = 0
        INUM = 1
        IVAL(1) = DSN
        SGRP = 74
        CALL PMXTXI (MESSFL, SCLU, SGRP, MAXLIN, SCINIT, IWRT,
     I               INUM, IVAL)
        EXIT = -2
      ELSE
 10     CONTINUE
C         initialize basename/dates screen; place station id in window name
          WINARR(1) = STAID
          CALL ZWNSOP (I1, WINARR)
          SGRP = 62
          CALL Q1INIT (MESSFL, SCLU, SGRP)
C
C         set default values for screen
          CIND = 1
          CALL QSTCTF (CIND, BASLEN, BASNAM)
          INUM = 6
          CALL COPYI (I3, STREC, IVAL)
          CALL COPYI (I3, ENDREC, IVAL(4))
          CALL QSETI (INUM, IVAL)
C
C         allow user to edit screen
          CALL Q1EDIT (IRET)
C
C       if user chose 'Oops' redraw screen
        IF (IRET .EQ. -1) GOTO 10
C
        IF (IRET .EQ. 7) THEN
C         user chose 'Interrupt'
          EXIT = -1
        ELSE
          EXIT = 0
C         get values from screen
          CALL QGTCTF (CIND, BASLEN,
     O                 BASNAM)
          CALL QGETI (INUM,
     O                DATE)
        END IF
      END IF
C
C     turn 'Interrupt' off
      CALL ZSTCMA (CMDID, I0)
C
      RETURN
      END
C
C
C
      INTEGER   FUNCTION   CHKNAM
     I                           (NAMLEN, FILNAM)
C
C     + + + PURPOSE + + +
C     ** SHOULD CKNAME IN qtfile.f BE USED INSTEAD??? **
C
C     Checks if filename is valid.  
C     Values returned:
C       0 - filename valid
C      -1 - file already exists
C     >=1 - filename invalid; actual value returned is error number 
C           returned by INQUIRE or OPEN
C
C     Note that if file already exists, it may still be the case that
C     user does not currently have write access for given filename 
C     or that filename is actually a directory name.  If file exists, 
C     then at point in code where file would be written to, programmer
C     needs to include error-checking for these two cases.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER     NAMLEN
      CHARACTER*1 FILNAM(NAMLEN)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     NAMLEN - length of filename
C     FILNAM - filename
C
C     + + + PARAMETERS + + +
      INCLUDE 'pbasln.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER            I1, I2, IOERR, RETVAL, UNITNO
      CHARACTER*(BSLNMX) FILSTR
      LOGICAL            FLEXST
C
C     + + + EXTERNALS + + +
      EXTERNAL  CARVAR, GETFUN
C
C     + + + END SPECIFICATIONS + + +
C
      I1 = 1
      I2 = 2
C
C     convert FILNAM from array to string
      CALL CARVAR (NAMLEN, FILNAM, NAMLEN, FILSTR)
C     check if file exists w/ same name as FILNAM
      INQUIRE (FILE=FILSTR, EXIST=FLEXST, IOSTAT=IOERR)
C
      IF (IOERR .NE. 0) THEN
C       error occurred during INQUIRE
        RETVAL = IOERR
      ELSE IF (FLEXST) THEN
C       file exists w/ same name
        RETVAL = -1
      ELSE
C       attempt to open file; INQUIRE will not return an error in some
C       cases when OPEN will fail, also need to check write access
        CALL GETFUN (I1, UNITNO)
        OPEN (UNIT=UNITNO, FILE=FILSTR, STATUS='NEW', IOSTAT=IOERR)
        IF (IOERR .NE. 0) THEN
C         file name invalid or no write access
          RETVAL = IOERR
        ELSE
C         file name valid
          RETVAL = 0
          CLOSE (UNIT=UNITNO, STATUS='DELETE')
C         free up Fortran unit number
          CALL GETFUN (I2, UNITNO)
        END IF
      END IF
C
      CHKNAM = RETVAL
C
      RETURN
      END
C
C
C
      SUBROUTINE   BSDATE
     I                   (MESSFL, SCLU, STREC, ENDREC, DATE, BGNMON, 
     O                    ENDMON, STCOMP, EDCOMP, BGNPD, ENDPD, 
     O                    BGNEXT, ENDEXT, AGAIN)
C
C     + + + PURPOSE + + +
C     Checks dates entered by user for period to be analyzed.  Finds 
C     bounding dates of initial 12-mo. period for analysis within 
C     period of record.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   MESSFL, SCLU, STREC(6), ENDREC(6), DATE(6), BGNMON, 
     $          ENDMON, STCOMP(6), EDCOMP(6), BGNPD(6), ENDPD(6), 
     $          BGNEXT(6), ENDEXT(6)
      LOGICAL   AGAIN
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of the message file
C     SCLU   - screen cluster number on message file
C     STREC  - start date of period of data available on DSN
C     ENDREC - end date of period of data available on DSN
C     DATE   - dates for analysis specified by user
C              DATE(1:3) - start yr/mo/dy, DATE(4:6) - end yr/mo/dy
C     BGNMON - beginning month of annual summary year
C     ENDMON - ending month of annual summary year
C     STCOMP - start date of period to be analyzed
C     EDCOMP - end date of period to be analyzed
C     BGNPD  - start of initial 12-mo. pd. to be analyzed
C     ENDPD  - end of initial 12-mo. pd. to be analyzed
C     BGNEXT - start of initial 12-mo. pd. to be analyzed minus 11 days
C     ENDEXT - end of initial 12-mo. pd. to be analyzed plus 11 days
C     AGAIN  - Boolean flag
C              .TRUE. - user entered invalid date, display date screen again
C
C     + + + LOCAL VARIABLES + + +
      INTEGER   I0, I3, I6, SGRP, YEARS, DATE1(6), DATE2(6), BGNYR(6), 
     $          ENDYR(6), BGNFLG, ENDFLG, TU, TS, DATFLG, TOTDAY
C
C     + + + FUNCTIONS + + +
      INTEGER  DAYMON
C
C     + + + EXTERNALS + + +
      EXTERNAL   WTFNDT, PRNTXT, PMXTXI, ZIPI, DAYMON
      EXTERNAL   COPYI, CKDATE, TIMDIF, ZSTCMA, BSYEAR
C
C     + + + END SPECIFICATIONS + + +
C
      I0 = 0
      I3 = 3
      I6 = 6
C
C     set DATE1/DATE2 equal to the start/end dates spec'd. by user
      CALL COPYI (I6, DATE, DATE1)
      CALL ZIPI (I3, I0, DATE1(4))
      CALL COPYI (I3, DATE(4), DATE2)
      DATE2(4) = 24
      DATE2(5) = 0
      DATE2(6) = 0
C     how many days in user-specified period?
      TU = 4
      TS = 1
      CALL TIMDIF (DATE1, DATE2, TU, TS, TOTDAY)
C
C     determine ending month of user-specified year
      ENDMON = BGNMON + 11
      IF (ENDMON .GT. 12)  ENDMON = ENDMON - 12
C
C     init. BGNYR/ENDYR to begin./end of the annual summary yr;
C     use BGNYR/ENDYR to determine if user has spec'd begin/ending
C     dates outside start or end of the annual summary yr--partial
C     years of data would then be included in analysis
      CALL COPYI (I6, DATE1, BGNYR)
      BGNYR(2) = BGNMON
      BGNYR(3) = 1
      CALL COPYI (I6, DATE2, ENDYR)
      ENDYR(2) = ENDMON
      ENDYR(3) = DAYMON(DATE2(1), ENDMON)
      CALL CKDATE (DATE1, BGNYR, BGNFLG)
      CALL CKDATE (ENDYR, DATE2, ENDFLG)
C
C     set time unit to years, time step to 1
      TU = 6
      TS = 1
      CALL CKDATE (DATE1, DATE2, DATFLG)
      CALL TIMDIF (DATE1, DATE2, TU, TS, YEARS)
      IF (DATFLG .GE. 0) THEN
C       invalid pd. specified--end date occurs before start date 
C       or start and end date are identical
        AGAIN = .TRUE.
        SGRP = 76
        CALL PRNTXT (MESSFL, SCLU, SGRP)
      ELSE IF ( (YEARS .GT. 100) .OR.
     $        (YEARS.EQ.99 .AND. BGNFLG.EQ.-1 .AND. ENDFLG.EQ.-1) .OR.
     $        (YEARS.EQ.100 .AND. (BGNFLG.EQ.-1.OR.ENDFLG.EQ.-1)) ) THEN
C       maximum no. of yr.s exceeded by user specifying more than 
C       the max or by specifying 99 or 100 complete years along w/
C       partial years of data at the begining and/or at the end
        AGAIN = .TRUE.
        SGRP = 77
        CALL PRNTXT (MESSFL, SCLU, SGRP)
      ELSE IF ((DATE(1).LT.STREC(1) .OR. DATE(4).GT.ENDREC(1)) .OR.
C       check case where years OK but months out of range
     $        ( (DATE(1).EQ.STREC(1) .AND. DATE(2).LT.STREC(2)) .OR.
     $        (DATE(4).EQ.ENDREC(1) .AND. DATE(5).GT.ENDREC(2)) )) THEN
C       date(s) outside of available period
        AGAIN = .TRUE.
        SGRP = 73
        CALL PRNTXT ( MESSFL, SCLU, SGRP )
      ELSE IF ( DATE(3) .GT. DAYMON(DATE(1),DATE(2)) .OR.
     $          DATE(6) .GT. DAYMON(DATE(4),DATE(5)) ) THEN
C       day doesn't exist for month selected--must be corrected
        AGAIN = .TRUE.
        SGRP = 72
        CALL PRNTXT (MESSFL, SCLU, SGRP)
      ELSE IF (TOTDAY .LT. 365) THEN
C       specified period shorter than 1 year
        AGAIN = .TRUE.
        SGRP = 85
        CALL PRNTXT (MESSFL, SCLU, SGRP)
      ELSE
C       all ok
        AGAIN = .FALSE.
      END IF
C
      IF (.NOT. AGAIN) THEN
C       set year, month, day
        STCOMP(1) = DATE(1)
        STCOMP(2) = DATE(2)
        STCOMP(3) = DATE(3)
        EDCOMP(1) = DATE(4)
        EDCOMP(2) = DATE(5)
        EDCOMP(3) = DATE(6)
C
C       set hours, minutes, and seconds
        STCOMP(4) = 0
        STCOMP(5) = 0
        STCOMP(6) = 0
        EDCOMP(4) = 24
        EDCOMP(5) = 0
        EDCOMP(6) = 0
C
C       get dates bounding initial 12-mo. pd. to be analyzed
        CALL BSYEAR (STCOMP, BGNMON, ENDMON,
     O               BGNPD, ENDPD, BGNEXT, ENDEXT)
      END IF
C
      RETURN
      END
C
C
C
      SUBROUTINE   BSYEAR
     I                   (STCOMP, BGNMON, ENDMON,
     O                    BGNPD, ENDPD, BGNEXT, ENDEXT)
C
C     + + + PURPOSE + + +
C     Determines dates bounding initial 12-mo. period to be analyzed 
C     (BGNPD and ENDPD).  The output arguments BGNEXT and ENDEXT bound 
C     the same period extended by 11 days at beginning and end.  The 
C     extra days increase the accuracy of baseflow computation at the 
C     start and end of the period.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   STCOMP(6), BGNMON, ENDMON, BGNPD(6), ENDPD(6), 
     $          BGNEXT(6), ENDEXT(6)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     STCOMP - start of pd. of record to be analyzed, as spec'd. by user
C     BGNMON - beginning month of annual summary year
C     ENDMON - ending month of annual summary year
C     BGNPD  - start of initial 12-mo. pd. to be analyzed
C     ENDPD  - end of initial 12-mo. pd. to be analyzed
C     BGNEXT - start of initial 12-mo. pd. to be analyzed minus 11 days
C     ENDEXT - end of initial 12-mo. pd. to be analyzed plus 11 days
C
C     + + + LOCAL VARIABLES + + +
      INTEGER   I, I6, I11, TU, TS
C
C     + + + FUNCTIONS + + +
      INTEGER   DAYMON
C
C     + + + EXTERNALS + + +
      EXTERNAL  COPYI, DAYMON, TIMADD, TIMBAK
C
C     + + + END SPECIFICATIONS + + +
C
      I6 = 6
      I11 = 11
C
      CALL COPYI (I6, STCOMP, BGNEXT)
C     if beginning mo. of annual summaries is later than beg. of data 
C     specified by user, move back one year to include data B4 BGNMON
      IF (BGNMON .GT. BGNEXT(2))  BGNEXT(1) = BGNEXT(1) - 1
      BGNEXT(2) = BGNMON
      BGNEXT(3) = 1
C     initialize beginning of period marker
      CALL COPYI (I6, BGNEXT, BGNPD)
C     find date corresponding to end of year which begins w/ BGNMON
      IF (BGNMON .EQ. 1) THEN
C       annual summary yr starts in Jan. and thus ends during same year
        ENDPD(1) = BGNPD(1)
      ELSE
C       ann. summary yr starts later than Jan. and thus ends following yr
        ENDPD(1) = BGNPD(1) + 1
      END IF
      ENDPD(2) = ENDMON
      ENDPD(3) = DAYMON(ENDPD(1), ENDMON)
      ENDPD(4) = 24
      ENDPD(5) = 0
      ENDPD(6) = 0
C
C     set time unit to days, time step to 1
      TU = 4
      TS = 1
C     back up 11 days from beginning of year
      DO 20 I = 1, 11
        CALL TIMBAK (TU, BGNEXT)
 20   CONTINUE
C     add 11 days to end of year
      CALL TIMADD (ENDPD, TU, TS, I11, ENDEXT)
C
      RETURN
      END
C
C
C
      LOGICAL   FUNCTION   NAMCHG
     I                           (NAMLEN, OLDNAM, NEWNAM)
C
C     + + + PURPOSE + + +
C     Checks file names passed in to see if are the same.  If file 
C     names differ, NAMCHG returns .TRUE.  Preceding and following 
C     spaces are not taken into account.  Maximum file name length 
C     is assumed to be 64 characters.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      NAMLEN
      CHARACTER*1  OLDNAM(NAMLEN), NEWNAM(NAMLEN)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     NAMLEN - length of file names
C     OLDNAM - original file name 
C     NEWNAM - latest file name; compared against original name
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, I1, OLDLN, NEWLN
      CHARACTER*1  TMPNAM(64)
C
C     + + + FUNCTIONS + + +
      INTEGER   LENSTR, STRFND
C
C     + + + EXTERNALS + + +
      EXTERNAL  CHRCHR, LENSTR, STRFND, CHRDEL
C
C     + + + END SPECIFICATIONS + + +
C
      I1 = 1
C
      CALL CHRCHR (NAMLEN, NEWNAM, TMPNAM)
      DO 10 I = NAMLEN+1, 64
        TMPNAM(I) = ' '
 10   CONTINUE
C
C     remove any leading blanks from file name
 20   CONTINUE
        IF (TMPNAM(1) .EQ. ' ')  CALL CHRDEL (NAMLEN, I1, TMPNAM)
      IF (TMPNAM(1) .EQ. ' ') GOTO 20
C
      OLDLN = LENSTR (NAMLEN, OLDNAM)
      NEWLN = LENSTR (NAMLEN, TMPNAM)
C
      IF ((NEWLN .EQ. OLDLN) .AND.
     $    (STRFND(OLDLN, OLDNAM, NEWLN, TMPNAM) .EQ. 1)) THEN
        NAMCHG = .FALSE.
      ELSE
        NAMCHG = .TRUE.
      END IF
C
      RETURN
      END
C
C
C
      SUBROUTINE   BSDATA 
     I                   (MESSFL, SCLU, WDMSFL, DSN, IREC, BGNEXT,
     I                    ENDEXT, STCOMP, EDCOMP, BGNPD, ENDPD, 
     I                    STREC, ENDREC, METH, DRAIN, STFIX, TU, TS,
     O                    INTRVL, NDAYS, LSTFLG, WDTRET) 
C
C     + + + PURPOSE + + +
C     This routine gets the discharge data from the WDM file and
C     computes the base flow and surface runoff.  One year of data is 
C     retrieved and processed.  The 1-year period is extended by 11 
C     days at the beginning and end to increase the accuracy of base-
C     flow computation at the start and end of the period. Thus, 388 
C     values are retrieved into a buffer, baseflow separation is per-
C     formed and dischage data and base flow are stored in the 2 366-
C     element output arrays.  Surface runoff is then calculated.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   MESSFL, SCLU, WDMSFL, DSN, IREC, BGNEXT(6), ENDEXT(6), 
     $          STCOMP(6), EDCOMP(6), BGNPD(6), ENDPD(6), STREC(6), 
     $          ENDREC(6), METH, STFIX, TU, TS, INTRVL, NDAYS, LSTFLG, 
     $          WDTRET
      REAL      DRAIN
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of message file
C     SCLU   - screen cluster number w/in message file
C     WDMSFL - Fortran unit number of WDM file
C     DSN    - data-set number of data being retrieved
C     IREC   - order no. of year of data w/in period specified by user
C     BGNEXT - start date of data being retrieved
C     ENDEXT - end date of data being retrieved
C     STCOMP - start date for analysis, yr/mon/dy/hr/min/sec
C     EDCOMP - end date for analysis, yr/mon/dy/hr/min/sec
C     BGNPD  - start date for year being analyzed, yr/mon/dy/hr/min/sec
C     ENDPD  - end date for year being analyzed, yr/mon/dy/hr/min/sec
C     STREC  - start date of period of data available on data set
C     ENDREC - end date of period of data available on data set
C     METH   - separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local minimum
C     DRAIN  - drainage area
C     STFIX  - variable specific to fixed separation method:  position 
C              (day) in DIS where initial interval should begin (index 
C              of last processed value/last bad value)
C     TU     - time units (1-sec, 2-min, 3-hour, 4-day....)
C     TS     - time step in TU units
C     INTRVL - interval, in days, used in hydrograph separation
C     NDAYS  - number of days in year being processed
C     LSTFLG - flag indicating if year to save is last one
C              1 - last year
C             -1 - not last year
C     WDTRET - error returned from WDTGET if couldn't retrieve data
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'chysep.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER   I, I6, L366, L388, SGRP, DTRAN, QFLG, TMPDAT(6), INUM, 
     $          IVAL(3), MAXLIN, SCINIT, IWRT, IBEFOR, IAFTER, 
     $          BGNDAT(6), ENDDAT(6), PREVDY, DAYAFT, DAY1, LSTDAY, 
     $          NVAL, DAYDIF
      REAL      NULL, DBUF(388), GBUF(388)
C
C     + + + EXTERNALS + + +
      EXTERNAL   WDTGET, TIMDIF, CKDATE, TIMADD, TIMBAK
      EXTERNAL   BSCOMP
      EXTERNAL   ZIPR, COPYI, COPYR, PMXTXI
C
C     + + + END SPECIFICATIONS + + +
C
      I6 = 6
      NULL = -999.
      L366 = 366
      L388 = 388
      IBEFOR = 0
      IAFTER = 0
C
C     zip out streamflow/baseflow arrays and buffers
      CALL ZIPR (L366, NULL, DIS)
      CALL ZIPR (L388, NULL, DBUF)
      CALL ZIPR (L366, NULL, GDIS)
      CALL ZIPR (L388, NULL, GBUF)
C     zip out surface runoff array
      CALL ZIPR (L366, NULL, RUNOFF)
C
C     get number of days in year including extra days at begin/end
      CALL TIMDIF (BGNEXT, ENDEXT, TU, TS, NDAYS)
C
      CALL COPYI (I6, BGNEXT, BGNDAT)
      CALL COPYI (I6, ENDEXT, ENDDAT)
      DAY1 = 1
C
      IF (IREC .EQ. 1) THEN
C       1st year to analyze in current data set
        CALL CKDATE (STCOMP, BGNPD, IBEFOR)
        IF (IBEFOR .GE. 0) THEN
C         BGNPD <= STCOMP; see how many days of data exist prior to STCOMP
          CALL TIMDIF (STREC, STCOMP, TU, TS, PREVDY)
C         if >11 days exist, reset PREVDY to retrieve max of 11 days prior to STCOMP
          IF (PREVDY .GT. 11) PREVDY = 11
          CALL COPYI (I6, STCOMP, BGNDAT)
C         back up PREVDY days from user-specified date
          DO 10 I = 1, PREVDY
            CALL TIMBAK (TU, BGNDAT)
 10       CONTINUE
          CALL TIMDIF (BGNEXT, BGNDAT, TU, TS, DAYDIF)
          DAY1 = DAYDIF + 1
        END IF
      END IF
C
C     check if current year is last yr for data set in pd specified by user
      CALL COPYI (I6, BGNPD, TMPDAT)
      TMPDAT(1) = TMPDAT(1) + 1
      CALL CKDATE (TMPDAT, EDCOMP, LSTFLG)
C
      IF (LSTFLG .EQ. 1) THEN
C       last yr to analyze in current data set
        CALL CKDATE (ENDPD, EDCOMP, IAFTER)
        IF (IAFTER .GE. 0) THEN
C         EDCOMP <= ENDPD; see how many days of data exist after EDCOMP
          CALL TIMDIF (EDCOMP, ENDREC, TU, TS, DAYAFT)
C         if >11 days exist, reset DAYAFT to retrieve max of 11 days after EDCOMP
          IF (DAYAFT .GT. 11) DAYAFT = 11
C         add DAYAFT days to user-specified end date
          CALL TIMADD (EDCOMP, TU, TS, DAYAFT, ENDDAT)
        END IF
      END IF
C
C     how many days of data to retrieve?
      CALL TIMDIF (BGNDAT, ENDDAT, TU, TS, NVAL)
C
C     get discharge data from WDM file
      DTRAN = 0
      QFLG = 30
      CALL WDTGET (WDMSFL, DSN, TS, BGNDAT, NVAL, DTRAN, QFLG, TU,
     O             DBUF(DAY1), WDTRET)
C
      IF (WDTRET .NE. 0) THEN
C       error in getting timeseries data from WDM file
        INUM = 3
        IVAL(1) = DSN 
        IVAL(2) = ENDPD(1)
        IVAL(3) = WDTRET
        MAXLIN = 5
        SCINIT = 1
        IWRT = 0
        SGRP = 79
        CALL PMXTXI (MESSFL, SCLU, SGRP, MAXLIN, SCINIT, IWRT,
     $               INUM, IVAL)
      ELSE
C       compute baseflow
        CALL BSCOMP (METH, NDAYS, DRAIN, DBUF, LSTFLG,
     M               STFIX,
     O               INTRVL, GBUF)
C
C       if 1st year partial, zip out 11-or-less-day interval B4 STCOMP
        IF (IBEFOR.EQ.1 .AND. PREVDY.GT.0) THEN
          CALL ZIPR (PREVDY, NULL, DBUF(DAY1))
          CALL ZIPR (PREVDY, NULL, GBUF(DAY1))
        END IF
C
C       if last year partial, zip out 11-or-less-day interval after EDCOMP
        IF (IAFTER.EQ.1 .AND. DAYAFT.GT.0) THEN
          CALL TIMDIF (BGNEXT, EDCOMP, TU, TS, LSTDAY)
          CALL ZIPR (DAYAFT, NULL, DBUF(LSTDAY+1))
          CALL ZIPR (DAYAFT, NULL, GBUF(LSTDAY+1))
        END IF
C
        NDAYS = NDAYS - 22
        CALL COPYR (NDAYS, DBUF(12), DIS(1))
        CALL COPYR (NDAYS, GBUF(12), GDIS(1))
        DO 50 I = 1, NDAYS
          IF (DIS(I).GE.0 .AND. GDIS(I).GE.0) THEN
            RUNOFF(I) = DIS(I) - GDIS(I)
          ELSE
            RUNOFF(I) = -999.0
          END IF
 50     CONTINUE
      END IF      
C
      RETURN
      END
C
C
C
      SUBROUTINE   BSCOMP 
     I                   (METH, NDAYS, DRAIN, SFBUFF, LSTFLG,
     M                    STFIX,
     O                    INTRVL, BFBUFF) 
C
C     + + + PURPOSE + + +
C     Calls routines to perform base-flow computation.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   METH, NDAYS, LSTFLG, STFIX, INTRVL
      REAL      DRAIN, SFBUFF(388), BFBUFF(388)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     METH   - baseflow separation method
C              1 - fixed interval
C              2 - sliding interval
C              3 - local mininum
C     NDAYS  - number of days in period being processed
C     DRAIN  - drainage area
C     SFBUFF - array of daily streamflow values
C     LSTFLG - flag set equal to 1 if last year being processed
C     STFIX  - index necess. for fixed interval mtd., indicates position
C              w/in SFBUFF array where baseflow separation should start
C     INTRVL - interval, in days, used in separation methods
C     BFBUFF - array of computed baseflow values
C
C     + + + LOCAL VARIABLES + + +
      REAL      RINTR
C
C     + + + EXTERNALS + + +
      EXTERNAL  FIXED, SLIDE, LOCMIN
C
C     + + + END SPECIFICATIONS + + +
C
Cmyg  IF (METH .LE. 3) THEN
C       set interval, in days, for separation methods
        RINTR = DRAIN**0.2
        RINTR = RINTR*2.0
        IF (RINTR .LE. 4.0) THEN
          INTRVL = 3
        ELSE IF (RINTR .LE. 6.0  .AND.  RINTR .GT. 4.0) THEN
          INTRVL = 5
        ELSE IF (RINTR .LE. 8.0  .AND.  RINTR .GT. 6.0) THEN
          INTRVL = 7
        ELSE IF (RINTR .LE. 10.  .AND.  RINTR .GT. 8.0) THEN
          INTRVL = 9
        ELSE
          INTRVL = 11
        END IF
Cmyg  ELSE
C       force interval to zero
Cmyg    INTRVL = 0
Cmyg  END IF
C
C     perform baseflow separation
      IF (METH .EQ. 1) THEN
C       Fixed interval method
        CALL FIXED (NDAYS, SFBUFF, INTRVL, LSTFLG,
     M              STFIX,
     O              BFBUFF)
      ELSE IF (METH .EQ. 2) THEN
C       Sliding interval method
        CALL SLIDE (NDAYS, SFBUFF, INTRVL,
     O              BFBUFF)
      ELSE IF (METH .EQ. 3) THEN
C       Local minimum method
        CALL LOCMIN (NDAYS, SFBUFF, INTRVL,
     O               BFBUFF)
      END IF
C
      RETURN
      END
C
C
C
      SUBROUTINE   BSPROG
     I                   (MESSFL, SCLU, HYDDEV, STAID, YRINDX, 
     I                    ENDYR, LSTFLG, SAVFLG, INTRPT)
C
C     + + + PURPOSE + + +
C     Writes progress report to screen on data processed.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER     MESSFL, SCLU, HYDDEV(2), YRINDX, ENDYR, LSTFLG, SAVFLG
      CHARACTER*8 STAID
      LOGICAL     INTRPT
C
C     + + + ARGUMENT DEFINITIONS + + +
C     MESSFL - Fortran unit number of message file
C     SCLU   - message file screen cluster number
C     HYDDEV - array of output devices for hydrograph
C     STAID  - station id. number of data being processed
C     YRINDX - index of which year being processed
C     ENDYR  - ending year of current period of data being processed
C     LSTFLG - flag indicating if current year is last year processed
C              1 - last year
C     SAVFLG - flag indicating data will be save to WATSTORE or WDM file
C     INTRPT - Boolean flag, indicates if user chose 'Intrpt' command
C              to halt plotting/processing of current data set
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I0, I1, ICMD, IRET, L8, SGRP, INUM, IVAL(1), MAXLIN, 
     $             IWRT, SCINIT
      CHARACTER*48 WNAME
C
C     + + + INTRINSICS + + +
      INTRINSIC    MOD
C
C     + + + EXTERNALS + + +
      EXTERNAL     CHRCHR, LENSTR
      EXTERNAL     PMXTXI, ZWNSET, ZSTCMA, ZGTRET
C
C     + + + END SPECIFICATIONS + + +
C
      I0 = 0
      I1 = 1
      MAXLIN = 10
      INUM = 1
      IVAL(1) = ENDYR
      INTRPT = .FALSE.
C
      IF (HYDDEV(1).EQ.1 .OR. HYDDEV(2).EQ.1) THEN
C       hydrograph drawn to screen--give separate report for each year
C       make 'Intrpt' available
        ICMD = 16
        CALL ZSTCMA (ICMD, I1)
        SCINIT = 1
        IWRT = 0
        SGRP = 66
        CALL PMXTXI (MESSFL, SCLU, SGRP, MAXLIN, SCINIT,
     I               IWRT, INUM, IVAL)
C       get screen exit status code
        CALL ZGTRET (IRET)
C       if user chose 'Intrpt', set flag
        IF (IRET .EQ. 7) INTRPT = .TRUE.
C       disable 'Intrpt'
        CALL ZSTCMA (ICMD, I0)
      ELSE
        IF (YRINDX .EQ. 1) THEN
C         1st yr. for current data set, clear screen
          SCINIT = 1
C         set window name, show which data set being processed
          WNAME = 'Execute (E) progress report for station       '
          L8 = 8
          CALL CHRCHR (L8, STAID, 
     O                 WNAME(41:48))
          CALL ZWNSET (WNAME)
        ELSE
C         don't clear screen--add to msg.s previously written
          SCINIT = -1
        END IF
        IF (MOD(YRINDX,2).EQ.1 .OR. LSTFLG.EQ.1) THEN
C         print msg. only for every other year and last year
          IWRT = 1
C         if last year and no data will be saved to WATSTORE or WDM
C         files, write message and wait for user acknowledgement
          IF (LSTFLG.EQ.1 .AND. SAVFLG.EQ.0) IWRT = 0
          SGRP = 65
          CALL PMXTXI (MESSFL, SCLU, SGRP, MAXLIN, SCINIT,
     I                 IWRT, INUM, IVAL)
        END IF
      END IF
C
      RETURN
      END
