C
C
C
      SUBROUTINE   WTPRT2
     I                   ( WDMFL, DSN,
     O                     CARD2, FLAG )
C
C     + + + PURPOSE + + +
C     This routine is used to retrieve from a WDM DSN the attributes
C     needed for the WATSTORE daily and unit values card type 2.  The
C     following are retrieved:
C                                  attribute
C          field   field name       #  name
C          -----   --------------  -- ------
C           2-15   station id       2 STAID    first choice
C                                  51 ISTAID   second choice
C          29-33   parm code       56 PARMCD
C          34-38   statistic code  57 STATCD
C
C     This routine is nearly identical to OTWAT2 in the IOWDM code
C     group OTWDM.  The character used in column 6 for continuation
C     was changed from "#" to "$."
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER   WDMFL, DSN, FLAG
      CHARACTER*1 CARD2(80)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     WDMFL  - Fortran unit number of WDM file
C     DSN    - requested data-set number
C     CARD2  - character array containing the WATSTORE card type 2
C     FLAG   - flag indicating availability of data
C              0 - found all information
C              1 - found some information
C              2 - found no information
C
C     + + + LOCAL VARIABLES + + +
      INTEGER   AI(4), AL(4), TEMP, JUSTL, JUSTR, JLEN, RET,
     $          LEN5, LEN15, LEN79
      CHARACTER*1 BLNK, CTMP(16)
C
C     + + + EXTERNALS + + +
      EXTERNAL   ZIPC, WDBSGC, WDBSGI, INTCHR, CHRCHR
C
C     + + + DATA INITIALIZATIONS + + +
C                staid istaid parmcd statcd
      DATA  AI /     2,    51,    56,    57 /,
     $      AL /    16,     1,     1,     1 /
      DATA  BLNK, LEN5, LEN15, LEN79, JUSTL, JUSTR
     $     / ' ',    5,    15,    79,     1,     0 /
C
C     + + + END SPECIFICATIONS + + +
C
      CARD2(1) = '2'
      FLAG = 0
      CALL ZIPC ( LEN79, BLNK, CARD2(2) )
C
C     get station id, try character first
      CALL WDBSGC ( WDMFL, DSN, AI(1), AL(1), CTMP, RET )
      IF (RET .EQ. 0) THEN
C       found character station id, make sure col 17 is blank
        CALL CHRCHR ( LEN15, CTMP, CARD2(2) )
      ELSE
C       try for integer station id
        CALL WDBSGI ( WDMFL, DSN, AI(2), AL(2), TEMP, RET )
        IF (RET .EQ. 0) THEN
C         convert integer station id to character string
          CALL INTCHR ( TEMP, LEN15, JUSTL, JLEN, CARD2(2) )
        ELSE
C         found no station, leave field blank
          CALL ZIPC ( LEN15, BLNK, CARD2(2) )
          FLAG = FLAG + 1
        END IF
      END IF
C
C     get parameter code
      CALL WDBSGI ( WDMFL, DSN, AI(3), AL(3), TEMP, RET )
      IF (RET .EQ. 0) THEN
C       convert parameter code to character
        CALL INTCHR ( TEMP, LEN5, JUSTR, JLEN, CARD2(29) )
      ELSE
        FLAG = FLAG + 1
      END IF
C
C     get statistic code
      CALL WDBSGI ( WDMFL, DSN, AI(4), AL(4), TEMP, RET )
      IF (RET .EQ. 0) THEN
C       convert statistic code to character
        CALL INTCHR ( TEMP, LEN5, JUSTR, JLEN, CARD2(34) )
      ELSE
        FLAG = FLAG + 1
      END IF
C
      IF (FLAG .GE. 1  .AND.  FLAG .LE. 2) THEN
C       missing some information
        FLAG = 1
      ELSE IF (FLAG .EQ. 3) THEN
C       missing all information
        FLAG = 2
      END IF
      RETURN
      END
C
C
C
      SUBROUTINE   WTPRT3
     I                    ( OT, IREC, DATE, NDP, NSIG, RVAL,
     I                      CARD2, FLAG )
C
C     + + + PURPOSE + + +
C     This routine is used to output time series to WATSTORE daily 
C     values card type 3 format.  This routine is a variation of
C     OTWAT3 in IOWDM code group OTWDM.  Time-series values are no
C     longer retrieved from the WDM file but are passed in via the
C     RVAL dummy argument.  Any values less than zero are considered
C     to represent missing values.  This routine no longer loops through
C     years of data and only deals with the data passed to it in
C     RVAL, which may be a year's worth of values or less.  The values
C     are also cycled through according to the dates passed in DATE,
C     rather than processing the data by calendar year.  Error messages
C     related to WDM retrievel and the progress report message have
C     been omitted.  The names of some variables have been modified to
C     be more descriptive of their purpose.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER      OT, IREC, DATE(12), NDP, NSIG, FLAG
      REAL         RVAL(366)
      CHARACTER*1  CARD2(80)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     OT     - Fortran unit number of output file
C     IREC   - order no. of year of data w/in period being processed
C     DATE   - array containing the requested begin and end dates
C     NDP    - number of decimal places for output
C     NSIG   - number of significant ditits for output
C     RVAL   - time-series values to be output
C     CARD2  - array containig WATSTORE card type 2
C     FLAG   - indicator for availability of 2 card
C              0 - all information available
C              1 - some information available
C              2 - no 2 card information available
C
C     + + + LOCAL VARIABLES + + +
      INTEGER      I, VALPTR, CLMN, KNT, JLEN, YR, YR1, YRN, M, DY, DY1,
     $             DYN, DYM, JUSTR, LEN4, LEN7, LEN15, LEN60, LEN80
      CHARACTER*1  CD(4), MO(2,12), BLNK, CARD(80)
C
C     + + + FUNCTIONS + + +
      INTEGER      DAYMON
C
C     + + + EXTERNALS + + +
      EXTERNAL     ZIPC, COPYC, DAYMON, INTCHR, DECCHX
C
C     + + + DATA INITIALIZATIONS + + +
      DATA  JUSTR, BLNK, CD
     $     /    0,  ' ', '1','2','3','4' /
      DATA  LEN4, LEN7, LEN15, LEN60, LEN80
     $     /   4,    7,    15,    60,    80 /
      DATA  MO
     $   /' ','1', ' ','2', ' ','3', ' ','4', ' ','5', ' ','6',
     $    ' ','7', ' ','8', ' ','9', '1','0', '1','1', '1','2' /
C
C     + + + FORMATS + + +
 2000 FORMAT ( 80A1 )
C
C     + + + END SPECIFICATIONS + + +
C
      YR1 = DATE(1)
      YRN = DATE(7)
      CALL ZIPC ( LEN80, BLNK, CARD )
      CARD(1) = '3'
      CALL COPYC (  LEN15, CARD2(2), CARD(2) )
C
      IF (IREC.EQ.1 .AND. FLAG.LT.2) WRITE (OT,2000) CARD2
C
      VALPTR = 0
      YR = YR1
      DO 200 I = 1, 12
        M = I + (DATE(2)-1)
        IF (M .GT. 12) THEN
          M = M - 12
          YR = YRN
        END IF
        CALL INTCHR ( YR, LEN4, JUSTR, JLEN, CARD(17) )
        DYM = DAYMON ( YR, M )
        DO 150 DY1 = 1, 25, 8
C         loop for each set of 8 days
          DYN = DY1 + 7
          IF (DYN .GT. DYM) DYN = DYM
          KNT = 0
          CLMN = 18
          CARD(21) = MO(1,M)
          CARD(22) = MO(2,M)
          DO 100 DY = DY1, DYN
C           loop for each day
            VALPTR = VALPTR + 1
            CLMN = CLMN + 7
            IF (RVAL(VALPTR) .GE. 0.) THEN
              CALL DECCHX (RVAL(VALPTR), LEN7, NSIG, NDP, CARD(CLMN))
              KNT = KNT + 1
            END IF
 100      CONTINUE
          IF (KNT .GT. 0) THEN
C           output 3 card
            CARD(24) = CD(DY1/8+1)
            WRITE (OT,2000) CARD
            CALL ZIPC ( LEN60, BLNK, CARD(21) )
          END IF
 150    CONTINUE
 200  CONTINUE
C
      RETURN
      END
